@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2023 OpenRCT2 developers
+ * Copyright (c) 2014-2024 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -34,7 +34,7 @@ namespace OpenRCT2::Audio
         {
             if (SDL_Init(SDL_INIT_AUDIO) < 0)
             {
-                SDLException::Throw("SDL_Init(SDL_INIT_AUDIO)");
+                Ui::SDLException::Throw("SDL_Init(SDL_INIT_AUDIO)");
             }
             _audioMixer = std::make_unique<AudioMixer>();
         }
