@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2023 OpenRCT2 developers
+ * Copyright (c) 2014-2024 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -37,29 +37,33 @@ namespace Dropdown
     void SetImage(int32_t index, ImageId image);
 } // namespace Dropdown
 
-extern int32_t gDropdownNumItems;
-extern Dropdown::Item gDropdownItems[Dropdown::ItemsMaxSize];
-extern bool gDropdownIsColour;
-extern int32_t gDropdownLastColourHover;
-extern int32_t gDropdownHighlightedIndex;
-extern int32_t gDropdownDefaultIndex;
+namespace OpenRCT2::Ui::Windows
+{
+    extern int32_t gDropdownNumItems;
+    extern Dropdown::Item gDropdownItems[Dropdown::ItemsMaxSize];
+    extern bool gDropdownIsColour;
+    extern int32_t gDropdownLastColourHover;
+    extern int32_t gDropdownHighlightedIndex;
+    extern int32_t gDropdownDefaultIndex;
 
-void WindowDropdownShowText(const ScreenCoordsXY& screenPos, int32_t extray, uint8_t colour, uint8_t flags, size_t num_items);
-void WindowDropdownShowTextCustomWidth(
-    const ScreenCoordsXY& screenPos, int32_t extray, uint8_t colour, uint8_t custom_height, uint8_t flags, size_t num_items,
-    int32_t width);
-void WindowDropdownShowImage(
-    int32_t x, int32_t y, int32_t extray, uint8_t colour, uint8_t flags, int32_t numItems, int32_t itemWidth,
-    int32_t itemHeight, int32_t numColumns);
-void WindowDropdownClose();
-int32_t DropdownIndexFromPoint(const ScreenCoordsXY& loc, WindowBase* w);
-void WindowDropdownShowColour(WindowBase* w, Widget* widget, uint8_t dropdownColour, uint8_t selectedColour);
-void WindowDropdownShowColourAvailable(
-    WindowBase* w, Widget* widget, uint8_t dropdownColour, uint8_t selectedColour, uint32_t availableColours);
-uint32_t DropdownGetAppropriateImageDropdownItemsPerRow(uint32_t numItems);
-bool WindowDropDownHasMultipleColumns(size_t numItems);
+    void WindowDropdownShowText(
+        const ScreenCoordsXY& screenPos, int32_t extray, uint8_t colour, uint8_t flags, size_t num_items);
+    void WindowDropdownShowTextCustomWidth(
+        const ScreenCoordsXY& screenPos, int32_t extray, uint8_t colour, uint8_t custom_height, uint8_t flags, size_t num_items,
+        int32_t width);
+    void WindowDropdownShowImage(
+        int32_t x, int32_t y, int32_t extray, uint8_t colour, uint8_t flags, int32_t numItems, int32_t itemWidth,
+        int32_t itemHeight, int32_t numColumns);
+    void WindowDropdownClose();
+    int32_t DropdownIndexFromPoint(const ScreenCoordsXY& loc, WindowBase* w);
+    void WindowDropdownShowColour(WindowBase* w, Widget* widget, uint8_t dropdownColour, uint8_t selectedColour);
+    void WindowDropdownShowColourAvailable(
+        WindowBase* w, Widget* widget, uint8_t dropdownColour, uint8_t selectedColour, uint32_t availableColours);
+    uint32_t DropdownGetAppropriateImageDropdownItemsPerRow(uint32_t numItems);
+    bool WindowDropDownHasMultipleColumns(size_t numItems);
 
-colour_t ColourDropDownIndexToColour(uint8_t ddidx);
+    colour_t ColourDropDownIndexToColour(uint8_t ddidx);
+} // namespace OpenRCT2::Ui::Windows
 
 namespace Dropdown
 {
@@ -120,8 +124,8 @@ namespace Dropdown
         for (int i = 0; i < N; ++i)
         {
             const ItemExt& item = items[i];
-            gDropdownItems[i].Format = item.itemFormat;
-            gDropdownItems[i].Args = item.stringId;
+            OpenRCT2::Ui::Windows::gDropdownItems[i].Format = item.itemFormat;
+            OpenRCT2::Ui::Windows::gDropdownItems[i].Args = item.stringId;
         }
     }
 
