@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2023 OpenRCT2 developers
+ * Copyright (c) 2014-2024 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -13,10 +13,10 @@
 #include <openrct2/common.h>
 #include <openrct2/sprites.h>
 
-#define MINIMUM_TOOL_SIZE 1
-#define MAXIMUM_TOOL_SIZE 64
+constexpr uint16_t kLandToolMinimumSize = 1;
+constexpr uint16_t kLandToolMaximumSize = 64;
 // The highest tool size to have a sprite. Bigger tool sizes simply display a number.
-#define MAX_TOOL_SIZE_WITH_SPRITE 7
+constexpr uint16_t kLandToolMaximumSizeWithSprite = 7;
 
 extern uint16_t gLandToolSize;
 extern money64 gLandToolRaiseCost;
