@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2023 OpenRCT2 developers
+ * Copyright (c) 2014-2024 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -9,6 +9,7 @@
 
 #include "Construction.h"
 
+#include <openrct2/GameState.h>
 #include <openrct2/actions/RideCreateAction.h>
 #include <openrct2/ride/Ride.h>
 #include <openrct2/ride/RideConstruction.h>
@@ -28,7 +29,8 @@ void RideConstructNew(RideSelection listItem)
     int32_t colour1 = RideGetRandomColourPresetIndex(listItem.Type);
     int32_t colour2 = RideGetUnusedPresetVehicleColour(rideEntryIndex);
 
-    auto gameAction = RideCreateAction(listItem.Type, listItem.EntryIndex, colour1, colour2, gLastEntranceStyle);
+    auto gameAction = RideCreateAction(
+        listItem.Type, listItem.EntryIndex, colour1, colour2, OpenRCT2::GetGameState().LastEntranceStyle);
 
     gameAction.SetCallback([](const GameAction* ga, const GameActions::Result* result) {
         if (result->Error != GameActions::Status::Ok)
@@ -42,7 +44,7 @@ void RideConstructNew(RideSelection listItem)
 }
 
 SpecialElementsDropdownState BuildSpecialElementsList(
-    const Ride& currentRide, uint8_t buildDirection, uint8_t buildSlope, uint8_t buildBank, RideConstructionState state)
+    const Ride& currentRide, uint8_t buildDirection, TrackPitch buildSlope, TrackRoll buildBank, RideConstructionState state)
 {
     auto buildDirectionIsDiagonal = TrackPieceDirectionIsDiagonal(buildDirection);
     SpecialElementsDropdownState list;
@@ -54,19 +56,19 @@ SpecialElementsDropdownState BuildSpecialElementsList(
     for (track_type_t trackType : DropdownOrder)
     {
         const auto& ted = GetTrackElementDescriptor(trackType);
-        if (!IsTrackEnabled(ted.Definition.type))
+        if (!IsTrackEnabled(ted.Definition.Type))
             continue;
         bool entryIsDisabled;
 
         // If the current build orientation (slope, bank, diagonal) matches the track element's, show the piece as enabled
         if (state == RideConstructionState::Back)
         {
-            entryIsDisabled = ted.Definition.vangle_end != buildSlope || ted.Definition.bank_end != buildBank
+            entryIsDisabled = ted.Definition.PitchEnd != buildSlope || ted.Definition.RollEnd != buildBank
                 || TrackPieceDirectionIsDiagonal(ted.Coordinates.rotation_end) != buildDirectionIsDiagonal;
         }
         else
         {
-            entryIsDisabled = ted.Definition.vangle_start != buildSlope || ted.Definition.bank_start != buildBank
+            entryIsDisabled = ted.Definition.PitchStart != buildSlope || ted.Definition.RollStart != buildBank
                 || TrackPieceDirectionIsDiagonal(ted.Coordinates.rotation_begin) != buildDirectionIsDiagonal;
         }
 
