@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2023 OpenRCT2 developers
+ * Copyright (c) 2014-2024 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -175,7 +175,7 @@ namespace OpenRCT2::Scripting
 
         void clear()
         {
-            GfxClear(&_dpi, _fill);
+            GfxClear(_dpi, _fill);
         }
 
         void clip(int32_t x, int32_t y, int32_t width, int32_t height)
