@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2023 OpenRCT2 developers
+ * Copyright (c) 2014-2024 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -61,6 +61,7 @@
 #include "platform/Crash.h"
 #include "platform/Platform.h"
 #include "profiling/Profiling.h"
+#include "rct2/RCT2.h"
 #include "ride/TrackData.h"
 #include "ride/TrackDesignRepository.h"
 #include "scenario/Scenario.h"
@@ -627,7 +628,7 @@ namespace OpenRCT2
                 {
                     parkImporter = ParkImporter::CreateParkFile(*_objectRepository);
                 }
-                else if (info.Version <= FILE_TYPE_S4_CUTOFF)
+                else if (info.Version <= kFileTypeS4Cutoff)
                 {
                     // Save is an S4 (RCT1 format)
                     parkImporter = ParkImporter::CreateS4();
@@ -646,7 +647,11 @@ namespace OpenRCT2
 
                 GameUnloadScripts();
                 _objectManager->LoadObjects(result.RequiredObjects);
-                parkImporter->Import();
+
+                // TODO: Have a separate GameState and exchange once loaded.
+                auto& gameState = ::GetGameState();
+                parkImporter->Import(gameState);
+
                 gScenarioSavePath = path;
                 gCurrentLoadedPath = path;
                 gFirstTimeSaving = true;
@@ -654,7 +659,7 @@ namespace OpenRCT2
                 MapAnimationAutoCreate();
                 EntityTweener::Get().Reset();
                 gScreenAge = 0;
-                gLastAutoSaveUpdate = AUTOSAVE_PAUSE;
+                gLastAutoSaveUpdate = kAutosavePause;
 
 #ifndef DISABLE_NETWORK
                 bool sendMap = false;
@@ -677,7 +682,7 @@ namespace OpenRCT2
                 }
                 else
                 {
-                    ScenarioBegin();
+                    ScenarioBegin(gameState);
 #ifndef DISABLE_NETWORK
                     if (_network.GetMode() == NETWORK_MODE_SERVER)
                     {
@@ -1084,14 +1089,14 @@ namespace OpenRCT2
         {
             // Ticks
             float scaledDeltaTime = deltaTime * _timeScale;
-            _ticksAccumulator = std::min(_ticksAccumulator + scaledDeltaTime, GAME_UPDATE_MAX_THRESHOLD);
+            _ticksAccumulator = std::min(_ticksAccumulator + scaledDeltaTime, kGameUpdateMaxThreshold);
 
             // Real Time.
-            _realtimeAccumulator = std::min(_realtimeAccumulator + deltaTime, GAME_UPDATE_MAX_THRESHOLD);
-            while (_realtimeAccumulator >= GAME_UPDATE_TIME_MS)
+            _realtimeAccumulator = std::min(_realtimeAccumulator + deltaTime, kGameUpdateMaxThreshold);
+            while (_realtimeAccumulator >= kGameUpdateTimeMS)
             {
                 gCurrentRealTimeTicks++;
-                _realtimeAccumulator -= GAME_UPDATE_TIME_MS;
+                _realtimeAccumulator -= kGameUpdateTimeMS;
             }
         }
 
@@ -1101,18 +1106,18 @@ namespace OpenRCT2
 
             _uiContext->ProcessMessages();
 
-            if (_ticksAccumulator < GAME_UPDATE_TIME_MS)
+            if (_ticksAccumulator < kGameUpdateTimeMS)
             {
-                const auto sleepTimeSec = (GAME_UPDATE_TIME_MS - _ticksAccumulator);
+                const auto sleepTimeSec = (kGameUpdateTimeMS - _ticksAccumulator);
                 Platform::Sleep(static_cast<uint32_t>(sleepTimeSec * 1000.f));
                 return;
             }
 
-            while (_ticksAccumulator >= GAME_UPDATE_TIME_MS)
+            while (_ticksAccumulator >= kGameUpdateTimeMS)
             {
                 Tick();
 
-                _ticksAccumulator -= GAME_UPDATE_TIME_MS;
+                _ticksAccumulator -= kGameUpdateTimeMS;
             }
 
             ContextHandleInput();
@@ -1133,7 +1138,7 @@ namespace OpenRCT2
 
             _uiContext->ProcessMessages();
 
-            while (_ticksAccumulator >= GAME_UPDATE_TIME_MS)
+            while (_ticksAccumulator >= kGameUpdateTimeMS)
             {
                 // Get the original position of each sprite
                 if (shouldDraw)
@@ -1141,7 +1146,7 @@ namespace OpenRCT2
 
                 Tick();
 
-                _ticksAccumulator -= GAME_UPDATE_TIME_MS;
+                _ticksAccumulator -= kGameUpdateTimeMS;
 
                 // Get the next position of each sprite
                 if (shouldDraw)
@@ -1153,7 +1158,7 @@ namespace OpenRCT2
 
             if (shouldDraw)
             {
-                const float alpha = std::min(_ticksAccumulator / GAME_UPDATE_TIME_MS, 1.0f);
+                const float alpha = std::min(_ticksAccumulator / kGameUpdateTimeMS, 1.0f);
                 tweener.Tween(alpha);
 
                 Draw();
@@ -1175,7 +1180,7 @@ namespace OpenRCT2
 
             // TODO: This variable has been never "variable" in time, some code expects
             // this to be 40Hz (25 ms). Refactor this once the UI is decoupled.
-            gCurrentDeltaTime = static_cast<uint16_t>(GAME_UPDATE_TIME_MS * 1000.0f);
+            gCurrentDeltaTime = static_cast<uint16_t>(kGameUpdateTimeMS * 1000.0f);
 
             if (GameIsNotPaused())
             {
@@ -1332,7 +1337,7 @@ namespace OpenRCT2
 
         void SetTimeScale(float newScale) override
         {
-            _timeScale = std::clamp(newScale, GAME_MIN_TIME_SCALE, GAME_MAX_TIME_SCALE);
+            _timeScale = std::clamp(newScale, kGameMinTimeScale, kGameMaxTimeScale);
         }
 
         float GetTimeScale() const override
