@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2023 OpenRCT2 developers
+ * Copyright (c) 2014-2024 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -11,6 +11,7 @@
 
 #include "core/Console.hpp"
 #include "core/String.hpp"
+#include "util/Util.h"
 
 #include <cstdarg>
 #include <cstdio>
@@ -20,7 +21,7 @@
 #endif
 
 [[maybe_unused]] static bool _log_location_enabled = true;
-bool _log_levels[static_cast<uint8_t>(DiagnosticLevel::Count)] = {
+bool _log_levels[EnumValue(DiagnosticLevel::Count)] = {
     true, true, true, false, true,
 };
 
@@ -38,7 +39,7 @@ static FILE* diagnostic_get_stream(DiagnosticLevel level)
 
 #ifdef __ANDROID__
 
-int _android_log_priority[static_cast<uint8_t>(DiagnosticLevel::Count)] = {
+int _android_log_priority[EnumValue(DiagnosticLevel::Count)] = {
     ANDROID_LOG_FATAL, ANDROID_LOG_ERROR, ANDROID_LOG_WARN, ANDROID_LOG_VERBOSE, ANDROID_LOG_INFO,
 };
 
@@ -46,11 +47,11 @@ void DiagnosticLog(DiagnosticLevel diagnosticLevel, const char* format, ...)
 {
     va_list args;
 
-    if (!_log_levels[static_cast<uint8_t>(diagnosticLevel)])
+    if (!_log_levels[EnumValue(diagnosticLevel)])
         return;
 
     va_start(args, format);
-    __android_log_vprint(_android_log_priority[static_cast<uint8_t>(diagnosticLevel)], "OpenRCT2", format, args);
+    __android_log_vprint(_android_log_priority[EnumValue(diagnosticLevel)], "OpenRCT2", format, args);
     va_end(args);
 }
 
@@ -60,13 +61,13 @@ void DiagnosticLogWithLocation(
     va_list args;
     char buf[1024];
 
-    if (!_log_levels[static_cast<uint8_t>(diagnosticLevel)])
+    if (!_log_levels[EnumValue(diagnosticLevel)])
         return;
 
     snprintf(buf, 1024, "[%s:%d (%s)]: ", file, line, function);
 
     va_start(args, format);
-    __android_log_vprint(_android_log_priority[static_cast<uint8_t>(diagnosticLevel)], file, format, args);
+    __android_log_vprint(_android_log_priority[EnumValue(diagnosticLevel)], file, format, args);
     va_end(args);
 }
 
@@ -88,10 +89,10 @@ static void DiagnosticPrint(DiagnosticLevel level, const std::string& prefix, co
 void DiagnosticLog(DiagnosticLevel diagnosticLevel, const char* format, ...)
 {
     va_list args;
-    if (_log_levels[static_cast<uint8_t>(diagnosticLevel)])
+    if (_log_levels[EnumValue(diagnosticLevel)])
     {
         // Level
-        auto prefix = String::StdFormat("%s: ", _level_strings[static_cast<uint8_t>(diagnosticLevel)]);
+        auto prefix = String::StdFormat("%s: ", _level_strings[EnumValue(diagnosticLevel)]);
 
         // Message
         va_start(args, format);
@@ -106,18 +107,17 @@ void DiagnosticLogWithLocation(
     DiagnosticLevel diagnosticLevel, const char* file, const char* function, int32_t line, const char* format, ...)
 {
     va_list args;
-    if (_log_levels[static_cast<uint8_t>(diagnosticLevel)])
+    if (_log_levels[EnumValue(diagnosticLevel)])
     {
         // Level and source code information
         std::string prefix;
         if (_log_location_enabled)
         {
-            prefix = String::StdFormat(
-                "%s[%s:%d (%s)]: ", _level_strings[static_cast<uint8_t>(diagnosticLevel)], file, line, function);
+            prefix = String::StdFormat("%s[%s:%d (%s)]: ", _level_strings[EnumValue(diagnosticLevel)], file, line, function);
         }
         else
         {
-            prefix = String::StdFormat("%s: ", _level_strings[static_cast<uint8_t>(diagnosticLevel)]);
+            prefix = String::StdFormat("%s: ", _level_strings[EnumValue(diagnosticLevel)]);
         }
 
         // Message
