@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2023 OpenRCT2 developers
+ * Copyright (c) 2014-2024 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -12,6 +12,7 @@
 #include "Context.h"
 #include "Editor.h"
 #include "Game.h"
+#include "GameState.h"
 #include "OpenRCT2.h"
 #include "drawing/Drawing.h"
 #include "localisation/Formatter.h"
@@ -479,18 +480,27 @@ void ResetSelectedObjectCountAndSize()
 
 void FinishObjectSelection()
 {
+    auto& gameState = OpenRCT2::GetGameState();
     if (gScreenFlags & SCREEN_FLAGS_TRACK_DESIGNER)
     {
         SetEveryRideTypeInvented();
         SetEveryRideEntryInvented();
-        gEditorStep = EditorStep::RollercoasterDesigner;
+
+        auto& objManager = OpenRCT2::GetContext()->GetObjectManager();
+        gameState.LastEntranceStyle = objManager.GetLoadedObjectEntryIndex("rct2.station.plain");
+        if (gameState.LastEntranceStyle == OBJECT_ENTRY_INDEX_NULL)
+        {
+            gameState.LastEntranceStyle = 0;
+        }
+
+        gameState.EditorStep = EditorStep::RollercoasterDesigner;
         GfxInvalidateScreen();
     }
     else
     {
         SetAllSceneryItemsInvented();
         ScenerySetDefaultPlacementConfiguration();
-        gEditorStep = EditorStep::LandscapeEditor;
+        gameState.EditorStep = EditorStep::LandscapeEditor;
         GfxInvalidateScreen();
     }
 }
