@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2023 OpenRCT2 developers
+ * Copyright (c) 2014-2024 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -11,6 +11,7 @@
 
 #include "Context.h"
 #include "Game.h"
+#include "GameState.h"
 #include "GameStateSnapshots.h"
 #include "OpenRCT2.h"
 #include "ParkImporter.h"
@@ -145,7 +146,7 @@ namespace OpenRCT2
 
             auto ga = GameActions::Clone(action);
 
-            _currentRecording->commands.emplace(gCurrentTicks, std::move(ga), _commandId++);
+            _currentRecording->commands.emplace(tick, std::move(ga), _commandId++);
         }
 
         void AddChecksum(uint32_t tick, EntitiesChecksum&& checksum)
@@ -159,17 +160,19 @@ namespace OpenRCT2
             if (_mode == ReplayMode::NONE)
                 return;
 
-            if ((_mode == ReplayMode::RECORDING || _mode == ReplayMode::NORMALISATION) && gCurrentTicks == _nextChecksumTick)
+            const auto currentTicks = GetGameState().CurrentTicks;
+
+            if ((_mode == ReplayMode::RECORDING || _mode == ReplayMode::NORMALISATION) && currentTicks == _nextChecksumTick)
             {
                 EntitiesChecksum checksum = GetAllEntitiesChecksum();
-                AddChecksum(gCurrentTicks, std::move(checksum));
+                AddChecksum(currentTicks, std::move(checksum));
 
-                _nextChecksumTick = gCurrentTicks + ChecksumTicksDelta();
+                _nextChecksumTick = currentTicks + ChecksumTicksDelta();
             }
 
             if (_mode == ReplayMode::RECORDING)
             {
-                if (gCurrentTicks >= _currentRecording->tickEnd)
+                if (currentTicks >= _currentRecording->tickEnd)
                 {
                     StopRecording();
                     return;
@@ -185,7 +188,7 @@ namespace OpenRCT2
                 ReplayCommands();
 
                 // Normal playback will always end at the specific tick.
-                if (gCurrentTicks >= _currentReplay->tickEnd)
+                if (currentTicks >= _currentReplay->tickEnd)
                 {
                     StopPlayback();
                     return;
@@ -214,7 +217,7 @@ namespace OpenRCT2
 
             auto& snapshot = snapshots->CreateSnapshot();
             snapshots->Capture(snapshot);
-            snapshots->LinkSnapshot(snapshot, gCurrentTicks, ScenarioRandState().s0);
+            snapshots->LinkSnapshot(snapshot, GetGameState().CurrentTicks, ScenarioRandState().s0);
             DataSerialiser snapShotDs(true, snapshotStream);
             snapshots->SerialiseSnapshot(snapshot, snapShotDs);
         }
@@ -230,14 +233,16 @@ namespace OpenRCT2
             if (_mode != ReplayMode::NONE && _mode != ReplayMode::NORMALISATION)
                 return false;
 
+            const auto currentTicks = GetGameState().CurrentTicks;
+
             auto replayData = std::make_unique<ReplayRecordData>();
             replayData->magic = ReplayMagic;
             replayData->version = ReplayVersion;
             replayData->networkId = NetworkGetVersion();
             replayData->name = name;
-            replayData->tickStart = gCurrentTicks;
+            replayData->tickStart = currentTicks;
             if (maxTicks != k_MaxReplayTicks)
-                replayData->tickEnd = gCurrentTicks + maxTicks;
+                replayData->tickEnd = currentTicks + maxTicks;
             else
                 replayData->tickEnd = k_MaxReplayTicks;
 
@@ -247,9 +252,10 @@ namespace OpenRCT2
             auto& objManager = context->GetObjectManager();
             auto objects = objManager.GetPackableObjects();
 
+            auto& gameState = GetGameState();
             auto exporter = std::make_unique<ParkFileExporter>();
             exporter->ExportObjectsList = objects;
-            exporter->Export(replayData->parkData);
+            exporter->Export(gameState, replayData->parkData);
 
             replayData->timeRecorded = std::chrono::seconds(std::time(nullptr)).count();
 
@@ -266,7 +272,7 @@ namespace OpenRCT2
 
             _currentRecording = std::move(replayData);
             _recordType = rt;
-            _nextChecksumTick = gCurrentTicks + 1;
+            _nextChecksumTick = currentTicks + 1;
 
             return true;
         }
@@ -283,11 +289,13 @@ namespace OpenRCT2
                 return true;
             }
 
-            _currentRecording->tickEnd = gCurrentTicks;
+            const auto currentTicks = GetGameState().CurrentTicks;
+
+            _currentRecording->tickEnd = currentTicks;
 
             {
                 EntitiesChecksum checksum = GetAllEntitiesChecksum();
-                AddChecksum(gCurrentTicks, std::move(checksum));
+                AddChecksum(currentTicks, std::move(checksum));
             }
 
             TakeGameStateSnapshot(_currentRecording->gameStateSnapshots);
@@ -366,7 +374,7 @@ namespace OpenRCT2
             info.Version = data->version;
             info.TimeRecorded = data->timeRecorded;
             if (_mode == ReplayMode::RECORDING)
-                info.Ticks = gCurrentTicks - data->tickStart;
+                info.Ticks = GetGameState().CurrentTicks - data->tickStart;
             else if (_mode == ReplayMode::PLAYING)
                 info.Ticks = data->tickEnd - data->tickStart;
             info.NumCommands = static_cast<uint32_t>(data->commands.size());
@@ -384,9 +392,11 @@ namespace OpenRCT2
             GameStateSnapshot_t& replaySnapshot = snapshots->CreateSnapshot();
             snapshots->SerialiseSnapshot(replaySnapshot, ds);
 
+            const auto currentTicks = GetGameState().CurrentTicks;
+
             auto& localSnapshot = snapshots->CreateSnapshot();
             snapshots->Capture(localSnapshot);
-            snapshots->LinkSnapshot(localSnapshot, gCurrentTicks, ScenarioRandState().s0);
+            snapshots->LinkSnapshot(localSnapshot, currentTicks, ScenarioRandState().s0);
             try
             {
                 GameStateCompareData cmpData = snapshots->Compare(replaySnapshot, localSnapshot);
@@ -402,7 +412,7 @@ namespace OpenRCT2
                     std::string outputPath = GetContext()->GetPlatformEnvironment()->GetDirectoryPath(
                         DIRBASE::USER, DIRID::LOG_DESYNCS);
                     char uniqueFileName[128] = {};
-                    snprintf(uniqueFileName, sizeof(uniqueFileName), "replay_desync_%u.txt", gCurrentTicks);
+                    snprintf(uniqueFileName, sizeof(uniqueFileName), "replay_desync_%u.txt", currentTicks);
 
                     std::string outputFile = Path::Combine(outputPath, uniqueFileName);
                     snapshots->LogCompareDataToFile(outputFile, cmpData);
@@ -433,7 +443,7 @@ namespace OpenRCT2
                 return false;
             }
 
-            gCurrentTicks = replayData->tickStart;
+            GetGameState().CurrentTicks = replayData->tickStart;
 
             LoadAndCompareSnapshot(replayData->gameStateSnapshots);
 
@@ -495,7 +505,7 @@ namespace OpenRCT2
                 return false;
             }
 
-            _nextReplayTick = gCurrentTicks + 1;
+            _nextReplayTick = GetGameState().CurrentTicks + 1;
 
             return true;
         }
@@ -526,7 +536,9 @@ namespace OpenRCT2
                 auto loadResult = importer->LoadFromStream(&data.parkData, false);
                 objManager.LoadObjects(loadResult.RequiredObjects);
 
-                importer->Import();
+                // TODO: Have a separate GameState and exchange once loaded.
+                auto& gameState = GetGameState();
+                importer->Import(gameState);
 
                 EntityTweener::Get().Reset();
 
@@ -653,8 +665,10 @@ namespace OpenRCT2
 
         bool SerialiseParkParameters(DataSerialiser& serialiser)
         {
-            serialiser << _guestGenerationProbability;
-            serialiser << _suggestedGuestMaximum;
+            auto& gameState = GetGameState();
+
+            serialiser << gameState.GuestGenerationProbability;
+            serialiser << gameState.SuggestedGuestMaximum;
             serialiser << gConfigGeneral.ShowRealNamesOfGuests;
 
             // To make this a little bit less volatile against updates
@@ -788,19 +802,21 @@ namespace OpenRCT2
             if (checksumIndex >= _currentReplay->checksums.size())
                 return;
 
+            const auto currentTicks = GetGameState().CurrentTicks;
+
             const auto& savedChecksum = _currentReplay->checksums[checksumIndex];
-            if (_currentReplay->checksums[checksumIndex].first == gCurrentTicks)
+            if (_currentReplay->checksums[checksumIndex].first == currentTicks)
             {
                 _currentReplay->checksumIndex++;
 
                 EntitiesChecksum checksum = GetAllEntitiesChecksum();
                 if (savedChecksum.second.raw != checksum.raw)
                 {
-                    uint32_t replayTick = gCurrentTicks - _currentReplay->tickStart;
+                    uint32_t replayTick = currentTicks - _currentReplay->tickStart;
 
                     // Detected different game state.
                     LOG_WARNING(
-                        "Different sprite checksum at tick %u (Replay Tick: %u) ; Saved: %s, Current: %s", gCurrentTicks,
+                        "Different sprite checksum at tick %u (Replay Tick: %u) ; Saved: %s, Current: %s", currentTicks,
                         replayTick, savedChecksum.second.ToString().c_str(), checksum.ToString().c_str());
 
                     _faultyChecksumIndex = checksumIndex;
@@ -809,8 +825,8 @@ namespace OpenRCT2
                 {
                     // Good state.
                     LOG_VERBOSE(
-                        "Good state at tick %u ; Saved: %s, Current: %s", gCurrentTicks,
-                        savedChecksum.second.ToString().c_str(), checksum.ToString().c_str());
+                        "Good state at tick %u ; Saved: %s, Current: %s", currentTicks, savedChecksum.second.ToString().c_str(),
+                        checksum.ToString().c_str());
                 }
             }
         }
@@ -820,6 +836,8 @@ namespace OpenRCT2
         {
             auto& replayQueue = _currentReplay->commands;
 
+            const auto currentTicks = GetGameState().CurrentTicks;
+
             while (replayQueue.begin() != replayQueue.end())
             {
                 const ReplayCommand& command = (*replayQueue.begin());
@@ -827,16 +845,16 @@ namespace OpenRCT2
                 if (_mode == ReplayMode::PLAYING)
                 {
                     // If this is a normal playback wait for the correct tick.
-                    if (command.tick != gCurrentTicks)
+                    if (command.tick != currentTicks)
                         break;
                 }
                 else if (_mode == ReplayMode::NORMALISATION)
                 {
                     // Allow one entry per tick.
-                    if (gCurrentTicks != _nextReplayTick)
+                    if (currentTicks != _nextReplayTick)
                         break;
 
-                    _nextReplayTick = gCurrentTicks + 1;
+                    _nextReplayTick = currentTicks + 1;
                 }
 
                 bool isPositionValid = false;
