@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2023 OpenRCT2 developers
+ * Copyright (c) 2014-2024 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -39,6 +39,8 @@
 #include "ParkSetLoanAction.h"
 #include "ParkSetParameterAction.h"
 
+using namespace OpenRCT2;
+
 using ParametersRange = std::pair<std::pair<int64_t, int64_t>, std::pair<int64_t, int64_t>>;
 
 CheatSetAction::CheatSetAction(CheatType cheatType, int64_t param1, int64_t param2)
@@ -70,18 +72,28 @@ GameActions::Result CheatSetAction::Query() const
 {
     if (static_cast<uint32_t>(_cheatType) >= static_cast<uint32_t>(CheatType::Count))
     {
-        return GameActions::Result(GameActions::Status::InvalidParameters, STR_NONE, STR_NONE);
+        LOG_ERROR("Invalid cheat type %u", _cheatType);
+        return GameActions::Result(
+            GameActions::Status::InvalidParameters, STR_ERR_INVALID_PARAMETER, STR_ERR_VALUE_OUT_OF_RANGE);
     }
 
     ParametersRange validRange = GetParameterRange(static_cast<CheatType>(_cheatType.id));
 
     if (_param1 < validRange.first.first || _param1 > validRange.first.second)
     {
-        return GameActions::Result(GameActions::Status::InvalidParameters, STR_NONE, STR_NONE);
+        LOG_ERROR(
+            "The first cheat parameter is out of range. Value = %d, min = %d, max = %d", _param1, validRange.first.first,
+            validRange.first.second);
+        return GameActions::Result(
+            GameActions::Status::InvalidParameters, STR_ERR_INVALID_PARAMETER, STR_ERR_VALUE_OUT_OF_RANGE);
     }
     if (_param2 < validRange.second.first || _param2 > validRange.second.second)
     {
-        return GameActions::Result(GameActions::Status::InvalidParameters, STR_NONE, STR_NONE);
+        LOG_ERROR(
+            "The second cheat parameter is out of range. Value = %d, min = %d, max = %d", _param2, validRange.second.first,
+            validRange.second.second);
+        return GameActions::Result(
+            GameActions::Status::InvalidParameters, STR_ERR_INVALID_PARAMETER, STR_ERR_VALUE_OUT_OF_RANGE);
     }
 
     return GameActions::Result();
@@ -89,53 +101,54 @@ GameActions::Result CheatSetAction::Query() const
 
 GameActions::Result CheatSetAction::Execute() const
 {
+    auto& gameState = GetGameState();
     switch (static_cast<CheatType>(_cheatType.id))
     {
         case CheatType::SandboxMode:
-            gCheatsSandboxMode = _param1 != 0;
+            GetGameState().Cheats.SandboxMode = _param1 != 0;
             WindowInvalidateByClass(WindowClass::Map);
             WindowInvalidateByClass(WindowClass::Footpath);
             break;
         case CheatType::DisableClearanceChecks:
-            gCheatsDisableClearanceChecks = _param1 != 0;
+            GetGameState().Cheats.DisableClearanceChecks = _param1 != 0;
             // Required to update the clearance checks overlay on the Cheats button.
             WindowInvalidateByClass(WindowClass::TopToolbar);
             break;
         case CheatType::DisableSupportLimits:
-            gCheatsDisableSupportLimits = _param1 != 0;
+            GetGameState().Cheats.DisableSupportLimits = _param1 != 0;
             break;
         case CheatType::ShowAllOperatingModes:
-            gCheatsShowAllOperatingModes = _param1 != 0;
+            GetGameState().Cheats.ShowAllOperatingModes = _param1 != 0;
             break;
         case CheatType::ShowVehiclesFromOtherTrackTypes:
-            gCheatsShowVehiclesFromOtherTrackTypes = _param1 != 0;
+            GetGameState().Cheats.ShowVehiclesFromOtherTrackTypes = _param1 != 0;
             break;
         case CheatType::FastLiftHill:
-            gCheatsUnlockOperatingLimits = _param1 != 0;
+            GetGameState().Cheats.UnlockOperatingLimits = _param1 != 0;
             break;
         case CheatType::DisableBrakesFailure:
-            gCheatsDisableBrakesFailure = _param1 != 0;
+            GetGameState().Cheats.DisableBrakesFailure = _param1 != 0;
             break;
         case CheatType::DisableAllBreakdowns:
-            gCheatsDisableAllBreakdowns = _param1 != 0;
+            GetGameState().Cheats.DisableAllBreakdowns = _param1 != 0;
             break;
         case CheatType::DisableTrainLengthLimit:
-            gCheatsDisableTrainLengthLimit = _param1 != 0;
+            GetGameState().Cheats.DisableTrainLengthLimit = _param1 != 0;
             break;
         case CheatType::EnableChainLiftOnAllTrack:
-            gCheatsEnableChainLiftOnAllTrack = _param1 != 0;
+            GetGameState().Cheats.EnableChainLiftOnAllTrack = _param1 != 0;
             break;
         case CheatType::BuildInPauseMode:
-            gCheatsBuildInPauseMode = _param1 != 0;
+            GetGameState().Cheats.BuildInPauseMode = _param1 != 0;
             break;
         case CheatType::IgnoreRideIntensity:
-            gCheatsIgnoreRideIntensity = _param1 != 0;
+            GetGameState().Cheats.IgnoreRideIntensity = _param1 != 0;
             break;
         case CheatType::DisableVandalism:
-            gCheatsDisableVandalism = _param1 != 0;
+            GetGameState().Cheats.DisableVandalism = _param1 != 0;
             break;
         case CheatType::DisableLittering:
-            gCheatsDisableLittering = _param1 != 0;
+            GetGameState().Cheats.DisableLittering = _param1 != 0;
             break;
         case CheatType::NoMoney:
             SetScenarioNoMoney(_param1 != 0);
@@ -174,7 +187,7 @@ GameActions::Result CheatSetAction::Execute() const
             RemoveLitter();
             break;
         case CheatType::DisablePlantAging:
-            gCheatsDisablePlantAging = _param1 != 0;
+            GetGameState().Cheats.DisablePlantAging = _param1 != 0;
             break;
         case CheatType::SetStaffSpeed:
             SetStaffSpeed(_param1);
@@ -183,7 +196,7 @@ GameActions::Result CheatSetAction::Execute() const
             RenewRides();
             break;
         case CheatType::MakeDestructible:
-            gCheatsMakeAllDestructible = _param1 != 0;
+            GetGameState().Cheats.MakeAllDestructible = _param1 != 0;
             WindowInvalidateByClass(WindowClass::Ride);
             break;
         case CheatType::FixRides:
@@ -196,42 +209,42 @@ GameActions::Result CheatSetAction::Execute() const
             Set10MinuteInspection();
             break;
         case CheatType::WinScenario:
-            ScenarioSuccess();
+            ScenarioSuccess(gameState);
             break;
         case CheatType::ForceWeather:
             // Todo - make sure this is safe
             ClimateForceWeather(WeatherType{ static_cast<uint8_t>(_param1) });
             break;
         case CheatType::FreezeWeather:
-            gCheatsFreezeWeather = _param1 != 0;
+            GetGameState().Cheats.FreezeWeather = _param1 != 0;
             break;
         case CheatType::NeverEndingMarketing:
-            gCheatsNeverendingMarketing = _param1 != 0;
+            GetGameState().Cheats.NeverendingMarketing = _param1 != 0;
             break;
         case CheatType::OpenClosePark:
             ParkSetOpen(!ParkIsOpen());
             break;
         case CheatType::HaveFun:
-            gScenarioObjective.Type = OBJECTIVE_HAVE_FUN;
+            gameState.ScenarioObjective.Type = OBJECTIVE_HAVE_FUN;
             break;
         case CheatType::SetForcedParkRating:
             ParkSetForcedRating(_param1);
             break;
         case CheatType::AllowArbitraryRideTypeChanges:
-            gCheatsAllowArbitraryRideTypeChanges = _param1 != 0;
+            GetGameState().Cheats.AllowArbitraryRideTypeChanges = _param1 != 0;
             WindowInvalidateByClass(WindowClass::Ride);
             break;
         case CheatType::OwnAllLand:
             OwnAllLand();
             break;
         case CheatType::DisableRideValueAging:
-            gCheatsDisableRideValueAging = _param1 != 0;
+            GetGameState().Cheats.DisableRideValueAging = _param1 != 0;
             break;
         case CheatType::IgnoreResearchStatus:
-            gCheatsIgnoreResearchStatus = _param1 != 0;
+            GetGameState().Cheats.IgnoreResearchStatus = _param1 != 0;
             break;
         case CheatType::EnableAllDrawableTrackPieces:
-            gCheatsEnableAllDrawableTrackPieces = _param1 != 0;
+            GetGameState().Cheats.EnableAllDrawableTrackPieces = _param1 != 0;
             break;
         case CheatType::CreateDucks:
             CreateDucks(_param1);
@@ -240,23 +253,23 @@ GameActions::Result CheatSetAction::Execute() const
             Duck::RemoveAll();
             break;
         case CheatType::AllowTrackPlaceInvalidHeights:
-            gCheatsAllowTrackPlaceInvalidHeights = _param1 != 0;
+            GetGameState().Cheats.AllowTrackPlaceInvalidHeights = _param1 != 0;
             break;
         case CheatType::AllowRegularPathAsQueue:
-            gCheatsAllowRegularPathAsQueue = _param1 != 0;
+            GetGameState().Cheats.AllowRegularPathAsQueue = _param1 != 0;
             break;
         case CheatType::AllowSpecialColourSchemes:
-            gCheatsAllowSpecialColourSchemes = static_cast<bool>(_param1);
+            GetGameState().Cheats.AllowSpecialColourSchemes = static_cast<bool>(_param1);
             break;
         case CheatType::RemoveParkFences:
             RemoveParkFences();
             break;
         default:
         {
-            LOG_ERROR("Unabled cheat: %d", _cheatType.id);
-            GameActions::Result(GameActions::Status::InvalidParameters, STR_NONE, STR_NONE);
+            LOG_ERROR("Invalid cheat type %d", _cheatType.id);
+            return GameActions::Result(
+                GameActions::Status::InvalidParameters, STR_ERR_INVALID_PARAMETER, STR_ERR_VALUE_OUT_OF_RANGE);
         }
-        break;
     }
 
     if (NetworkGetMode() == NETWORK_MODE_NONE)
@@ -413,9 +426,10 @@ ParametersRange CheatSetAction::GetParameterRange(CheatType cheatType) const
 
 void CheatSetAction::SetGrassLength(int32_t length) const
 {
-    for (int32_t y = 0; y < gMapSize.y; y++)
+    auto& gameState = GetGameState();
+    for (int32_t y = 0; y < gameState.MapSize.y; y++)
     {
-        for (int32_t x = 0; x < gMapSize.x; x++)
+        for (int32_t x = 0; x < gameState.MapSize.x; x++)
         {
             auto surfaceElement = MapGetSurfaceElementAt(TileCoordsXY{ x, y });
             if (surfaceElement == nullptr)
@@ -545,14 +559,16 @@ void CheatSetAction::Set10MinuteInspection() const
 
 void CheatSetAction::SetScenarioNoMoney(bool enabled) const
 {
+    auto& gameState = GetGameState();
     if (enabled)
     {
-        gParkFlags |= PARK_FLAGS_NO_MONEY;
+        gameState.ParkFlags |= PARK_FLAGS_NO_MONEY;
     }
     else
     {
-        gParkFlags &= ~PARK_FLAGS_NO_MONEY;
+        gameState.ParkFlags &= ~PARK_FLAGS_NO_MONEY;
     }
+
     // Invalidate all windows that have anything to do with finance
     WindowInvalidateByClass(WindowClass::Ride);
     WindowInvalidateByClass(WindowClass::Peep);
@@ -565,7 +581,7 @@ void CheatSetAction::SetScenarioNoMoney(bool enabled) const
 
 void CheatSetAction::SetMoney(money64 amount) const
 {
-    gCash = amount;
+    GetGameState().Cash = amount;
 
     WindowInvalidateByClass(WindowClass::Finances);
     WindowInvalidateByClass(WindowClass::BottomToolbar);
@@ -573,7 +589,7 @@ void CheatSetAction::SetMoney(money64 amount) const
 
 void CheatSetAction::AddMoney(money64 amount) const
 {
-    gCash = AddClamp_money64(gCash, amount);
+    GetGameState().Cash = AddClamp_money64(GetGameState().Cash, amount);
 
     WindowInvalidateByClass(WindowClass::Finances);
     WindowInvalidateByClass(WindowClass::BottomToolbar);
@@ -582,7 +598,7 @@ void CheatSetAction::AddMoney(money64 amount) const
 void CheatSetAction::ClearLoan() const
 {
     // First give money
-    AddMoney(gBankLoan);
+    AddMoney(GetGameState().BankLoan);
 
     // Then pay the loan
     auto gameAction = ParkSetLoanAction(0.00_GBP);
@@ -758,7 +774,7 @@ void CheatSetAction::OwnAllLand() const
     }
 
     // Completely unown peep spawn points
-    for (const auto& spawn : gPeepSpawns)
+    for (const auto& spawn : GetGameState().PeepSpawns)
     {
         auto* surfaceElement = MapGetSurfaceElementAt(spawn);
         if (surfaceElement != nullptr)
