@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2023 OpenRCT2 developers
+ * Copyright (c) 2014-2024 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -67,6 +67,7 @@
 #include "RideSetStatusAction.h"
 #include "RideSetVehicleAction.h"
 #include "ScenarioSetSettingAction.h"
+#include "ScenerySetRestrictedAction.h"
 #include "SignSetNameAction.h"
 #include "SignSetStyleAction.h"
 #include "SmallSceneryPlaceAction.h"
@@ -208,6 +209,7 @@ namespace GameActions
         REGISTER_ACTION(CheatSetAction);
         REGISTER_ACTION(MapChangeSizeAction);
         REGISTER_ACTION(GameSetSpeedAction);
+        REGISTER_ACTION(ScenerySetRestrictedAction);
 #ifdef ENABLE_SCRIPTING
         REGISTER_ACTION(CustomAction);
 #endif
