@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2023 OpenRCT2 developers
+ * Copyright (c) 2014-2024 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -58,13 +58,13 @@ GameActions::Result GuestSetNameAction::Query() const
 {
     if (_spriteIndex.ToUnderlying() >= MAX_ENTITIES || _spriteIndex.IsNull())
     {
-        return GameActions::Result(GameActions::Status::InvalidParameters, STR_CANT_NAME_GUEST, STR_NONE);
+        return GameActions::Result(GameActions::Status::InvalidParameters, STR_CANT_NAME_GUEST, STR_ERR_VALUE_OUT_OF_RANGE);
     }
 
     auto guest = TryGetEntity<Guest>(_spriteIndex);
     if (guest == nullptr)
     {
-        LOG_WARNING("Invalid game command for sprite %u", _spriteIndex);
+        LOG_ERROR("Guest entity not found for spriteIndex %u", _spriteIndex);
         return GameActions::Result(GameActions::Status::InvalidParameters, STR_CANT_NAME_GUEST, STR_NONE);
     }
 
@@ -76,7 +76,7 @@ GameActions::Result GuestSetNameAction::Execute() const
     auto guest = TryGetEntity<Guest>(_spriteIndex);
     if (guest == nullptr)
     {
-        LOG_WARNING("Invalid game command for sprite %u", _spriteIndex);
+        LOG_ERROR("Guest entity not found for spriteIndex %u", _spriteIndex);
         return GameActions::Result(GameActions::Status::InvalidParameters, STR_CANT_NAME_GUEST, STR_NONE);
     }
 
