@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2023 OpenRCT2 developers
+ * Copyright (c) 2014-2024 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -10,6 +10,7 @@
 #include "ParkSetLoanAction.h"
 
 #include "../Context.h"
+#include "../GameState.h"
 #include "../core/MemoryStream.h"
 #include "../localisation/StringIds.h"
 #include "../management/Finance.h"
@@ -17,6 +18,8 @@
 #include "../ui/WindowManager.h"
 #include "../windows/Intent.h"
 
+using namespace OpenRCT2;
+
 ParkSetLoanAction::ParkSetLoanAction(money64 value)
     : _value(value)
 {
@@ -40,19 +43,20 @@ void ParkSetLoanAction::Serialise(DataSerialiser& stream)
 
 GameActions::Result ParkSetLoanAction::Query() const
 {
-    if (_value > gBankLoan && _value > gMaxBankLoan)
+    auto& gameState = GetGameState();
+    if (_value > gameState.BankLoan && _value > gameState.MaxBankLoan)
     {
         return GameActions::Result(
             GameActions::Status::Disallowed, STR_CANT_BORROW_ANY_MORE_MONEY, STR_BANK_REFUSES_TO_INCREASE_LOAN);
     }
-    if (_value < gBankLoan && _value < 0.00_GBP)
+    if (_value < gameState.BankLoan && _value < 0.00_GBP)
     {
         return GameActions::Result(GameActions::Status::InvalidParameters, STR_CANT_PAY_BACK_LOAN, STR_LOAN_CANT_BE_NEGATIVE);
     }
     // The “isPayingBack” check is needed to allow increasing the loan when the player is in debt.
-    const auto isPayingBack = gBankLoan > _value;
-    const auto amountToPayBack = gBankLoan - _value;
-    if (isPayingBack && amountToPayBack > gCash)
+    const auto isPayingBack = gameState.BankLoan > _value;
+    const auto amountToPayBack = gameState.BankLoan - _value;
+    if (isPayingBack && amountToPayBack > gameState.Cash)
     {
         return GameActions::Result(
             GameActions::Status::InsufficientFunds, STR_CANT_PAY_BACK_LOAN, STR_NOT_ENOUGH_CASH_AVAILABLE);
@@ -62,8 +66,10 @@ GameActions::Result ParkSetLoanAction::Query() const
 
 GameActions::Result ParkSetLoanAction::Execute() const
 {
-    gCash -= (gBankLoan - _value);
-    gBankLoan = _value;
+    auto& gameState = GetGameState();
+
+    gameState.Cash -= (gameState.BankLoan - _value);
+    gameState.BankLoan = _value;
 
     auto windowManager = OpenRCT2::GetContext()->GetUiContext()->GetWindowManager();
     windowManager->BroadcastIntent(Intent(INTENT_ACTION_UPDATE_CASH));
