@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2023 OpenRCT2 developers
+ * Copyright (c) 2014-2024 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -9,11 +9,14 @@
 
 #include "ParkSetParameterAction.h"
 
+#include "../GameState.h"
 #include "../interface/Window.h"
 #include "../ride/ShopItem.h"
 #include "../util/Util.h"
 #include "../world/Park.h"
 
+using namespace OpenRCT2;
+
 ParkSetParameterAction::ParkSetParameterAction(ParkParameter parameter, uint64_t value)
     : _parameter(parameter)
     , _value(value)
@@ -41,7 +44,9 @@ GameActions::Result ParkSetParameterAction::Query() const
 {
     if (_parameter >= ParkParameter::Count)
     {
-        return GameActions::Result(GameActions::Status::InvalidParameters, STR_NONE, STR_NONE);
+        LOG_ERROR("Invalid park parameter %d", _parameter);
+        return GameActions::Result(
+            GameActions::Status::InvalidParameters, STR_ERR_INVALID_PARAMETER, STR_ERR_VALUE_OUT_OF_RANGE);
     }
 
     auto res = GameActions::Result();
@@ -51,28 +56,31 @@ GameActions::Result ParkSetParameterAction::Query() const
 
 GameActions::Result ParkSetParameterAction::Execute() const
 {
+    auto& gameState = GetGameState();
     switch (_parameter)
     {
         case ParkParameter::Close:
-            if (gParkFlags & PARK_FLAGS_PARK_OPEN)
+            if (gameState.ParkFlags & PARK_FLAGS_PARK_OPEN)
             {
-                gParkFlags &= ~PARK_FLAGS_PARK_OPEN;
+                gameState.ParkFlags &= ~PARK_FLAGS_PARK_OPEN;
                 WindowInvalidateByClass(WindowClass::ParkInformation);
             }
             break;
         case ParkParameter::Open:
-            if (!(gParkFlags & PARK_FLAGS_PARK_OPEN))
+            if (!(gameState.ParkFlags & PARK_FLAGS_PARK_OPEN))
             {
-                gParkFlags |= PARK_FLAGS_PARK_OPEN;
+                gameState.ParkFlags |= PARK_FLAGS_PARK_OPEN;
                 WindowInvalidateByClass(WindowClass::ParkInformation);
             }
             break;
         case ParkParameter::SamePriceInPark:
-            gSamePriceThroughoutPark = _value;
+            gameState.SamePriceThroughoutPark = _value;
             WindowInvalidateByClass(WindowClass::Ride);
             break;
         default:
-            return GameActions::Result(GameActions::Status::InvalidParameters, STR_NONE, STR_NONE);
+            LOG_ERROR("Invalid park parameter %d", _parameter);
+            return GameActions::Result(
+                GameActions::Status::InvalidParameters, STR_ERR_INVALID_PARAMETER, STR_ERR_VALUE_OUT_OF_RANGE);
     }
 
     auto res = GameActions::Result();
