@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2023 OpenRCT2 developers
+ * Copyright (c) 2014-2024 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -10,6 +10,7 @@
 #include "ParkSetResearchFundingAction.h"
 
 #include "../Context.h"
+#include "../GameState.h"
 #include "../core/MemoryStream.h"
 #include "../localisation/StringIds.h"
 #include "../management/Research.h"
@@ -17,6 +18,8 @@
 #include "../ui/WindowManager.h"
 #include "../windows/Intent.h"
 
+using namespace OpenRCT2;
+
 ParkSetResearchFundingAction::ParkSetResearchFundingAction(uint32_t priorities, uint8_t fundingAmount)
     : _priorities(priorities)
     , _fundingAmount(fundingAmount)
@@ -44,15 +47,18 @@ GameActions::Result ParkSetResearchFundingAction::Query() const
 {
     if (_fundingAmount >= RESEARCH_FUNDING_COUNT)
     {
-        return GameActions::Result(GameActions::Status::InvalidParameters, STR_NONE, STR_NONE);
+        LOG_ERROR("Invalid research funding amount %d", _fundingAmount);
+        return GameActions::Result(
+            GameActions::Status::InvalidParameters, STR_ERR_INVALID_PARAMETER, STR_ERR_VALUE_OUT_OF_RANGE);
     }
     return GameActions::Result();
 }
 
 GameActions::Result ParkSetResearchFundingAction::Execute() const
 {
-    gResearchPriorities = _priorities;
-    gResearchFundingLevel = _fundingAmount;
+    auto& gameState = GetGameState();
+    gameState.ResearchPriorities = _priorities;
+    gameState.ResearchFundingLevel = _fundingAmount;
 
     auto windowManager = OpenRCT2::GetContext()->GetUiContext()->GetWindowManager();
     windowManager->BroadcastIntent(Intent(INTENT_ACTION_UPDATE_RESEARCH));
