@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2023 OpenRCT2 developers
+ * Copyright (c) 2014-2024 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -106,7 +106,7 @@ GameActions::Result PeepPickupAction::Query() const
             }
             break;
         default:
-            LOG_ERROR("Invalid pickup type: %u", _type);
+            LOG_ERROR("Invalid peep pickup type %u", _type);
             return GameActions::Result(GameActions::Status::InvalidParameters, STR_ERR_CANT_PLACE_PERSON_HERE, STR_NONE);
     }
     return res;
@@ -175,7 +175,7 @@ GameActions::Result PeepPickupAction::Execute() const
             CancelConcurrentPickups(peep);
             break;
         default:
-            LOG_ERROR("Invalid pickup type: %u", _type);
+            LOG_ERROR("Invalid peep pickup type %u", _type);
             return GameActions::Result(GameActions::Status::InvalidParameters, STR_ERR_CANT_PLACE_PERSON_HERE, STR_NONE);
     }
     return res;
