@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2023 OpenRCT2 developers
+ * Copyright (c) 2014-2024 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -11,6 +11,7 @@
 
 #include "../Cheats.h"
 #include "../Context.h"
+#include "../GameState.h"
 #include "../core/Memory.hpp"
 #include "../core/MemoryStream.h"
 #include "../interface/Window.h"
@@ -27,6 +28,8 @@
 
 #include <algorithm>
 
+using namespace OpenRCT2;
+
 RideCreateAction::RideCreateAction(
     int32_t rideType, ObjectEntryIndex subType, int32_t colour1, int32_t colour2, ObjectEntryIndex entranceObjectIndex)
     : _rideType(rideType)
@@ -80,6 +83,7 @@ GameActions::Result RideCreateAction::Query() const
 
     if (_rideType >= RIDE_TYPE_COUNT)
     {
+        LOG_ERROR("Invalid ride type %d", _rideType);
         return GameActions::Result(
             GameActions::Status::InvalidParameters, STR_CANT_CREATE_NEW_RIDE_ATTRACTION, STR_INVALID_RIDE_TYPE);
     }
@@ -87,6 +91,7 @@ GameActions::Result RideCreateAction::Query() const
     int32_t rideEntryIndex = RideGetEntryIndex(_rideType, _subType);
     if (rideEntryIndex >= MAX_RIDE_OBJECTS)
     {
+        LOG_ERROR("Ride entry not found for rideType %d, subType %d", _rideType, _subType);
         return GameActions::Result(
             GameActions::Status::InvalidParameters, STR_CANT_CREATE_NEW_RIDE_ATTRACTION, STR_INVALID_RIDE_TYPE);
     }
@@ -94,12 +99,15 @@ GameActions::Result RideCreateAction::Query() const
     const auto& colourPresets = GetRideTypeDescriptor(_rideType).ColourPresets;
     if (_colour1 >= colourPresets.count)
     {
-        return GameActions::Result(GameActions::Status::InvalidParameters, STR_CANT_CREATE_NEW_RIDE_ATTRACTION, STR_NONE);
+        LOG_ERROR("Can't create ride, invalid colour preset %d", _colour1);
+        return GameActions::Result(
+            GameActions::Status::InvalidParameters, STR_CANT_CREATE_NEW_RIDE_ATTRACTION, STR_ERR_INVALID_COLOUR);
     }
 
     const auto* rideEntry = GetRideEntryByIndex(rideEntryIndex);
     if (rideEntry == nullptr)
     {
+        LOG_ERROR("Ride entry not found for rideEntryIndex %d", rideEntryIndex);
         return GameActions::Result(
             GameActions::Status::InvalidParameters, STR_CANT_CREATE_NEW_RIDE_ATTRACTION, STR_UNKNOWN_OBJECT_TYPE);
     }
@@ -127,11 +135,12 @@ GameActions::Result RideCreateAction::Execute() const
     const auto* rideEntry = GetRideEntryByIndex(rideEntryIndex);
     if (rideEntry == nullptr)
     {
-        LOG_WARNING("Invalid request for ride %u", rideIndex);
+        LOG_ERROR(
+            "Ride entry not found for index rideEntryIndex %u (from rideType %u, subType %u)", rideEntryIndex, _rideType,
+            _subType);
         return GameActions::Result(GameActions::Status::Unknown, STR_CANT_CREATE_NEW_RIDE_ATTRACTION, STR_UNKNOWN_OBJECT_TYPE);
     }
 
-    ride->id = rideIndex;
     ride->type = _rideType;
     ride->subtype = rideEntryIndex;
     ride->SetColourPreset(_colour1);
@@ -143,18 +152,17 @@ GameActions::Result RideCreateAction::Execute() const
         station.Start.SetNull();
         station.Entrance.SetNull();
         station.Exit.SetNull();
-        station.TrainAtStation = RideStation::NO_TRAIN;
+        station.TrainAtStation = RideStation::kNoTrain;
         station.QueueTime = 0;
+        station.SegmentLength = 0;
+        station.QueueLength = 0;
+        station.Length = 0;
+        station.Height = 0;
     }
 
-    std::fill(std::begin(ride->vehicles), std::end(ride->vehicles), EntityId::GetNull());
-
     ride->status = RideStatus::Closed;
-    ride->lifecycle_flags = 0;
-    ride->vehicle_change_timeout = 0;
-    ride->num_stations = 0;
     ride->NumTrains = 1;
-    if (gCheatsDisableTrainLengthLimit)
+    if (GetGameState().Cheats.DisableTrainLengthLimit)
     {
         // Reduce amount of proposed trains to prevent 32 trains from always spawning when limits are disabled
         if (rideEntry->cars_per_flat_ride == NoFlatRideCars)
@@ -196,18 +204,10 @@ GameActions::Result RideCreateAction::Execute() const
 
     ride->lift_hill_speed = rtd.LiftData.minimum_speed;
 
-    ride->measurement = {};
-    ride->excitement = RIDE_RATING_UNDEFINED;
-    ride->cur_num_customers = 0;
-    ride->num_customers_timeout = 0;
-    ride->chairlift_bullwheel_rotation = 0;
+    ride->excitement = kRideRatingUndefined;
 
-    for (auto& price : ride->price)
-    {
-        price = 0;
-    }
-
-    if (!(gParkFlags & PARK_FLAGS_NO_MONEY))
+    auto& gameState = GetGameState();
+    if (!(gameState.ParkFlags & PARK_FLAGS_NO_MONEY))
     {
         for (auto i = 0; i < RCT2::ObjectLimits::MaxShopItemsPerRideEntry; i++)
         {
@@ -216,7 +216,7 @@ GameActions::Result RideCreateAction::Execute() const
 
         if (rideEntry->shop_item[0] == ShopItem::None)
         {
-            if (!ParkRidePricesUnlocked() || gParkEntranceFee > 0)
+            if (!ParkRidePricesUnlocked() || gameState.ParkEntranceFee > 0)
             {
                 ride->price[0] = 0;
             }
@@ -230,7 +230,7 @@ GameActions::Result RideCreateAction::Execute() const
             ride->price[1] = GetShopItemDescriptor(rideEntry->shop_item[1]).DefaultPrice;
         }
 
-        if (gScenarioObjective.Type == OBJECTIVE_BUILD_THE_BEST)
+        if (gameState.ScenarioObjective.Type == OBJECTIVE_BUILD_THE_BEST)
         {
             ride->price[0] = 0;
         }
@@ -240,7 +240,7 @@ GameActions::Result RideCreateAction::Execute() const
             if (ShopItemHasCommonPrice(ShopItem::Admission))
             {
                 auto price = RideGetCommonPrice(*ride);
-                if (price != MONEY64_UNDEFINED)
+                if (price != kMoney64Undefined)
                 {
                     ride->price[0] = price;
                 }
@@ -254,7 +254,7 @@ GameActions::Result RideCreateAction::Execute() const
                 if (ShopItemHasCommonPrice(rideEntry->shop_item[i]))
                 {
                     auto price = ShopItemGetCommonPrice(ride, rideEntry->shop_item[i]);
-                    if (price != MONEY64_UNDEFINED)
+                    if (price != kMoney64Undefined)
                     {
                         ride->price[i] = price;
                     }
@@ -266,44 +266,27 @@ GameActions::Result RideCreateAction::Execute() const
         if (!rtd.HasFlag(RIDE_TYPE_FLAG_IS_SHOP_OR_FACILITY) && ShopItemHasCommonPrice(ShopItem::Photo))
         {
             auto price = ShopItemGetCommonPrice(ride, ShopItem::Photo);
-            if (price != MONEY64_UNDEFINED)
+            if (price != kMoney64Undefined)
             {
                 ride->price[1] = price;
             }
         }
     }
 
-    std::fill(std::begin(ride->num_customers), std::end(ride->num_customers), 0);
     ride->value = RIDE_VALUE_UNDEFINED;
     ride->satisfaction = 255;
-    ride->satisfaction_time_out = 0;
-    ride->satisfaction_next = 0;
     ride->popularity = 255;
-    ride->popularity_time_out = 0;
-    ride->popularity_next = 0;
-    ride->window_invalidate_flags = 0;
-    ride->total_customers = 0;
-    ride->total_profit = 0;
-    ride->num_riders = 0;
-    ride->slide_in_use = 0;
-    ride->maze_tiles = 0;
     ride->build_date = GetDate().GetMonthsElapsed();
     ride->music_tune_id = TUNE_ID_NULL;
 
     ride->breakdown_reason = 255;
-    ride->upkeep_cost = MONEY64_UNDEFINED;
-    ride->reliability = RIDE_INITIAL_RELIABILITY;
+    ride->upkeep_cost = kMoney64Undefined;
+    ride->reliability = kRideInitialReliability;
     ride->unreliability_factor = 1;
     ride->inspection_interval = RIDE_INSPECTION_EVERY_30_MINUTES;
-    ride->last_inspection = 0;
-    ride->downtime = 0;
-    std::fill_n(ride->downtime_history, sizeof(ride->downtime_history), 0x00);
-    ride->no_primary_items_sold = 0;
-    ride->no_secondary_items_sold = 0;
     ride->last_crash_type = RIDE_CRASH_TYPE_NONE;
-    ride->income_per_hour = MONEY64_UNDEFINED;
-    ride->profit = MONEY64_UNDEFINED;
-    ride->connected_message_throttle = 0;
+    ride->income_per_hour = kMoney64Undefined;
+    ride->profit = kMoney64Undefined;
 
     ride->entrance_style = OBJECT_ENTRY_INDEX_NULL;
     if (rtd.HasFlag(RIDE_TYPE_FLAG_HAS_ENTRANCE_EXIT))
@@ -311,9 +294,6 @@ GameActions::Result RideCreateAction::Execute() const
         ride->entrance_style = _entranceObjectIndex;
     }
 
-    ride->num_block_brakes = 0;
-    ride->guests_favourite = 0;
-
     ride->num_circuits = 1;
     ride->mode = ride->GetDefaultMode();
     ride->MinCarsPerTrain = rideEntry->min_cars_in_train;
