@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2023 OpenRCT2 developers
+ * Copyright (c) 2014-2024 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -60,13 +60,13 @@ GameActions::Result RideDemolishAction::Query() const
     auto ride = GetRide(_rideIndex);
     if (ride == nullptr)
     {
-        LOG_WARNING("Invalid game command for ride %u", _rideIndex.ToUnderlying());
-        return GameActions::Result(GameActions::Status::InvalidParameters, STR_CANT_DEMOLISH_RIDE, STR_NONE);
+        LOG_ERROR("Ride not found for rideIndex %u", _rideIndex.ToUnderlying());
+        return GameActions::Result(GameActions::Status::InvalidParameters, STR_CANT_DEMOLISH_RIDE, STR_ERR_RIDE_NOT_FOUND);
     }
 
     if ((ride->lifecycle_flags & (RIDE_LIFECYCLE_INDESTRUCTIBLE | RIDE_LIFECYCLE_INDESTRUCTIBLE_TRACK)
          && _modifyType == RIDE_MODIFY_DEMOLISH)
-        && !gCheatsMakeAllDestructible)
+        && !GetGameState().Cheats.MakeAllDestructible)
     {
         return GameActions::Result(
             GameActions::Status::NoClearance, STR_CANT_DEMOLISH_RIDE,
@@ -105,8 +105,8 @@ GameActions::Result RideDemolishAction::Execute() const
     auto ride = GetRide(_rideIndex);
     if (ride == nullptr)
     {
-        LOG_WARNING("Invalid game command for ride %u", _rideIndex.ToUnderlying());
-        return GameActions::Result(GameActions::Status::InvalidParameters, STR_CANT_DEMOLISH_RIDE, STR_NONE);
+        LOG_ERROR("Ride not found for rideIndex %u", _rideIndex.ToUnderlying());
+        return GameActions::Result(GameActions::Status::InvalidParameters, STR_CANT_DEMOLISH_RIDE, STR_ERR_RIDE_NOT_FOUND);
     }
 
     switch (_modifyType)
@@ -115,9 +115,10 @@ GameActions::Result RideDemolishAction::Execute() const
             return DemolishRide(*ride);
         case RIDE_MODIFY_RENEW:
             return RefurbishRide(*ride);
+        default:
+            LOG_ERROR("Unknown ride demolish type %d", _modifyType);
+            return GameActions::Result(GameActions::Status::InvalidParameters, STR_CANT_DO_THIS, STR_ERR_VALUE_OUT_OF_RANGE);
     }
-
-    return GameActions::Result(GameActions::Status::InvalidParameters, STR_CANT_DO_THIS, STR_NONE);
 }
 
 GameActions::Result RideDemolishAction::DemolishRide(Ride& ride) const
@@ -155,7 +156,7 @@ GameActions::Result RideDemolishAction::DemolishRide(Ride& ride) const
     }
 
     ride.Delete();
-    gParkValue = GetContext()->GetGameState()->GetPark().CalculateParkValue();
+    GetGameState().ParkValue = GetContext()->GetGameState()->GetPark().CalculateParkValue();
 
     // Close windows related to the demolished ride
     WindowCloseByNumber(WindowClass::RideConstruction, rideId.ToUnderlying());
@@ -186,7 +187,7 @@ money64 RideDemolishAction::MazeRemoveTrack(const CoordsXYZD& coords) const
         return execRes.Cost;
     }
 
-    return MONEY64_UNDEFINED;
+    return kMoney64Undefined;
 }
 
 money64 RideDemolishAction::DemolishTracks() const
@@ -195,10 +196,11 @@ money64 RideDemolishAction::DemolishTracks() const
 
     uint8_t oldpaused = gGamePaused;
     gGamePaused = 0;
+    auto& gameState = GetGameState();
 
-    for (TileCoordsXY tilePos = {}; tilePos.x < gMapSize.x; ++tilePos.x)
+    for (TileCoordsXY tilePos = {}; tilePos.x < gameState.MapSize.x; ++tilePos.x)
     {
-        for (tilePos.y = 0; tilePos.y < gMapSize.y; ++tilePos.y)
+        for (tilePos.y = 0; tilePos.y < gameState.MapSize.y; ++tilePos.y)
         {
             const auto tileCoords = tilePos.ToCoordsXY();
             // Loop over all elements of the tile until there are no more items to remove
@@ -249,7 +251,7 @@ money64 RideDemolishAction::DemolishTracks() const
                     {
                         const CoordsXYZ off = { DirOffsets[dir], 0 };
                         money64 removePrice = MazeRemoveTrack({ location + off, dir });
-                        if (removePrice != MONEY64_UNDEFINED)
+                        if (removePrice != kMoney64Undefined)
                         {
                             refundPrice += removePrice;
                         }
