@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2023 OpenRCT2 developers
+ * Copyright (c) 2014-2024 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -53,8 +53,8 @@ GameActions::Result RideSetAppearanceAction::Query() const
     auto ride = GetRide(_rideIndex);
     if (ride == nullptr)
     {
-        LOG_WARNING("Invalid game command, ride_id = %u", _rideIndex.ToUnderlying());
-        return GameActions::Result(GameActions::Status::InvalidParameters, STR_NONE, STR_NONE);
+        LOG_ERROR("Ride not found for rideIndex %u", _rideIndex.ToUnderlying());
+        return GameActions::Result(GameActions::Status::InvalidParameters, STR_ERR_INVALID_PARAMETER, STR_ERR_RIDE_NOT_FOUND);
     }
 
     switch (_type)
@@ -64,17 +64,19 @@ GameActions::Result RideSetAppearanceAction::Query() const
         case RideSetAppearanceType::TrackColourSupports:
             if (_index >= std::size(ride->track_colour))
             {
-                LOG_WARNING("Invalid game command, index %d out of bounds", _index);
-                return GameActions::Result(GameActions::Status::InvalidParameters, STR_NONE, STR_NONE);
+                LOG_ERROR("Invalid track colour %u", _index);
+                return GameActions::Result(
+                    GameActions::Status::InvalidParameters, STR_ERR_INVALID_PARAMETER, STR_ERR_INVALID_COLOUR);
             }
             break;
         case RideSetAppearanceType::VehicleColourBody:
         case RideSetAppearanceType::VehicleColourTrim:
-        case RideSetAppearanceType::VehicleColourTernary:
+        case RideSetAppearanceType::VehicleColourTertiary:
             if (_index >= std::size(ride->vehicle_colours))
             {
-                LOG_WARNING("Invalid game command, index %d out of bounds", _index);
-                return GameActions::Result(GameActions::Status::InvalidParameters, STR_NONE, STR_NONE);
+                LOG_ERROR("Invalid vehicle colour %u", _index);
+                return GameActions::Result(
+                    GameActions::Status::InvalidParameters, STR_ERR_INVALID_PARAMETER, STR_ERR_INVALID_COLOUR);
             }
             break;
         case RideSetAppearanceType::VehicleColourScheme:
@@ -82,8 +84,9 @@ GameActions::Result RideSetAppearanceAction::Query() const
         case RideSetAppearanceType::SellingItemColourIsRandom:
             break;
         default:
-            LOG_WARNING("Invalid game command, type %d not recognised", _type);
-            return GameActions::Result(GameActions::Status::InvalidParameters, STR_NONE, STR_NONE);
+            LOG_ERROR("Invalid ride appearance type %u", _type);
+            return GameActions::Result(
+                GameActions::Status::InvalidParameters, STR_ERR_INVALID_PARAMETER, STR_ERR_VALUE_OUT_OF_RANGE);
     }
 
     return GameActions::Result();
@@ -94,8 +97,8 @@ GameActions::Result RideSetAppearanceAction::Execute() const
     auto ride = GetRide(_rideIndex);
     if (ride == nullptr)
     {
-        LOG_WARNING("Invalid game command, ride_id = %u", _rideIndex.ToUnderlying());
-        return GameActions::Result(GameActions::Status::InvalidParameters, STR_NONE, STR_NONE);
+        LOG_ERROR("Ride not found for rideIndex %u", _rideIndex.ToUnderlying());
+        return GameActions::Result(GameActions::Status::InvalidParameters, STR_ERR_INVALID_PARAMETER, STR_ERR_RIDE_NOT_FOUND);
     }
 
     switch (_type)
@@ -120,7 +123,7 @@ GameActions::Result RideSetAppearanceAction::Execute() const
             ride->vehicle_colours[_index].Trim = _value;
             RideUpdateVehicleColours(*ride);
             break;
-        case RideSetAppearanceType::VehicleColourTernary:
+        case RideSetAppearanceType::VehicleColourTertiary:
             ride->vehicle_colours[_index].Tertiary = _value;
             RideUpdateVehicleColours(*ride);
             break;
