@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2023 OpenRCT2 developers
+ * Copyright (c) 2014-2024 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -9,6 +9,7 @@
 
 #include "ScenarioSetSettingAction.h"
 
+#include "../GameState.h"
 #include "../OpenRCT2.h"
 #include "../entity/Peep.h"
 #include "../interface/Window.h"
@@ -19,6 +20,8 @@
 
 #include <algorithm>
 
+using namespace OpenRCT2;
+
 void ScenarioSetSettingAction::Serialise(DataSerialiser& stream)
 {
     GameAction::Serialise(stream);
@@ -36,8 +39,9 @@ GameActions::Result ScenarioSetSettingAction::Query() const
 {
     if (_setting >= ScenarioSetSetting::Count)
     {
-        LOG_ERROR("Invalid setting: %u", _setting);
-        return GameActions::Result(GameActions::Status::InvalidParameters, STR_NONE, STR_NONE);
+        LOG_ERROR("Invalid scenario setting: %u", _setting);
+        return GameActions::Result(
+            GameActions::Status::InvalidParameters, STR_ERR_INVALID_PARAMETER, STR_ERR_VALUE_OUT_OF_RANGE);
     }
 
     return GameActions::Result();
@@ -45,6 +49,7 @@ GameActions::Result ScenarioSetSettingAction::Query() const
 
 GameActions::Result ScenarioSetSettingAction::Execute() const
 {
+    auto& gameState = GetGameState();
     switch (_setting)
     {
         case ScenarioSetSetting::NoMoney:
@@ -52,22 +57,22 @@ GameActions::Result ScenarioSetSettingAction::Execute() const
             {
                 if (_value != 0)
                 {
-                    gParkFlags |= PARK_FLAGS_NO_MONEY;
+                    gameState.ParkFlags |= PARK_FLAGS_NO_MONEY;
                 }
                 else
                 {
-                    gParkFlags &= ~PARK_FLAGS_NO_MONEY;
+                    gameState.ParkFlags &= ~PARK_FLAGS_NO_MONEY;
                 }
             }
             else
             {
                 if (_value != 0)
                 {
-                    gParkFlags |= PARK_FLAGS_NO_MONEY;
+                    gameState.ParkFlags |= PARK_FLAGS_NO_MONEY;
                 }
                 else
                 {
-                    gParkFlags &= ~PARK_FLAGS_NO_MONEY;
+                    gameState.ParkFlags &= ~PARK_FLAGS_NO_MONEY;
                 }
                 // Invalidate all windows that have anything to do with finance
                 WindowInvalidateByClass(WindowClass::Ride);
@@ -79,168 +84,168 @@ GameActions::Result ScenarioSetSettingAction::Execute() const
             }
             break;
         case ScenarioSetSetting::InitialCash:
-            gInitialCash = std::clamp<money64>(_value, 0.00_GBP, 1000000.00_GBP);
-            gCash = gInitialCash;
+            gameState.InitialCash = std::clamp<money64>(_value, 0.00_GBP, 1000000.00_GBP);
+            gameState.Cash = gameState.InitialCash;
             WindowInvalidateByClass(WindowClass::Finances);
             WindowInvalidateByClass(WindowClass::BottomToolbar);
             break;
         case ScenarioSetSetting::InitialLoan:
-            gBankLoan = std::clamp<money64>(_value, 0.00_GBP, 5000000.00_GBP);
-            gMaxBankLoan = std::max(gBankLoan, gMaxBankLoan);
+            gameState.BankLoan = std::clamp<money64>(_value, 0.00_GBP, 5000000.00_GBP);
+            gameState.MaxBankLoan = std::max(gameState.BankLoan, gameState.MaxBankLoan);
             WindowInvalidateByClass(WindowClass::Finances);
             break;
         case ScenarioSetSetting::MaximumLoanSize:
-            gMaxBankLoan = std::clamp<money64>(_value, 0.00_GBP, 5000000.00_GBP);
-            gBankLoan = std::min(gBankLoan, gMaxBankLoan);
+            gameState.MaxBankLoan = std::clamp<money64>(_value, 0.00_GBP, 5000000.00_GBP);
+            gameState.BankLoan = std::min(gameState.BankLoan, gameState.MaxBankLoan);
             WindowInvalidateByClass(WindowClass::Finances);
             break;
         case ScenarioSetSetting::AnnualInterestRate:
-            gBankLoanInterestRate = std::clamp<uint8_t>(_value, 0, MaxBankLoanInterestRate);
+            gameState.BankLoanInterestRate = std::clamp<uint8_t>(_value, 0, MaxBankLoanInterestRate);
             WindowInvalidateByClass(WindowClass::Finances);
             break;
         case ScenarioSetSetting::ForbidMarketingCampaigns:
             if (_value != 0)
             {
-                gParkFlags |= PARK_FLAGS_FORBID_MARKETING_CAMPAIGN;
+                gameState.ParkFlags |= PARK_FLAGS_FORBID_MARKETING_CAMPAIGN;
             }
             else
             {
-                gParkFlags &= ~PARK_FLAGS_FORBID_MARKETING_CAMPAIGN;
+                gameState.ParkFlags &= ~PARK_FLAGS_FORBID_MARKETING_CAMPAIGN;
             }
             break;
         case ScenarioSetSetting::AverageCashPerGuest:
-            gGuestInitialCash = std::clamp<money64>(_value, 0.00_GBP, 1000.00_GBP);
+            gameState.GuestInitialCash = std::clamp<money64>(_value, 0.00_GBP, 1000.00_GBP);
             break;
         case ScenarioSetSetting::GuestInitialHappiness:
-            gGuestInitialHappiness = std::clamp<uint8_t>(_value, 40, 250);
+            gameState.GuestInitialHappiness = std::clamp<uint8_t>(_value, 40, 250);
             break;
         case ScenarioSetSetting::GuestInitialHunger:
-            gGuestInitialHunger = std::clamp<uint8_t>(_value, 40, 250);
+            gameState.GuestInitialHunger = std::clamp<uint8_t>(_value, 40, 250);
             break;
         case ScenarioSetSetting::GuestInitialThirst:
-            gGuestInitialThirst = std::clamp<uint8_t>(_value, 40, 250);
+            gameState.GuestInitialThirst = std::clamp<uint8_t>(_value, 40, 250);
             break;
         case ScenarioSetSetting::GuestsPreferLessIntenseRides:
             if (_value != 0)
             {
-                gParkFlags |= PARK_FLAGS_PREF_LESS_INTENSE_RIDES;
+                gameState.ParkFlags |= PARK_FLAGS_PREF_LESS_INTENSE_RIDES;
             }
             else
             {
-                gParkFlags &= ~PARK_FLAGS_PREF_LESS_INTENSE_RIDES;
+                gameState.ParkFlags &= ~PARK_FLAGS_PREF_LESS_INTENSE_RIDES;
             }
             break;
         case ScenarioSetSetting::GuestsPreferMoreIntenseRides:
             if (_value != 0)
             {
-                gParkFlags |= PARK_FLAGS_PREF_MORE_INTENSE_RIDES;
+                gameState.ParkFlags |= PARK_FLAGS_PREF_MORE_INTENSE_RIDES;
             }
             else
             {
-                gParkFlags &= ~PARK_FLAGS_PREF_MORE_INTENSE_RIDES;
+                gameState.ParkFlags &= ~PARK_FLAGS_PREF_MORE_INTENSE_RIDES;
             }
             break;
         case ScenarioSetSetting::CostToBuyLand:
-            gLandPrice = std::clamp<money64>(_value, 5.00_GBP, 200.00_GBP);
+            gameState.LandPrice = std::clamp<money64>(_value, 5.00_GBP, 200.00_GBP);
             break;
         case ScenarioSetSetting::CostToBuyConstructionRights:
-            gConstructionRightsPrice = std::clamp<money64>(_value, 5.00_GBP, 200.00_GBP);
+            gameState.ConstructionRightsPrice = std::clamp<money64>(_value, 5.00_GBP, 200.00_GBP);
             break;
         case ScenarioSetSetting::ParkChargeMethod:
             if (gScreenFlags & SCREEN_FLAGS_SCENARIO_EDITOR)
             {
                 if (_value == 0)
                 {
-                    gParkFlags |= PARK_FLAGS_PARK_FREE_ENTRY;
-                    gParkFlags &= ~PARK_FLAGS_UNLOCK_ALL_PRICES;
-                    gParkEntranceFee = 0.00_GBP;
+                    gameState.ParkFlags |= PARK_FLAGS_PARK_FREE_ENTRY;
+                    gameState.ParkFlags &= ~PARK_FLAGS_UNLOCK_ALL_PRICES;
+                    gameState.ParkEntranceFee = 0.00_GBP;
                 }
                 else if (_value == 1)
                 {
-                    gParkFlags &= ~PARK_FLAGS_PARK_FREE_ENTRY;
-                    gParkFlags &= ~PARK_FLAGS_UNLOCK_ALL_PRICES;
-                    gParkEntranceFee = 10.00_GBP;
+                    gameState.ParkFlags &= ~PARK_FLAGS_PARK_FREE_ENTRY;
+                    gameState.ParkFlags &= ~PARK_FLAGS_UNLOCK_ALL_PRICES;
+                    gameState.ParkEntranceFee = 10.00_GBP;
                 }
                 else
                 {
-                    gParkFlags |= PARK_FLAGS_PARK_FREE_ENTRY;
-                    gParkFlags |= PARK_FLAGS_UNLOCK_ALL_PRICES;
-                    gParkEntranceFee = 10.00_GBP;
+                    gameState.ParkFlags |= PARK_FLAGS_PARK_FREE_ENTRY;
+                    gameState.ParkFlags |= PARK_FLAGS_UNLOCK_ALL_PRICES;
+                    gameState.ParkEntranceFee = 10.00_GBP;
                 }
             }
             else
             {
                 if (_value == 0)
                 {
-                    gParkFlags |= PARK_FLAGS_PARK_FREE_ENTRY;
-                    gParkFlags &= ~PARK_FLAGS_UNLOCK_ALL_PRICES;
+                    gameState.ParkFlags |= PARK_FLAGS_PARK_FREE_ENTRY;
+                    gameState.ParkFlags &= ~PARK_FLAGS_UNLOCK_ALL_PRICES;
                 }
                 else if (_value == 1)
                 {
-                    gParkFlags &= ~PARK_FLAGS_PARK_FREE_ENTRY;
-                    gParkFlags &= ~PARK_FLAGS_UNLOCK_ALL_PRICES;
+                    gameState.ParkFlags &= ~PARK_FLAGS_PARK_FREE_ENTRY;
+                    gameState.ParkFlags &= ~PARK_FLAGS_UNLOCK_ALL_PRICES;
                 }
                 else
                 {
-                    gParkFlags |= PARK_FLAGS_PARK_FREE_ENTRY;
-                    gParkFlags |= PARK_FLAGS_UNLOCK_ALL_PRICES;
+                    gameState.ParkFlags |= PARK_FLAGS_PARK_FREE_ENTRY;
+                    gameState.ParkFlags |= PARK_FLAGS_UNLOCK_ALL_PRICES;
                 }
                 WindowInvalidateByClass(WindowClass::ParkInformation);
                 WindowInvalidateByClass(WindowClass::Ride);
             }
             break;
         case ScenarioSetSetting::ParkChargeEntryFee:
-            gParkEntranceFee = std::clamp<money64>(_value, 0.00_GBP, MAX_ENTRANCE_FEE);
+            gameState.ParkEntranceFee = std::clamp<money64>(_value, 0.00_GBP, MAX_ENTRANCE_FEE);
             WindowInvalidateByClass(WindowClass::ParkInformation);
             break;
         case ScenarioSetSetting::ForbidTreeRemoval:
             if (_value != 0)
             {
-                gParkFlags |= PARK_FLAGS_FORBID_TREE_REMOVAL;
+                gameState.ParkFlags |= PARK_FLAGS_FORBID_TREE_REMOVAL;
             }
             else
             {
-                gParkFlags &= ~PARK_FLAGS_FORBID_TREE_REMOVAL;
+                gameState.ParkFlags &= ~PARK_FLAGS_FORBID_TREE_REMOVAL;
             }
             break;
         case ScenarioSetSetting::ForbidLandscapeChanges:
             if (_value != 0)
             {
-                gParkFlags |= PARK_FLAGS_FORBID_LANDSCAPE_CHANGES;
+                gameState.ParkFlags |= PARK_FLAGS_FORBID_LANDSCAPE_CHANGES;
             }
             else
             {
-                gParkFlags &= ~PARK_FLAGS_FORBID_LANDSCAPE_CHANGES;
+                gameState.ParkFlags &= ~PARK_FLAGS_FORBID_LANDSCAPE_CHANGES;
             }
             break;
         case ScenarioSetSetting::ForbidHighConstruction:
             if (_value != 0)
             {
-                gParkFlags |= PARK_FLAGS_FORBID_HIGH_CONSTRUCTION;
+                gameState.ParkFlags |= PARK_FLAGS_FORBID_HIGH_CONSTRUCTION;
             }
             else
             {
-                gParkFlags &= ~PARK_FLAGS_FORBID_HIGH_CONSTRUCTION;
+                gameState.ParkFlags &= ~PARK_FLAGS_FORBID_HIGH_CONSTRUCTION;
             }
             break;
         case ScenarioSetSetting::ParkRatingHigherDifficultyLevel:
             if (_value != 0)
             {
-                gParkFlags |= PARK_FLAGS_DIFFICULT_PARK_RATING;
+                gameState.ParkFlags |= PARK_FLAGS_DIFFICULT_PARK_RATING;
             }
             else
             {
-                gParkFlags &= ~PARK_FLAGS_DIFFICULT_PARK_RATING;
+                gameState.ParkFlags &= ~PARK_FLAGS_DIFFICULT_PARK_RATING;
             }
             break;
         case ScenarioSetSetting::GuestGenerationHigherDifficultyLevel:
             if (_value != 0)
             {
-                gParkFlags |= PARK_FLAGS_DIFFICULT_GUEST_GENERATION;
+                gameState.ParkFlags |= PARK_FLAGS_DIFFICULT_GUEST_GENERATION;
             }
             else
             {
-                gParkFlags &= ~PARK_FLAGS_DIFFICULT_GUEST_GENERATION;
+                gameState.ParkFlags &= ~PARK_FLAGS_DIFFICULT_GUEST_GENERATION;
             }
             break;
         case ScenarioSetSetting::AllowEarlyCompletion:
@@ -250,17 +255,18 @@ GameActions::Result ScenarioSetSettingAction::Execute() const
         {
             if (_value != 0)
             {
-                gParkFlags |= PARK_FLAGS_RCT1_INTEREST;
+                gameState.ParkFlags |= PARK_FLAGS_RCT1_INTEREST;
             }
             else
             {
-                gParkFlags &= ~PARK_FLAGS_RCT1_INTEREST;
+                gameState.ParkFlags &= ~PARK_FLAGS_RCT1_INTEREST;
             }
             break;
         }
         default:
-            LOG_ERROR("Invalid setting: %u", _setting);
-            return GameActions::Result(GameActions::Status::InvalidParameters, STR_NONE, STR_NONE);
+            LOG_ERROR("Invalid scenario setting %u", _setting);
+            return GameActions::Result(
+                GameActions::Status::InvalidParameters, STR_ERR_INVALID_PARAMETER, STR_ERR_VALUE_OUT_OF_RANGE);
     }
     WindowInvalidateByClass(WindowClass::EditorScenarioOptions);
     return GameActions::Result();
