@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2023 OpenRCT2 developers
+ * Copyright (c) 2014-2024 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -11,6 +11,7 @@
 
 #include "../Cheats.h"
 #include "../Context.h"
+#include "../GameState.h"
 #include "../core/MemoryStream.h"
 #include "../drawing/Drawing.h"
 #include "../entity/EntityRegistry.h"
@@ -28,6 +29,8 @@
 
 #include <set>
 
+using namespace OpenRCT2;
+
 /* rct2: 0x009929FC */
 static constexpr PeepSpriteType spriteTypes[] = {
     PeepSpriteType::Handyman,
@@ -82,10 +85,8 @@ GameActions::Result StaffHireNewAction::QueryExecute(bool execute) const
 
     if (_staffType >= static_cast<uint8_t>(StaffType::Count))
     {
-        // Invalid staff type.
-        LOG_ERROR("Tried to use invalid staff type: %u", static_cast<uint32_t>(_staffType));
-
-        return GameActions::Result(GameActions::Status::InvalidParameters, STR_CANT_HIRE_NEW_STAFF, STR_NONE);
+        LOG_ERROR("Invalid staff type %u", static_cast<uint32_t>(_staffType));
+        return GameActions::Result(GameActions::Status::InvalidParameters, STR_CANT_HIRE_NEW_STAFF, STR_ERR_VALUE_OUT_OF_RANGE);
     }
 
     if (GetNumFreeEntities() < 400)
@@ -97,19 +98,17 @@ GameActions::Result StaffHireNewAction::QueryExecute(bool execute) const
     {
         if (static_cast<uint8_t>(_entertainerType) >= static_cast<uint8_t>(EntertainerCostume::Count))
         {
-            // Invalid entertainer costume
-            LOG_ERROR("Tried to use invalid entertainer type: %u", static_cast<uint32_t>(_entertainerType));
-
-            return GameActions::Result(GameActions::Status::InvalidParameters, STR_CANT_HIRE_NEW_STAFF, STR_NONE);
+            LOG_ERROR("Invalid entertainer type %u", static_cast<uint32_t>(_entertainerType));
+            return GameActions::Result(
+                GameActions::Status::InvalidParameters, STR_CANT_HIRE_NEW_STAFF, STR_ERR_VALUE_OUT_OF_RANGE);
         }
 
         uint32_t availableCostumes = StaffGetAvailableEntertainerCostumes();
         if (!(availableCostumes & (1 << static_cast<uint8_t>(_entertainerType))))
         {
-            // Entertainer costume unavailable
-            LOG_ERROR("Tried to use unavailable entertainer type: %u", static_cast<uint32_t>(_entertainerType));
-
-            return GameActions::Result(GameActions::Status::InvalidParameters, STR_CANT_HIRE_NEW_STAFF, STR_NONE);
+            LOG_ERROR("Unavailable entertainer costume %u", static_cast<uint32_t>(_entertainerType));
+            return GameActions::Result(
+                GameActions::Status::InvalidParameters, STR_CANT_HIRE_NEW_STAFF, STR_ERR_VALUE_OUT_OF_RANGE);
         }
     }
 
@@ -201,21 +200,21 @@ GameActions::Result StaffHireNewAction::QueryExecute(bool execute) const
         newPeep->TrousersColour = colour;
 
         // Staff energy determines their walking speed
-        switch (gCheatsSelectedStaffSpeed)
+        switch (GetGameState().Cheats.SelectedStaffSpeed)
         {
             case StaffSpeedCheat::None:
-                newPeep->Energy = CHEATS_STAFF_NORMAL_SPEED;
-                newPeep->EnergyTarget = CHEATS_STAFF_NORMAL_SPEED;
+                newPeep->Energy = kCheatsStaffNormalSpeed;
+                newPeep->EnergyTarget = kCheatsStaffNormalSpeed;
                 break;
 
             case StaffSpeedCheat::Frozen:
-                newPeep->Energy = CHEATS_STAFF_FREEZE_SPEED;
-                newPeep->EnergyTarget = CHEATS_STAFF_FREEZE_SPEED;
+                newPeep->Energy = kCheatsStaffFreezeSpeed;
+                newPeep->EnergyTarget = kCheatsStaffFreezeSpeed;
                 break;
 
             case StaffSpeedCheat::Fast:
-                newPeep->Energy = CHEATS_STAFF_FAST_SPEED;
-                newPeep->EnergyTarget = CHEATS_STAFF_FAST_SPEED;
+                newPeep->Energy = kCheatsStaffFastSpeed;
+                newPeep->EnergyTarget = kCheatsStaffFastSpeed;
                 break;
         }
 
@@ -288,10 +287,11 @@ void StaffHireNewAction::AutoPositionNewStaff(Peep* newPeep) const
     else
     {
         // No walking guests; pick random park entrance
-        if (!gParkEntrances.empty())
+        const auto& gameState = GetGameState();
+        if (!gameState.ParkEntrances.empty())
         {
-            auto rand = ScenarioRandMax(static_cast<uint32_t>(gParkEntrances.size()));
-            const auto& entrance = gParkEntrances[rand];
+            auto rand = ScenarioRandMax(static_cast<uint32_t>(gameState.ParkEntrances.size()));
+            const auto& entrance = gameState.ParkEntrances[rand];
             auto dir = entrance.direction;
             newLocation = entrance;
             // TODO: Replace with CoordsDirectionDelta
