@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2023 OpenRCT2 developers
+ * Copyright (c) 2014-2024 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -9,6 +9,7 @@
 
 #include "TrackRemoveAction.h"
 
+#include "../GameState.h"
 #include "../management/Finance.h"
 #include "../ride/RideData.h"
 #include "../ride/Track.h"
@@ -19,6 +20,7 @@
 #include "../world/Surface.h"
 #include "RideSetSettingAction.h"
 
+using namespace OpenRCT2;
 using namespace OpenRCT2::TrackMetaData;
 
 TrackRemoveAction::TrackRemoveAction(track_type_t trackType, int32_t sequence, const CoordsXYZD& origin)
@@ -108,10 +110,11 @@ GameActions::Result TrackRemoveAction::Query() const
 
     if (!found)
     {
-        LOG_WARNING(
+        LOG_ERROR(
             "Track Element not found. x = %d, y = %d, z = %d, d = %d, seq = %d.", _origin.x, _origin.y, _origin.z,
             _origin.direction, _sequence);
-        return GameActions::Result(GameActions::Status::InvalidParameters, STR_RIDE_CONSTRUCTION_CANT_REMOVE_THIS, STR_NONE);
+        return GameActions::Result(
+            GameActions::Status::InvalidParameters, STR_RIDE_CONSTRUCTION_CANT_REMOVE_THIS, STR_ERR_TRACK_ELEMENT_NOT_FOUND);
     }
 
     if (tileElement->AsTrack()->IsIndestructible())
@@ -127,22 +130,25 @@ GameActions::Result TrackRemoveAction::Query() const
     auto ride = GetRide(rideIndex);
     if (ride == nullptr)
     {
-        LOG_WARNING("Ride not found. ride index = %d.", rideIndex);
-        return GameActions::Result(GameActions::Status::InvalidParameters, STR_RIDE_CONSTRUCTION_CANT_REMOVE_THIS, STR_NONE);
+        LOG_ERROR("Ride not found for rideIndex %d.", rideIndex);
+        return GameActions::Result(
+            GameActions::Status::InvalidParameters, STR_RIDE_CONSTRUCTION_CANT_REMOVE_THIS, STR_ERR_RIDE_NOT_FOUND);
     }
 
     if (ride->type >= RIDE_TYPE_COUNT)
     {
-        LOG_WARNING("Ride type not found. ride type = %d.", ride->type);
-        return GameActions::Result(GameActions::Status::InvalidParameters, STR_RIDE_CONSTRUCTION_CANT_REMOVE_THIS, STR_NONE);
+        LOG_ERROR("Ride type not found. ride type = %d.", ride->type);
+        return GameActions::Result(
+            GameActions::Status::InvalidParameters, STR_RIDE_CONSTRUCTION_CANT_REMOVE_THIS, STR_ERR_VALUE_OUT_OF_RANGE);
     }
     const auto& ted = GetTrackElementDescriptor(trackType);
     auto sequenceIndex = tileElement->AsTrack()->GetSequenceIndex();
     const PreviewTrack* trackBlock = ted.GetBlockForSequence(sequenceIndex);
     if (trackBlock == nullptr)
     {
-        LOG_WARNING("Track block %d not found for track type %d.", sequenceIndex, trackType);
-        return GameActions::Result(GameActions::Status::InvalidParameters, STR_RIDE_CONSTRUCTION_CANT_REMOVE_THIS, STR_NONE);
+        LOG_ERROR("Track block %d not found for track type %d.", sequenceIndex, trackType);
+        return GameActions::Result(
+            GameActions::Status::InvalidParameters, STR_RIDE_CONSTRUCTION_CANT_REMOVE_THIS, STR_ERR_TRACK_BLOCK_NOT_FOUND);
     }
 
     auto startLoc = _origin;
@@ -167,7 +173,7 @@ GameActions::Result TrackRemoveAction::Query() const
         if (!LocationValid(mapLoc))
         {
             return GameActions::Result(
-                GameActions::Status::NotOwned, STR_RIDE_CONSTRUCTION_CANT_REMOVE_THIS, STR_LAND_NOT_OWNED_BY_PARK);
+                GameActions::Status::InvalidParameters, STR_RIDE_CONSTRUCTION_CANT_REMOVE_THIS, STR_OFF_EDGE_OF_MAP);
         }
         MapInvalidateTileFull(mapLoc);
 
@@ -202,10 +208,11 @@ GameActions::Result TrackRemoveAction::Query() const
 
         if (!found)
         {
-            LOG_WARNING(
+            LOG_ERROR(
                 "Track Element not found. x = %d, y = %d, z = %d, d = %d, seq = %d.", mapLoc.x, mapLoc.y, mapLoc.z,
                 _origin.direction, trackBlock->index);
-            return GameActions::Result(GameActions::Status::Unknown, STR_RIDE_CONSTRUCTION_CANT_REMOVE_THIS, STR_NONE);
+            return GameActions::Result(
+                GameActions::Status::Unknown, STR_RIDE_CONSTRUCTION_CANT_REMOVE_THIS, STR_ERR_TRACK_ELEMENT_NOT_FOUND);
         }
 
         int32_t entranceDirections = std::get<0>(ted.SequenceProperties);
@@ -222,8 +229,9 @@ GameActions::Result TrackRemoveAction::Query() const
         auto* surfaceElement = MapGetSurfaceElementAt(mapLoc);
         if (surfaceElement == nullptr)
         {
-            LOG_WARNING("Surface Element not found. x = %d, y = %d", mapLoc.x, mapLoc.y);
-            return GameActions::Result(GameActions::Status::Unknown, STR_RIDE_CONSTRUCTION_CANT_REMOVE_THIS, STR_NONE);
+            LOG_ERROR("Surface Element not found. x = %d, y = %d", mapLoc.x, mapLoc.y);
+            return GameActions::Result(
+                GameActions::Status::Unknown, STR_RIDE_CONSTRUCTION_CANT_REMOVE_THIS, STR_ERR_SURFACE_ELEMENT_NOT_FOUND);
         }
 
         int8_t _support_height = tileElement->BaseHeight - surfaceElement->BaseHeight;
@@ -309,10 +317,11 @@ GameActions::Result TrackRemoveAction::Execute() const
 
     if (!found)
     {
-        LOG_WARNING(
+        LOG_ERROR(
             "Track Element not found. x = %d, y = %d, z = %d, d = %d, seq = %d.", _origin.x, _origin.y, _origin.z,
             _origin.direction, _sequence);
-        return GameActions::Result(GameActions::Status::InvalidParameters, STR_RIDE_CONSTRUCTION_CANT_REMOVE_THIS, STR_NONE);
+        return GameActions::Result(
+            GameActions::Status::InvalidParameters, STR_RIDE_CONSTRUCTION_CANT_REMOVE_THIS, STR_ERR_TRACK_ELEMENT_NOT_FOUND);
     }
 
     RideId rideIndex = tileElement->AsTrack()->GetRideIndex();
@@ -322,16 +331,18 @@ GameActions::Result TrackRemoveAction::Execute() const
     auto ride = GetRide(rideIndex);
     if (ride == nullptr)
     {
-        LOG_WARNING("Ride not found. ride index = %d.", rideIndex);
-        return GameActions::Result(GameActions::Status::InvalidParameters, STR_RIDE_CONSTRUCTION_CANT_REMOVE_THIS, STR_NONE);
+        LOG_ERROR("Ride not found. ride index = %d.", rideIndex);
+        return GameActions::Result(
+            GameActions::Status::InvalidParameters, STR_RIDE_CONSTRUCTION_CANT_REMOVE_THIS, STR_ERR_RIDE_NOT_FOUND);
     }
     const auto& ted = GetTrackElementDescriptor(trackType);
     auto sequenceIndex = tileElement->AsTrack()->GetSequenceIndex();
     const PreviewTrack* trackBlock = ted.GetBlockForSequence(sequenceIndex);
     if (trackBlock == nullptr)
     {
-        LOG_WARNING("Track block %d not found for track type %d.", sequenceIndex, trackType);
-        return GameActions::Result(GameActions::Status::InvalidParameters, STR_RIDE_CONSTRUCTION_CANT_REMOVE_THIS, STR_NONE);
+        LOG_ERROR("Track block %d not found for track type %d.", sequenceIndex, trackType);
+        return GameActions::Result(
+            GameActions::Status::InvalidParameters, STR_RIDE_CONSTRUCTION_CANT_REMOVE_THIS, STR_ERR_TRACK_BLOCK_NOT_FOUND);
     }
 
     auto startLoc = _origin;
@@ -386,10 +397,11 @@ GameActions::Result TrackRemoveAction::Execute() const
 
         if (!found)
         {
-            LOG_WARNING(
+            LOG_ERROR(
                 "Track Element not found. x = %d, y = %d, z = %d, d = %d, seq = %d.", mapLoc.x, mapLoc.y, mapLoc.z,
                 _origin.direction, trackBlock->index);
-            return GameActions::Result(GameActions::Status::Unknown, STR_RIDE_CONSTRUCTION_CANT_REMOVE_THIS, STR_NONE);
+            return GameActions::Result(
+                GameActions::Status::Unknown, STR_RIDE_CONSTRUCTION_CANT_REMOVE_THIS, STR_ERR_TRACK_ELEMENT_NOT_FOUND);
         }
 
         int32_t entranceDirections = std::get<0>(ted.SequenceProperties);
@@ -406,8 +418,9 @@ GameActions::Result TrackRemoveAction::Execute() const
         auto* surfaceElement = MapGetSurfaceElementAt(mapLoc);
         if (surfaceElement == nullptr)
         {
-            LOG_WARNING("Surface Element not found. x = %d, y = %d", mapLoc.x, mapLoc.y);
-            return GameActions::Result(GameActions::Status::Unknown, STR_RIDE_CONSTRUCTION_CANT_REMOVE_THIS, STR_NONE);
+            LOG_ERROR("Surface Element not found. x = %d, y = %d", mapLoc.x, mapLoc.y);
+            return GameActions::Result(
+                GameActions::Status::Unknown, STR_RIDE_CONSTRUCTION_CANT_REMOVE_THIS, STR_ERR_SURFACE_ELEMENT_NOT_FOUND);
         }
 
         int8_t _support_height = tileElement->BaseHeight - surfaceElement->BaseHeight;
@@ -440,7 +453,7 @@ GameActions::Result TrackRemoveAction::Execute() const
 
         InvalidateTestResults(*ride);
         FootpathQueueChainReset();
-        if (!gCheatsDisableClearanceChecks || !(tileElement->IsGhost()))
+        if (!GetGameState().Cheats.DisableClearanceChecks || !(tileElement->IsGhost()))
         {
             FootpathRemoveEdgesAt(mapLoc, tileElement);
         }
