@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2023 OpenRCT2 developers
+ * Copyright (c) 2014-2024 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -9,6 +9,7 @@
 
 #include "WallSetColourAction.h"
 
+#include "../GameState.h"
 #include "../OpenRCT2.h"
 #include "../management/Finance.h"
 #include "../object/WallSceneryEntry.h"
@@ -19,6 +20,8 @@
 #include "../world/Scenery.h"
 #include "../world/Surface.h"
 
+using namespace OpenRCT2;
+
 WallSetColourAction::WallSetColourAction(
     const CoordsXYZD& loc, int32_t primaryColour, int32_t secondaryColour, int32_t tertiaryColour)
     : _loc(loc)
@@ -60,10 +63,10 @@ GameActions::Result WallSetColourAction::Query() const
 
     if (!LocationValid(_loc))
     {
-        return GameActions::Result(GameActions::Status::NotOwned, STR_CANT_REPAINT_THIS, STR_LAND_NOT_OWNED_BY_PARK);
+        return GameActions::Result(GameActions::Status::InvalidParameters, STR_CANT_REPAINT_THIS, STR_OFF_EDGE_OF_MAP);
     }
 
-    if (!(gScreenFlags & SCREEN_FLAGS_SCENARIO_EDITOR) && !MapIsLocationInPark(_loc) && !gCheatsSandboxMode)
+    if (!(gScreenFlags & SCREEN_FLAGS_SCENARIO_EDITOR) && !MapIsLocationInPark(_loc) && !GetGameState().Cheats.SandboxMode)
     {
         return GameActions::Result(GameActions::Status::NotOwned, STR_CANT_REPAINT_THIS, STR_LAND_NOT_OWNED_BY_PARK);
     }
@@ -73,7 +76,8 @@ GameActions::Result WallSetColourAction::Query() const
     {
         LOG_ERROR(
             "Could not find wall element at: x = %d, y = %d, z = %d, direction = %u", _loc.x, _loc.y, _loc.z, _loc.direction);
-        return GameActions::Result(GameActions::Status::InvalidParameters, STR_CANT_REPAINT_THIS, STR_NONE);
+        return GameActions::Result(
+            GameActions::Status::InvalidParameters, STR_CANT_REPAINT_THIS, STR_ERR_WALL_ELEMENT_NOT_FOUND);
     }
 
     if ((GetFlags() & GAME_COMMAND_FLAG_GHOST) && !(wallElement->IsGhost()))
@@ -84,23 +88,23 @@ GameActions::Result WallSetColourAction::Query() const
     auto* wallEntry = wallElement->GetEntry();
     if (wallEntry == nullptr)
     {
-        LOG_ERROR("Could not find wall object");
+        LOG_ERROR(
+            "Wall element does not have wall entry at x = %d, y = %d, z = %d, direction = %u", _loc.x, _loc.y, _loc.z,
+            _loc.direction);
         return GameActions::Result(GameActions::Status::Unknown, STR_CANT_REPAINT_THIS, STR_NONE);
     }
 
     if (_primaryColour >= COLOUR_COUNT)
     {
         LOG_ERROR("Primary colour invalid: colour = %d", _primaryColour);
-        return GameActions::Result(GameActions::Status::InvalidParameters, STR_CANT_REPAINT_THIS, STR_NONE);
+        return GameActions::Result(GameActions::Status::InvalidParameters, STR_CANT_REPAINT_THIS, STR_ERR_INVALID_COLOUR);
     }
-
-    if (_secondaryColour >= COLOUR_COUNT)
+    else if (_secondaryColour >= COLOUR_COUNT)
     {
         LOG_ERROR("Secondary colour invalid: colour = %d", _secondaryColour);
-        return GameActions::Result(GameActions::Status::InvalidParameters, STR_CANT_REPAINT_THIS, STR_NONE);
+        return GameActions::Result(GameActions::Status::InvalidParameters, STR_CANT_REPAINT_THIS, STR_ERR_INVALID_COLOUR);
     }
-
-    if (wallEntry->flags & WALL_SCENERY_HAS_TERTIARY_COLOUR)
+    else if (wallEntry->flags & WALL_SCENERY_HAS_TERTIARY_COLOUR)
     {
         if (_tertiaryColour >= COLOUR_COUNT)
         {
@@ -136,7 +140,9 @@ GameActions::Result WallSetColourAction::Execute() const
     auto* wallEntry = wallElement->GetEntry();
     if (wallEntry == nullptr)
     {
-        LOG_ERROR("Could not find wall object");
+        LOG_ERROR(
+            "Wall element does not have wall entry at x = %d, y = %d, z = %d, direction = %u", _loc.x, _loc.y, _loc.z,
+            _loc.direction);
         return GameActions::Result(GameActions::Status::Unknown, STR_CANT_REPAINT_THIS, STR_NONE);
     }
 
