@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2023 OpenRCT2 developers
+ * Copyright (c) 2014-2024 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -9,12 +9,15 @@
 
 #include "WaterSetHeightAction.h"
 
+#include "../GameState.h"
 #include "../OpenRCT2.h"
 #include "../management/Finance.h"
 #include "../world/ConstructionClearance.h"
 #include "../world/Park.h"
 #include "../world/Surface.h"
 
+using namespace OpenRCT2;
+
 WaterSetHeightAction::WaterSetHeightAction(const CoordsXY& coords, uint8_t height)
     : _coords(coords)
     , _height(height)
@@ -45,8 +48,8 @@ GameActions::Result WaterSetHeightAction::Query() const
     res.Expenditure = ExpenditureType::Landscaping;
     res.Position = { _coords, _height * COORDS_Z_STEP };
 
-    if (!(gScreenFlags & SCREEN_FLAGS_SCENARIO_EDITOR) && !gCheatsSandboxMode
-        && gParkFlags & PARK_FLAGS_FORBID_LANDSCAPE_CHANGES)
+    if (!(gScreenFlags & SCREEN_FLAGS_SCENARIO_EDITOR) && !GetGameState().Cheats.SandboxMode
+        && GetGameState().ParkFlags & PARK_FLAGS_FORBID_LANDSCAPE_CHANGES)
     {
         return GameActions::Result(GameActions::Status::Disallowed, STR_NONE, STR_FORBIDDEN_BY_THE_LOCAL_AUTHORITY);
     }
@@ -62,7 +65,7 @@ GameActions::Result WaterSetHeightAction::Query() const
         return GameActions::Result(GameActions::Status::NotOwned, STR_NONE, STR_LAND_NOT_OWNED_BY_PARK);
     }
 
-    if (!(gScreenFlags & SCREEN_FLAGS_SCENARIO_EDITOR) && !gCheatsSandboxMode)
+    if (!(gScreenFlags & SCREEN_FLAGS_SCENARIO_EDITOR) && !GetGameState().Cheats.SandboxMode)
     {
         if (!MapIsLocationInPark(_coords))
         {
@@ -73,8 +76,9 @@ GameActions::Result WaterSetHeightAction::Query() const
     SurfaceElement* surfaceElement = MapGetSurfaceElementAt(_coords);
     if (surfaceElement == nullptr)
     {
-        LOG_ERROR("Could not find surface element at: x %u, y %u", _coords.x, _coords.y);
-        return GameActions::Result(GameActions::Status::Unknown, STR_NONE, STR_NONE);
+        LOG_ERROR("No surface element at: x %u, y %u", _coords.x, _coords.y);
+        return GameActions::Result(
+            GameActions::Status::InvalidParameters, STR_ERR_INVALID_PARAMETER, STR_ERR_SURFACE_ELEMENT_NOT_FOUND);
     }
 
     int32_t zHigh = surfaceElement->GetBaseZ();
@@ -96,7 +100,8 @@ GameActions::Result WaterSetHeightAction::Query() const
     }
     if (surfaceElement->HasTrackThatNeedsWater())
     {
-        return GameActions::Result(GameActions::Status::Disallowed, STR_NONE, STR_NONE);
+        return GameActions::Result(
+            GameActions::Status::Disallowed, STR_ERR_INVALID_PARAMETER, STR_ERR_TRACK_ON_THIS_TILE_NEEDS_WATER);
     }
 
     res.Cost = 250;
@@ -112,14 +117,15 @@ GameActions::Result WaterSetHeightAction::Execute() const
 
     int32_t surfaceHeight = TileElementHeight(_coords);
     FootpathRemoveLitter({ _coords, surfaceHeight });
-    if (!gCheatsDisableClearanceChecks)
+    if (!GetGameState().Cheats.DisableClearanceChecks)
         WallRemoveAtZ({ _coords, surfaceHeight });
 
     SurfaceElement* surfaceElement = MapGetSurfaceElementAt(_coords);
     if (surfaceElement == nullptr)
     {
-        LOG_ERROR("Could not find surface element at: x %u, y %u", _coords.x, _coords.y);
-        return GameActions::Result(GameActions::Status::Unknown, STR_NONE, STR_NONE);
+        LOG_ERROR("No surface element at: x %u, y %u", _coords.x, _coords.y);
+        return GameActions::Result(
+            GameActions::Status::InvalidParameters, STR_ERR_INVALID_PARAMETER, STR_ERR_SURFACE_ELEMENT_NOT_FOUND);
     }
 
     if (_height > surfaceElement->BaseHeight)
@@ -145,12 +151,12 @@ StringId WaterSetHeightAction::CheckParameters() const
         return STR_OFF_EDGE_OF_MAP;
     }
 
-    if (_height < MINIMUM_WATER_HEIGHT)
+    if (_height < kMinimumWaterHeight)
     {
         return STR_TOO_LOW;
     }
 
-    if (_height > MAXIMUM_WATER_HEIGHT)
+    if (_height > kMaximumWaterHeight)
     {
         return STR_TOO_HIGH;
     }
