@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2023 OpenRCT2 developers
+ * Copyright (c) 2014-2024 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -101,27 +101,10 @@ namespace OpenRCT2::Audio
     {
         auto& objManager = GetContext()->GetObjectManager();
 
-        Object* baseAudio{};
-
-        // We have a different audio object for RCT Classic
-        auto env = GetContext()->GetPlatformEnvironment();
-        if (env->IsUsingClassic())
+        Object* baseAudio = objManager.LoadObject(AudioObjectIdentifiers::RCT2);
+        if (baseAudio != nullptr)
         {
-            baseAudio = objManager.LoadObject(AudioObjectIdentifiers::RCTCBase);
-            if (baseAudio != nullptr)
-            {
-                _soundsAudioObjectEntryIndex = objManager.GetLoadedObjectEntryIndex(baseAudio);
-            }
-        }
-
-        if (baseAudio == nullptr)
-        {
-            // Fallback to vanilla RCT2 audio object
-            baseAudio = objManager.LoadObject(AudioObjectIdentifiers::RCT2Base);
-            if (baseAudio != nullptr)
-            {
-                _soundsAudioObjectEntryIndex = objManager.GetLoadedObjectEntryIndex(baseAudio);
-            }
+            _soundsAudioObjectEntryIndex = objManager.GetLoadedObjectEntryIndex(baseAudio);
         }
 
         objManager.LoadObject(AudioObjectIdentifiers::OpenRCT2Additional);
@@ -500,7 +483,7 @@ namespace OpenRCT2::Audio
         }
 
         mixer->Lock();
-        auto channel = mixer->Play(source, loop ? MIXER_LOOP_INFINITE : MIXER_LOOP_NONE, forget);
+        auto channel = mixer->Play(source, loop ? kMixerLoopInfinite : kMixerLoopNone, forget);
         if (channel != nullptr)
         {
             channel->SetGroup(group);
@@ -515,7 +498,7 @@ namespace OpenRCT2::Audio
 
     int32_t DStoMixerVolume(int32_t volume)
     {
-        return static_cast<int32_t>(MIXER_VOLUME_MAX * (std::pow(10.0f, static_cast<float>(volume) / 2000)));
+        return static_cast<int32_t>(kMixerVolumeMax * (std::pow(10.0f, static_cast<float>(volume) / 2000)));
     }
 
     float DStoMixerPan(int32_t pan)
