@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2023 OpenRCT2 developers
+ * Copyright (c) 2014-2024 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -130,6 +130,7 @@ namespace OpenRCT2::Audio
         CrowdAmbience,
         LiftRMC,
         TrackFrictionRMC,
+        LiftFlume,
         NoScream = 254,
         Null = 255
     };
@@ -139,7 +140,9 @@ namespace OpenRCT2::Audio
     namespace AudioObjectIdentifiers
     {
         constexpr std::string_view RCT1Title = "rct1.audio.title";
-        constexpr std::string_view RCT2Base = "rct2.audio.base";
+        // virtual name, used by either RCT2Base or RCTCBase, depending on which one is loaded.
+        constexpr std::string_view RCT2 = "rct2.audio.base";
+        constexpr std::string_view RCT2Base = "rct2.audio.base.rct2";
         constexpr std::string_view RCTCBase = "rct2.audio.base.rctc";
         constexpr std::string_view RCT2Title = "rct2.audio.title";
         constexpr std::string_view OpenRCT2Title = "openrct2.audio.title";
@@ -261,10 +264,10 @@ namespace OpenRCT2::Audio
     AudioObject* GetBaseAudioObject();
 
     std::shared_ptr<IAudioChannel> CreateAudioChannel(
-        SoundId soundId, bool loop = false, int32_t volume = MIXER_VOLUME_MAX, float pan = 0.5f, double rate = 1,
+        SoundId soundId, bool loop = false, int32_t volume = kMixerVolumeMax, float pan = 0.5f, double rate = 1,
         bool forget = false);
     std::shared_ptr<IAudioChannel> CreateAudioChannel(
-        IAudioSource* source, MixerGroup group, bool loop = false, int32_t volume = MIXER_VOLUME_MAX, float pan = 0.5f,
+        IAudioSource* source, MixerGroup group, bool loop = false, int32_t volume = kMixerVolumeMax, float pan = 0.5f,
         double rate = 1, bool forget = false);
 
     int32_t DStoMixerVolume(int32_t volume);
