@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2023 OpenRCT2 developers
+ * Copyright (c) 2014-2024 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -201,7 +201,7 @@ namespace Imaging
                 }
                 for (size_t i = 0; i < PNG_MAX_PALETTE_LENGTH; i++)
                 {
-                    const auto& entry = (*image.Palette)[static_cast<uint16_t>(i)];
+                    const auto& entry = (*image.Palette)[i];
                     png_palette[i].blue = entry.Blue;
                     png_palette[i].green = entry.Green;
                     png_palette[i].red = entry.Red;
