@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2023 OpenRCT2 developers
+ * Copyright (c) 2014-2024 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -15,6 +15,9 @@
 #include <stdexcept>
 #include <vector>
 #ifndef _WIN32
+#    ifndef __FreeBSD__
+#        include <alloca.h>
+#    endif
 #    include <unicode/ucnv.h>
 #    include <unicode/unistr.h>
 #    include <unicode/utypes.h>
@@ -26,7 +29,6 @@
 
 #include "../common.h"
 #include "../localisation/ConversionTables.h"
-#include "../localisation/FormatCodes.h"
 #include "../localisation/Language.h"
 #include "../util/Util.h"
 #include "Memory.hpp"
