@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2023 OpenRCT2 developers
+ * Copyright (c) 2014-2024 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -10,6 +10,7 @@
 #include "LightFX.h"
 
 #include "../Game.h"
+#include "../GameState.h"
 #include "../common.h"
 #include "../config/Config.h"
 #include "../entity/EntityRegistry.h"
@@ -21,7 +22,6 @@
 #include "../ride/RideData.h"
 #include "../ride/Vehicle.h"
 #include "../util/Util.h"
-#include "../world/Climate.h"
 #include "../world/Map.h"
 #include "Drawing.h"
 
@@ -305,7 +305,7 @@ void LightFXPrepareLightList()
                     dpi.zoom_level = _current_view_zoom_front;
                     dpi.width = 1;
 
-                    PaintSession* session = PaintSessionAlloc(dpi, w->viewport->flags);
+                    PaintSession* session = PaintSessionAlloc(dpi, w->viewport->flags, w->viewport->rotation);
                     PaintSessionGenerate(*session);
                     PaintSessionArrange(*session);
                     auto info = SetInteractionInfoFromPaintSession(session, w->viewport->flags, ViewportInteractionItemAll);
@@ -437,7 +437,7 @@ void LightFXUpdateViewportSettings()
         Viewport* viewport = WindowGetViewport(mainWindow);
         _current_view_x_back = viewport->viewPos.x;
         _current_view_y_back = viewport->viewPos.y;
-        _current_view_rotation_back = GetCurrentRotation();
+        _current_view_rotation_back = viewport->rotation;
         _current_view_zoom_back = viewport->zoom;
     }
 }
@@ -838,6 +838,8 @@ void LightFxAddShopLights(const CoordsXY& mapPosition, const uint8_t direction,
 
 void LightFXApplyPaletteFilter(uint8_t i, uint8_t* r, uint8_t* g, uint8_t* b)
 {
+    auto& gameState = OpenRCT2::GetGameState();
+
     float night = static_cast<float>(pow(gDayNightCycle, 1.5));
 
     float natLightR = 1.0f;
@@ -867,9 +869,9 @@ void LightFXApplyPaletteFilter(uint8_t i, uint8_t* r, uint8_t* g, uint8_t* b)
 
     //  overExpose += ((lightMax - lightAvg) / lightMax) * 0.01f;
 
-    if (gClimateCurrent.Temperature > 20)
+    if (gameState.ClimateCurrent.Temperature > 20)
     {
-        float offset = (static_cast<float>(gClimateCurrent.Temperature - 20)) * 0.04f;
+        float offset = (static_cast<float>(gameState.ClimateCurrent.Temperature - 20)) * 0.04f;
         offset *= 1.0f - night;
         lightAvg /= 1.0f + offset;
         //      overExpose += offset * 0.1f;
@@ -891,12 +893,12 @@ void LightFXApplyPaletteFilter(uint8_t i, uint8_t* r, uint8_t* g, uint8_t* b)
     natLightB *= 1.0f + overExpose;
     overExpose *= 255.0f;
 
-    float targetFogginess = static_cast<float>(gClimateCurrent.Level) / 8.0f;
+    float targetFogginess = static_cast<float>(gameState.ClimateCurrent.Level) / 8.0f;
     targetFogginess += (night * night) * 0.15f;
 
-    if (gClimateCurrent.Temperature < 10)
+    if (gameState.ClimateCurrent.Temperature < 10)
     {
-        targetFogginess += (static_cast<float>(10 - gClimateCurrent.Temperature)) * 0.01f;
+        targetFogginess += (static_cast<float>(10 - gameState.ClimateCurrent.Temperature)) * 0.01f;
     }
 
     fogginess -= (fogginess - targetFogginess) * 0.00001f;
@@ -934,7 +936,7 @@ void LightFXApplyPaletteFilter(uint8_t i, uint8_t* r, uint8_t* g, uint8_t* b)
     natLightG /= 1.0f + lightPolution;
     natLightB /= 1.0f + lightPolution;
 
-    reduceColourLit += static_cast<float>(gClimateCurrent.Level) / 2.0f;
+    reduceColourLit += static_cast<float>(gameState.ClimateCurrent.Level) / 2.0f;
 
     reduceColourNat /= 1.0f + fogginess;
     reduceColourLit /= 1.0f + fogginess;
