@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2023 OpenRCT2 developers
+ * Copyright (c) 2014-2024 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -10,11 +10,13 @@
 #include "Weather.h"
 
 #include "../Game.h"
+#include "../GameState.h"
 #include "../config/Config.h"
 #include "../interface/Viewport.h"
 #include "../ride/TrackDesign.h"
 #include "../scenario/Scenario.h"
 #include "../ui/UiContext.h"
+#include "../util/Util.h"
 #include "../world/Climate.h"
 #include "Drawing.h"
 #include "IDrawingEngine.h"
@@ -62,13 +64,13 @@ void DrawWeather(DrawPixelInfo& dpi, IWeatherDrawer* weatherDrawer)
             viewFlags = viewport->flags;
 
         // Get weather draw function and draw weather
-        auto weatherLevel = gClimateCurrent.Level;
+        auto weatherLevel = GetGameState().ClimateCurrent.Level;
         if (weatherLevel != WeatherLevel::None && !gTrackDesignSaveMode && !(viewFlags & VIEWPORT_FLAG_HIGHLIGHT_PATH_ISSUES))
         {
-            auto drawFunc = DrawRainFunctions[static_cast<int8_t>(weatherLevel)];
+            auto drawFunc = DrawRainFunctions[EnumValue(weatherLevel)];
             if (ClimateIsSnowing())
             {
-                drawFunc = DrawSnowFunctions[static_cast<int8_t>(weatherLevel)];
+                drawFunc = DrawSnowFunctions[EnumValue(weatherLevel)];
             }
             auto uiContext = GetContext()->GetUiContext();
             uiContext->DrawWeatherAnimation(weatherDrawer, dpi, drawFunc);
@@ -83,15 +85,17 @@ void DrawWeather(DrawPixelInfo& dpi, IWeatherDrawer* weatherDrawer)
 static void DrawLightRain(
     DrawPixelInfo& dpi, IWeatherDrawer* weatherDrawer, int32_t left, int32_t top, int32_t width, int32_t height)
 {
-    int32_t x_start = -static_cast<int32_t>(gCurrentTicks) + 8;
-    int32_t y_start = (gCurrentTicks * 3) + 7;
+    const auto currentTicks = GetGameState().CurrentTicks;
+
+    int32_t x_start = -static_cast<int32_t>(currentTicks) + 8;
+    int32_t y_start = (currentTicks * 3) + 7;
     y_start = -y_start;
     x_start += left;
     y_start += top;
     weatherDrawer->Draw(dpi, left, top, width, height, x_start, y_start, RainPattern);
 
-    x_start = -static_cast<int32_t>(gCurrentTicks) + 0x18;
-    y_start = (gCurrentTicks * 4) + 0x0D;
+    x_start = -static_cast<int32_t>(currentTicks) + 0x18;
+    y_start = (currentTicks * 4) + 0x0D;
     y_start = -y_start;
     x_start += left;
     y_start += top;
@@ -105,29 +109,31 @@ static void DrawLightRain(
 static void DrawHeavyRain(
     DrawPixelInfo& dpi, IWeatherDrawer* weatherDrawer, int32_t left, int32_t top, int32_t width, int32_t height)
 {
-    int32_t x_start = -static_cast<int32_t>(gCurrentTicks);
-    int32_t y_start = gCurrentTicks * 5;
+    const auto currentTicks = GetGameState().CurrentTicks;
+
+    int32_t x_start = -static_cast<int32_t>(currentTicks);
+    int32_t y_start = currentTicks * 5;
     y_start = -y_start;
     x_start += left;
     y_start += top;
     weatherDrawer->Draw(dpi, left, top, width, height, x_start, y_start, RainPattern);
 
-    x_start = -static_cast<int32_t>(gCurrentTicks) + 0x10;
-    y_start = (gCurrentTicks * 6) + 5;
+    x_start = -static_cast<int32_t>(currentTicks) + 0x10;
+    y_start = (currentTicks * 6) + 5;
     y_start = -y_start;
     x_start += left;
     y_start += top;
     weatherDrawer->Draw(dpi, left, top, width, height, x_start, y_start, RainPattern);
 
-    x_start = -static_cast<int32_t>(gCurrentTicks) + 8;
-    y_start = (gCurrentTicks * 3) + 7;
+    x_start = -static_cast<int32_t>(currentTicks) + 8;
+    y_start = (currentTicks * 3) + 7;
     y_start = -y_start;
     x_start += left;
     y_start += top;
     weatherDrawer->Draw(dpi, left, top, width, height, x_start, y_start, RainPattern);
 
-    x_start = -static_cast<int32_t>(gCurrentTicks) + 0x18;
-    y_start = (gCurrentTicks * 4) + 0x0D;
+    x_start = -static_cast<int32_t>(currentTicks) + 0x18;
+    y_start = (currentTicks * 4) + 0x0D;
     y_start = -y_start;
     x_start += left;
     y_start += top;
@@ -137,9 +143,11 @@ static void DrawHeavyRain(
 static void DrawLightSnow(
     DrawPixelInfo& dpi, IWeatherDrawer* weatherDrawer, int32_t left, int32_t top, int32_t width, int32_t height)
 {
-    const uint32_t t = gCurrentTicks / 2;
+    const auto currentTicks = GetGameState().CurrentTicks;
+
+    const uint32_t t = currentTicks / 2;
     const int32_t negT = -static_cast<int32_t>(t);
-    const double cosTick = static_cast<double>(gCurrentTicks) * 0.05;
+    const double cosTick = static_cast<double>(currentTicks) * 0.05;
 
     int32_t x_start = negT + 1 + (cos(1.0 + cosTick) * 6);
     int32_t y_start = t + 1;
@@ -159,29 +167,31 @@ static void DrawLightSnow(
 static void DrawHeavySnow(
     DrawPixelInfo& dpi, IWeatherDrawer* weatherDrawer, int32_t left, int32_t top, int32_t width, int32_t height)
 {
-    int32_t x_start = -static_cast<int32_t>(gCurrentTicks * 3) + 1;
-    int32_t y_start = gCurrentTicks + 23;
+    const auto currentTicks = GetGameState().CurrentTicks;
+
+    int32_t x_start = -static_cast<int32_t>(currentTicks * 3) + 1;
+    int32_t y_start = currentTicks + 23;
     y_start = -y_start;
     x_start += left;
     y_start += top;
     weatherDrawer->Draw(dpi, left, top, width, height, x_start, y_start, SnowPattern);
 
-    x_start = -static_cast<int32_t>(gCurrentTicks * 4) + 6;
-    y_start = gCurrentTicks + 5;
+    x_start = -static_cast<int32_t>(currentTicks * 4) + 6;
+    y_start = currentTicks + 5;
     y_start = -y_start;
     x_start += left;
     y_start += top;
     weatherDrawer->Draw(dpi, left, top, width, height, x_start, y_start, SnowPattern);
 
-    x_start = -static_cast<int32_t>(gCurrentTicks * 2) + 11;
-    y_start = gCurrentTicks + 18;
+    x_start = -static_cast<int32_t>(currentTicks * 2) + 11;
+    y_start = currentTicks + 18;
     y_start = -y_start;
     x_start += left;
     y_start += top;
     weatherDrawer->Draw(dpi, left, top, width, height, x_start, y_start, SnowPattern);
 
-    x_start = -static_cast<int32_t>(gCurrentTicks * 3) + 17;
-    y_start = gCurrentTicks + 11;
+    x_start = -static_cast<int32_t>(currentTicks * 3) + 17;
+    y_start = currentTicks + 11;
     y_start = -y_start;
     x_start += left;
     y_start += top;
