@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2023 OpenRCT2 developers
+ * Copyright (c) 2014-2024 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -10,6 +10,7 @@
 #include "EntityRegistry.h"
 
 #include "../Game.h"
+#include "../GameState.h"
 #include "../core/Algorithm.hpp"
 #include "../core/ChecksumStream.h"
 #include "../core/Crypt.h"
@@ -36,23 +37,14 @@
 #include <numeric>
 #include <vector>
 
-union Entity
-{
-    uint8_t Pad00[0x200];
-    EntityBase base;
-    Entity()
-        : Pad00()
-    {
-    }
-};
+using namespace OpenRCT2;
 
-static Entity _entities[MAX_ENTITIES]{};
 static std::array<std::list<EntityId>, EnumValue(EntityType::Count)> gEntityLists;
 static std::vector<EntityId> _freeIdList;
 
 static bool _entityFlashingList[MAX_ENTITIES];
 
-constexpr const uint32_t SPATIAL_INDEX_SIZE = (MAXIMUM_MAP_SIZE_TECHNICAL * MAXIMUM_MAP_SIZE_TECHNICAL) + 1;
+constexpr const uint32_t SPATIAL_INDEX_SIZE = (kMaximumMapSizeTechnical * kMaximumMapSizeTechnical) + 1;
 constexpr uint32_t SPATIAL_INDEX_LOCATION_NULL = SPATIAL_INDEX_SIZE - 1;
 
 static std::array<std::vector<EntityId>, SPATIAL_INDEX_SIZE> gEntitySpatialIndex;
@@ -68,10 +60,10 @@ static constexpr size_t GetSpatialIndexOffset(const CoordsXY& loc)
     const auto tileX = std::abs(loc.x) / COORDS_XY_STEP;
     const auto tileY = std::abs(loc.y) / COORDS_XY_STEP;
 
-    if (tileX >= MAXIMUM_MAP_SIZE_TECHNICAL || tileY >= MAXIMUM_MAP_SIZE_TECHNICAL)
+    if (tileX >= kMaximumMapSizeTechnical || tileY >= kMaximumMapSizeTechnical)
         return SPATIAL_INDEX_LOCATION_NULL;
 
-    return tileX * MAXIMUM_MAP_SIZE_TECHNICAL + tileY;
+    return tileX * kMaximumMapSizeTechnical + tileY;
 }
 
 constexpr bool EntityTypeIsMiscEntity(const EntityType type)
@@ -120,8 +112,9 @@ std::string EntitiesChecksum::ToString() const
 
 EntityBase* TryGetEntity(EntityId entityIndex)
 {
+    auto& gameState = GetGameState();
     const auto idx = entityIndex.ToUnderlying();
-    return idx >= MAX_ENTITIES ? nullptr : &_entities[idx].base;
+    return idx >= MAX_ENTITIES ? nullptr : &gameState.Entities[idx].base;
 }
 
 EntityBase* GetEntity(EntityId entityIndex)
@@ -171,8 +164,6 @@ const std::list<EntityId>& GetEntityList(const EntityType id)
  */
 void ResetAllEntities()
 {
-    gSavedAge = 0;
-
     // Free all associated Entity pointers prior to zeroing memory
     for (int32_t i = 0; i < MAX_ENTITIES; ++i)
     {
@@ -184,7 +175,8 @@ void ResetAllEntities()
         FreeEntity(*spr);
     }
 
-    std::fill(std::begin(_entities), std::end(_entities), Entity());
+    auto& gameState = GetGameState();
+    std::fill(std::begin(gameState.Entities), std::end(gameState.Entities), Entity_t());
     OpenRCT2::RideUse::GetHistory().Clear();
     OpenRCT2::RideUse::GetTypeHistory().Clear();
     for (int32_t i = 0; i < MAX_ENTITIES; ++i)
@@ -268,14 +260,15 @@ static void EntityReset(EntityBase* entity)
     auto entityIndex = entity->Id;
     _entityFlashingList[entityIndex.ToUnderlying()] = false;
 
-    Entity* spr = reinterpret_cast<Entity*>(entity);
-    *spr = Entity();
+    Entity_t* tempEntity = reinterpret_cast<Entity_t*>(entity);
+    *tempEntity = Entity_t();
 
     entity->Id = entityIndex;
     entity->Type = EntityType::Null;
 }
 
-static constexpr uint16_t MAX_MISC_SPRITES = 300;
+static constexpr uint16_t MAX_MISC_SPRITES = 1600;
+
 static void AddToEntityList(EntityBase* entity)
 {
     auto& list = gEntityLists[EnumValue(entity->Type)];
@@ -341,11 +334,14 @@ EntityBase* CreateEntity(EntityType type)
 
     if (EntityTypeIsMiscEntity(type))
     {
-        // Misc sprites are commonly used for effects, if there are less than MAX_MISC_SPRITES
-        // free it will fail to keep slots for more relevant sprites.
-        // Also there can't be more than MAX_MISC_SPRITES sprites in this list.
-        uint16_t miscSlotsRemaining = MAX_MISC_SPRITES - GetMiscEntityCount();
-        if (miscSlotsRemaining >= _freeIdList.size())
+        // Misc sprites are commonly used for effects, give other entity types higher priority.
+        if (GetMiscEntityCount() >= MAX_MISC_SPRITES)
+        {
+            return nullptr;
+        }
+
+        // If there are less than MAX_MISC_SPRITES free slots, ensure other entities can be created.
+        if (_freeIdList.size() < MAX_MISC_SPRITES)
         {
             return nullptr;
         }
