@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2023 OpenRCT2 developers
+ * Copyright (c) 2014-2024 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -321,7 +321,7 @@ public:
     uint64_t ItemFlags;
 
     void UpdateGuest();
-    void Tick128UpdateGuest(int32_t index);
+    void Tick128UpdateGuest(uint32_t index);
     int64_t GetFoodOrDrinkFlags() const;
     int64_t GetEmptyContainerFlags() const;
     bool HasDrink() const;
@@ -460,18 +460,6 @@ enum
     EASTEREGG_PEEP_NAME_DAVID_ELLIS
 };
 
-extern uint8_t gGuestChangeModifier;
-extern uint32_t gNumGuestsInPark;
-extern uint32_t gNumGuestsInParkLastWeek;
-extern uint32_t gNumGuestsHeadingForPark;
-
-extern money64 gGuestInitialCash;
-extern uint8_t gGuestInitialHappiness;
-extern uint8_t gGuestInitialHunger;
-extern uint8_t gGuestInitialThirst;
-
-extern uint32_t gNextGuestNumber;
-
 void PeepThoughtSetFormatArgs(const PeepThought* thought, Formatter& ft);
 
 void IncrementGuestsInPark();
