@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2023 OpenRCT2 developers
+ * Copyright (c) 2014-2024 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -199,7 +199,7 @@ enum PeepFlags : uint32_t
 {
     PEEP_FLAGS_LEAVING_PARK = (1 << 0),
     PEEP_FLAGS_SLOW_WALK = (1 << 1),
-    PEEP_FLAGS_2 = (1 << 2),
+    PEEP_FLAGS_DEBUG_PATHFINDING = (1 << 2), // Enables debug logging for path finding
     PEEP_FLAGS_TRACKING = (1 << 3),
     PEEP_FLAGS_WAVING = (1 << 4),                  // Makes the peep wave
     PEEP_FLAGS_HAS_PAID_FOR_PARK_ENTRY = (1 << 5), // Set on paying to enter park
@@ -459,8 +459,6 @@ enum
 extern const PeepAnimationEntry g_peep_animation_entries[EnumValue(PeepSpriteType::Count)];
 extern const bool gSpriteTypeToSlowWalkMap[48];
 
-extern uint8_t gPeepWarningThrottle[16];
-
 int32_t PeepGetStaffCount();
 void PeepUpdateAll();
 void PeepProblemWarningsUpdate();
