@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2023 OpenRCT2 developers
+ * Copyright (c) 2014-2024 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -142,14 +142,10 @@ enum class EntertainerCostume : uint8_t
     Count
 };
 
-extern const StringId StaffCostumeNames[static_cast<uint8_t>(EntertainerCostume::Count)];
-
-extern colour_t gStaffHandymanColour;
-extern colour_t gStaffMechanicColour;
-extern colour_t gStaffSecurityColour;
+extern const StringId StaffCostumeNames[EnumValue(EntertainerCostume::Count)];
 
 colour_t StaffGetColour(StaffType staffType);
-bool StaffSetColour(StaffType staffType, colour_t value);
+GameActions::Result StaffSetColour(StaffType staffType, colour_t value);
 uint32_t StaffGetAvailableEntertainerCostumes();
 int32_t StaffGetAvailableEntertainerCostumeList(EntertainerCostume* costumeList);
 
