@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2023 OpenRCT2 developers
+ * Copyright (c) 2014-2024 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -9,6 +9,7 @@
 
 #include "Award.h"
 
+#include "../GameState.h"
 #include "../config/Config.h"
 #include "../entity/Guest.h"
 #include "../interface/Window.h"
@@ -23,6 +24,8 @@
 
 #include <algorithm>
 
+using namespace OpenRCT2;
+
 constexpr uint8_t NEGATIVE = 0;
 constexpr uint8_t POSITIVE = 1;
 
@@ -66,13 +69,6 @@ static constexpr StringId AwardNewsStrings[] = {
     STR_NEWS_ITEM_BEST_GENTLE_RIDES,
 };
 
-static std::vector<Award> _currentAwards;
-
-std::vector<Award>& GetAwards()
-{
-    return _currentAwards;
-}
-
 bool AwardIsPositive(AwardType type)
 {
     return AwardPositiveMap[EnumValue(type)];
@@ -107,7 +103,7 @@ static bool AwardIsDeservedMostUntidy(int32_t activeAwardTypes)
         }
     }
 
-    return (negativeCount > gNumGuestsInPark / 16);
+    return (negativeCount > GetGameState().NumGuestsInPark / 16);
 }
 
 /** More than 1/64 of the total guests must be thinking tidy thoughts and less than 6 guests thinking untidy thoughts. */
@@ -139,7 +135,7 @@ static bool AwardIsDeservedMostTidy(int32_t activeAwardTypes)
         }
     }
 
-    return (negativeCount <= 5 && positiveCount > gNumGuestsInPark / 64);
+    return (negativeCount <= 5 && positiveCount > GetGameState().NumGuestsInPark / 64);
 }
 
 /** At least 6 open roller coasters. */
@@ -172,19 +168,21 @@ static bool AwardIsDeservedBestRollercoasters([[maybe_unused]] int32_t activeAwa
 /** Entrance fee is 0.10 less than half of the total ride value. */
 static bool AwardIsDeservedBestValue(int32_t activeAwardTypes)
 {
+    auto& gameState = GetGameState();
+
     if (activeAwardTypes & EnumToFlag(AwardType::WorstValue))
         return false;
 
     if (activeAwardTypes & EnumToFlag(AwardType::MostDisappointing))
         return false;
 
-    if ((gParkFlags & PARK_FLAGS_NO_MONEY) || !ParkEntranceFeeUnlocked())
+    if ((gameState.ParkFlags & PARK_FLAGS_NO_MONEY) || !ParkEntranceFeeUnlocked())
         return false;
 
-    if (gTotalRideValueForMoney < 10.00_GBP)
+    if (gameState.TotalRideValueForMoney < 10.00_GBP)
         return false;
 
-    if (ParkGetEntranceFee() + 0.10_GBP >= gTotalRideValueForMoney / 2)
+    if (ParkGetEntranceFee() + 0.10_GBP >= gameState.TotalRideValueForMoney / 2)
         return false;
 
     return true;
@@ -220,21 +218,23 @@ static bool AwardIsDeservedMostBeautiful(int32_t activeAwardTypes)
         }
     }
 
-    return (negativeCount <= 15 && positiveCount > gNumGuestsInPark / 128);
+    return (negativeCount <= 15 && positiveCount > GetGameState().NumGuestsInPark / 128);
 }
 
 /** Entrance fee is more than total ride value. */
 static bool AwardIsDeservedWorstValue(int32_t activeAwardTypes)
 {
+    auto& gameState = GetGameState();
+
     if (activeAwardTypes & EnumToFlag(AwardType::BestValue))
         return false;
-    if (gParkFlags & PARK_FLAGS_NO_MONEY)
+    if (gameState.ParkFlags & PARK_FLAGS_NO_MONEY)
         return false;
 
     const auto parkEntranceFee = ParkGetEntranceFee();
     if (parkEntranceFee == 0.00_GBP)
         return false;
-    if (parkEntranceFee <= gTotalRideValueForMoney)
+    if (parkEntranceFee <= gameState.TotalRideValueForMoney)
         return false;
     return true;
 }
@@ -308,7 +308,7 @@ static bool AwardIsDeservedBestFood(int32_t activeAwardTypes)
         }
     }
 
-    if (shops < 7 || uniqueShops < 4 || shops < gNumGuestsInPark / 128)
+    if (shops < 7 || uniqueShops < 4 || shops < GetGameState().NumGuestsInPark / 128)
         return false;
 
     // Count hungry peeps
@@ -353,7 +353,7 @@ static bool AwardIsDeservedWorstFood(int32_t activeAwardTypes)
         }
     }
 
-    if (uniqueShops > 2 || shops > gNumGuestsInPark / 256)
+    if (uniqueShops > 2 || shops > GetGameState().NumGuestsInPark / 256)
         return false;
 
     // Count hungry peeps
@@ -385,7 +385,7 @@ static bool AwardIsDeservedBestToilets([[maybe_unused]] int32_t activeAwardTypes
         return false;
 
     // At least one open toilet for every 128 guests
-    if (numToilets < gNumGuestsInPark / 128u)
+    if (numToilets < GetGameState().NumGuestsInPark / 128u)
         return false;
 
     // Count number of guests who are thinking they need the toilet
@@ -407,7 +407,7 @@ static bool AwardIsDeservedMostDisappointing(int32_t activeAwardTypes)
 {
     if (activeAwardTypes & EnumToFlag(AwardType::BestValue))
         return false;
-    if (gParkRating > 650)
+    if (GetGameState().ParkRating > 650)
         return false;
 
     // Count the number of disappointing rides
@@ -595,7 +595,7 @@ static bool AwardIsDeserved(AwardType awardType, int32_t activeAwardTypes)
 
 void AwardReset()
 {
-    _currentAwards.clear();
+    GetGameState().CurrentAwards.clear();
 }
 
 /**
@@ -606,32 +606,33 @@ void AwardUpdateAll()
 {
     PROFILED_FUNCTION();
 
+    auto& currentAwards = GetGameState().CurrentAwards;
     // Decrease award times
-    for (auto& award : _currentAwards)
+    for (auto& award : currentAwards)
     {
         --award.Time;
     }
     // Remove any 0 time awards
     auto res = std::remove_if(
-        std::begin(_currentAwards), std::end(_currentAwards), [](const Award& award) { return award.Time == 0; });
-    if (res != std::end(_currentAwards))
+        std::begin(currentAwards), std::end(currentAwards), [](const Award& award) { return award.Time == 0; });
+    if (res != std::end(currentAwards))
     {
-        _currentAwards.erase(res, std::end(_currentAwards));
+        currentAwards.erase(res, std::end(currentAwards));
         WindowInvalidateByClass(WindowClass::ParkInformation);
     }
 
     // Only add new awards if park is open
-    if (gParkFlags & PARK_FLAGS_PARK_OPEN)
+    if (GetGameState().ParkFlags & PARK_FLAGS_PARK_OPEN)
     {
         // Set active award types as flags
         int32_t activeAwardTypes = 0;
-        for (auto& award : _currentAwards)
+        for (auto& award : currentAwards)
         {
             activeAwardTypes |= (1 << EnumValue(award.Type));
         }
 
         // Check if there was a free award entry
-        if (_currentAwards.size() < OpenRCT2::Limits::MaxAwards)
+        if (currentAwards.size() < OpenRCT2::Limits::MaxAwards)
         {
             // Get a random award type not already active
             AwardType awardType;
@@ -644,7 +645,7 @@ void AwardUpdateAll()
             if (AwardIsDeserved(awardType, activeAwardTypes))
             {
                 // Add award
-                _currentAwards.push_back(Award{ 5u, awardType });
+                currentAwards.push_back(Award{ 5u, awardType });
                 if (gConfigNotifications.ParkAward)
                 {
                     News::AddItemToQueue(News::ItemType::Award, AwardNewsStrings[EnumValue(awardType)], 0, {});
