@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2023 OpenRCT2 developers
+ * Copyright (c) 2014-2024 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -161,9 +161,10 @@ std::vector<std::unique_ptr<ImageTable::RequiredImage>> ImageTable::ParseImages(
         {
             auto imageData = context->GetData(s);
             auto image = Imaging::ReadFromBuffer(imageData);
+            auto meta = ImageImportMeta{};
 
             ImageImporter importer;
-            auto importResult = importer.Import(image, 0, 0, ImageImporter::Palette::OpenRCT2, ImageImporter::ImportFlags::RLE);
+            auto importResult = importer.Import(image, meta);
 
             result.push_back(std::make_unique<RequiredImage>(importResult.Element));
         }
@@ -183,30 +184,11 @@ std::vector<std::unique_ptr<ImageTable::RequiredImage>> ImageTable::ParseImages(
     Guard::Assert(el.is_object(), "ImageTable::ParseImages expects parameter el to be object");
 
     auto path = Json::GetString(el["path"]);
-    auto x = Json::GetNumber<int16_t>(el["x"]);
-    auto y = Json::GetNumber<int16_t>(el["y"]);
-    auto srcX = Json::GetNumber<int16_t>(el["srcX"]);
-    auto srcY = Json::GetNumber<int16_t>(el["srcY"]);
-    auto srcWidth = Json::GetNumber<int16_t>(el["srcWidth"]);
-    auto srcHeight = Json::GetNumber<int16_t>(el["srcHeight"]);
-    auto raw = Json::GetString(el["format"]) == "raw";
-    auto keepPalette = Json::GetString(el["palette"]) == "keep";
-    auto zoomOffset = Json::GetNumber<int32_t>(el["zoom"]);
+    auto meta = createImageImportMetaFromJson(el);
 
     std::vector<std::unique_ptr<RequiredImage>> result;
     try
     {
-        auto flags = ImageImporter::ImportFlags::None;
-        auto palette = ImageImporter::Palette::OpenRCT2;
-        if (!raw)
-        {
-            flags = static_cast<ImageImporter::ImportFlags>(flags | ImageImporter::ImportFlags::RLE);
-        }
-        if (keepPalette)
-        {
-            palette = ImageImporter::Palette::KeepIndices;
-        }
-
         auto itSource = std::find_if(
             imageSources.begin(), imageSources.end(),
             [&path](const std::pair<std::string, Image>& item) { return item.first == path; });
@@ -216,16 +198,9 @@ std::vector<std::unique_ptr<ImageTable::RequiredImage>> ImageTable::ParseImages(
         }
         auto& image = itSource->second;
 
-        if (srcWidth == 0)
-            srcWidth = image.Width;
-
-        if (srcHeight == 0)
-            srcHeight = image.Height;
-
         ImageImporter importer;
-        auto importResult = importer.Import(image, srcX, srcY, srcWidth, srcHeight, x, y, palette, flags);
+        auto importResult = importer.Import(image, meta);
         auto g1element = importResult.Element;
-        g1element.zoomed_offset = zoomOffset;
         result.push_back(std::make_unique<RequiredImage>(g1element));
     }
     catch (const std::exception& e)
