@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2023 OpenRCT2 developers
+ * Copyright (c) 2014-2024 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -94,10 +94,13 @@ void EntityPaintSetup(PaintSession& session, const CoordsXY& pos)
             }
         }
 
-        if (session.DPI.y + session.DPI.height <= spr->SpriteData.SpriteRect.GetTop()
-            || spr->SpriteData.SpriteRect.GetBottom() <= session.DPI.y
-            || session.DPI.x + session.DPI.width <= spr->SpriteData.SpriteRect.GetLeft()
-            || spr->SpriteData.SpriteRect.GetRight() <= session.DPI.x)
+        auto screenCoords = Translate3DTo2DWithZ(session.CurrentRotation, spr->GetLocation());
+        auto spriteRect = ScreenRect(
+            screenCoords - ScreenCoordsXY{ spr->SpriteData.Width, spr->SpriteData.HeightMin },
+            screenCoords + ScreenCoordsXY{ spr->SpriteData.Width, spr->SpriteData.HeightMax });
+
+        if (session.DPI.y + session.DPI.height <= spriteRect.GetTop() || spriteRect.GetBottom() <= session.DPI.y
+            || session.DPI.x + session.DPI.width <= spriteRect.GetLeft() || spriteRect.GetRight() <= session.DPI.x)
         {
             continue;
         }
