@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2023 OpenRCT2 developers
+ * Copyright (c) 2014-2024 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -26,18 +26,24 @@ enum edge_t
     EDGE_TOPRIGHT = EDGE_NE
 };
 
-enum
+// This controls in which segment of a tile something is drawn.
+// This is from a screen perspective, e.g. topCorner will always represent the part of top of the screen.
+enum class PaintSegment : uint16_t
 {
-    SEGMENT_B4 = (1 << 0), // 0
-    SEGMENT_CC = (1 << 1), // 6
-    SEGMENT_BC = (1 << 2), // 2
-    SEGMENT_D4 = (1 << 3), // 8
-    SEGMENT_C0 = (1 << 4), // 3
-    SEGMENT_D0 = (1 << 5), // 7
-    SEGMENT_B8 = (1 << 6), // 1
-    SEGMENT_C8 = (1 << 7), // 5
-    SEGMENT_C4 = (1 << 8), // 4
+    topCorner = 0,
+    topRightSide = 1,
+    rightCorner = 2,
+    bottomRightSide = 3,
+    bottomCorner = 4,
+    bottomLeftSide = 5,
+    leftCorner = 6,
+    topLeftSide = 7,
+    centre = 8,
 };
+constexpr int32_t kSegmentsAll = EnumsToFlags(
+    PaintSegment::topCorner, PaintSegment::leftCorner, PaintSegment::rightCorner, PaintSegment::bottomCorner,
+    PaintSegment::centre, PaintSegment::topLeftSide, PaintSegment::topRightSide, PaintSegment::bottomLeftSide,
+    PaintSegment::bottomRightSide);
 
 enum
 {
@@ -71,7 +77,6 @@ enum
     TUNNEL_TYPE_COUNT
 };
 
-extern const int32_t SEGMENTS_ALL;
 extern const uint16_t segment_offsets[9];
 
 extern bool gShowSupportSegmentHeights;
