@@ -8,6 +8,8 @@ struct ObjectRepositoryItem;
 
 namespace OpenRCT2
 {
+    struct GameState_t;
+
     // Current version that is saved.
     constexpr uint32_t PARK_FILE_CURRENT_VERSION = 33;
 
@@ -28,6 +30,6 @@ class ParkFileExporter
 public:
     std::vector<const ObjectRepositoryItem*> ExportObjectsList;
 
-    void Export(std::string_view path);
-    void Export(OpenRCT2::IStream& stream);
+    void Export(OpenRCT2::GameState_t& gameState, std::string_view path);
+    void Export(OpenRCT2::GameState_t& gameState, OpenRCT2::IStream& stream);
 };
