@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2023 OpenRCT2 developers
+ * Copyright (c) 2014-2024 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -136,11 +136,10 @@ namespace RCT1
                 td->ride_mode = RideMode::PoweredLaunch;
             }
 
-            // Convert RCT1 vehicle type to RCT2 vehicle type. Initialise with a string consisting of 8 spaces.
             std::string_view vehicleObject;
             if (td4Base.Type == RideType::HedgeMaze)
             {
-                vehicleObject = RCT1::GetRideTypeObject(td4Base.Type);
+                vehicleObject = RCT1::GetRideTypeObject(td4Base.Type, false);
             }
             else
             {
@@ -148,7 +147,7 @@ namespace RCT1
             }
             assert(!vehicleObject.empty());
             td->vehicle_object = ObjectEntryDescriptor(vehicleObject);
-            td->vehicle_type = td4Base.VehicleType;
+            td->vehicle_type = EnumValue(td4Base.VehicleType);
 
             td->flags = td4Base.Flags;
             td->colour_scheme = td4Base.VersionAndColourScheme & 0x3;
@@ -204,6 +203,7 @@ namespace RCT1
                 td->vehicle_colours[i] = td->vehicle_colours[0];
             }
 
+            td->StationObjectIdentifier = GetStationIdentifierFromStyle(RCT12_STATION_STYLE_PLAIN);
             td->depart_flags = td4Base.DepartFlags;
             td->number_of_trains = td4Base.NumberOfTrains;
             td->number_of_cars_per_train = td4Base.NumberOfCarsPerTrain;
@@ -249,12 +249,7 @@ namespace RCT1
                     _stream.Read(&t4MazeElement, sizeof(TD46MazeElement));
                     if (t4MazeElement.All != 0)
                     {
-                        TrackDesignMazeElement mazeElement{};
-                        mazeElement.x = t4MazeElement.x;
-                        mazeElement.y = t4MazeElement.y;
-                        mazeElement.direction = t4MazeElement.Direction;
-                        mazeElement.type = t4MazeElement.Type;
-                        td->maze_elements.push_back(mazeElement);
+                        ImportMazeElement(*td, t4MazeElement);
                     }
                 }
             }
