@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2023 OpenRCT2 developers
+ * Copyright (c) 2014-2024 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -11,6 +11,8 @@
 
 #include "../common.h"
 
+#include <memory>
+
 /**
  * The type of encoding / compression for a sawyer encoded chunk.
  */
@@ -28,14 +30,14 @@ enum class SAWYER_ENCODING : uint8_t
 class SawyerChunk final
 {
 private:
-    void* _data = nullptr;
+    std::unique_ptr<uint8_t[]> _data;
     size_t _length = 0;
     SAWYER_ENCODING _encoding = SAWYER_ENCODING::NONE;
 
 public:
     const void* GetData() const
     {
-        return _data;
+        return _data.get();
     }
     size_t GetLength() const
     {
@@ -46,6 +48,5 @@ public:
         return _encoding;
     }
 
-    SawyerChunk(SAWYER_ENCODING encoding, void* data, size_t length);
-    ~SawyerChunk();
+    SawyerChunk(SAWYER_ENCODING encoding, std::unique_ptr<uint8_t[]> data, size_t length);
 };
