@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2023 OpenRCT2 developers
+ * Copyright (c) 2014-2024 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -20,6 +20,7 @@
 #include "RideData.h"
 
 #include "../Cheats.h"
+#include "../GameState.h"
 #include "../audio/audio.h"
 #include "../interface/Colour.h"
 #include "../localisation/Localisation.h"
@@ -33,6 +34,7 @@
 #include "coaster/meta/AlpineCoaster.h"
 #include "coaster/meta/BobsleighCoaster.h"
 #include "coaster/meta/ClassicMiniRollerCoaster.h"
+#include "coaster/meta/ClassicStandUpRollerCoaster.h"
 #include "coaster/meta/ClassicWoodenRollerCoaster.h"
 #include "coaster/meta/CompactInvertedCoaster.h"
 #include "coaster/meta/CorkscrewRollerCoaster.h"
@@ -120,79 +122,84 @@
 
 #include <iterator>
 
+using namespace OpenRCT2;
 using namespace OpenRCT2::Entity::Yaw;
 
 // clang-format off
 
 const CarEntry CableLiftVehicle = {
-    /* .TabRotationMask = */ 31,
-    /* .spacing = */ 0,
-    /* .car_mass = */ 0,
-    /* .tab_height = */ 0,
-    /* .num_seats = */ 0,
-    /* .sprite_width = */ 0,
-    /* .sprite_height_negative = */ 0,
-    /* .sprite_height_positive = */ 0,
-    /* .animation = */ CarEntryAnimation::None,
-    /* .flags = */ 0,
-    /* .base_num_frames = */ 1,
-    /* .base_image_id = */ 29110,
-    /* .SpriteGroups[SlopeFlat] = */ 29110, SpritePrecision::Sprites32,
-    /* .SpriteGroups[Slopes12] = */ 29142, SpritePrecision::Sprites4,
-    /* .SpriteGroups[Slopes25] = */ 29150, SpritePrecision::Sprites32,
-    /* .SpriteGroups[Slopes42] = */ 29214, SpritePrecision::Sprites8,
-    /* .SpriteGroups[Slopes60] = */ 29230, SpritePrecision::Sprites32,
-    /* .SpriteGroups[Slopes75] = */ 0, SpritePrecision::None,
-    /* .SpriteGroups[Slopes90] = */ 0, SpritePrecision::None,
-    /* .SpriteGroups[SlopesLoop] = */ 0, SpritePrecision::None,
-    /* .SpriteGroups[SlopeInverted] = */ 0, SpritePrecision::None,
-    /* .SpriteGroups[Slopes8] = */ 0, SpritePrecision::None,
-    /* .SpriteGroups[Slopes16] = */ 0, SpritePrecision::None,
-    /* .SpriteGroups[Slopes50] = */ 0, SpritePrecision::None,
-    /* .SpriteGroups[FlatBanked22] = */ 0, SpritePrecision::None,
-    /* .SpriteGroups[FlatBanked45] = */ 0, SpritePrecision::None,
-    /* .SpriteGroups[FlatBanked67] = */ 0, SpritePrecision::None,
-    /* .SpriteGroups[FlatBanked90] = */ 0, SpritePrecision::None,
-    /* .SpriteGroups[InlineTwists] = */ 0, SpritePrecision::None,
-    /* .SpriteGroups[Slopes12Banked22] = */ 0, SpritePrecision::None,
-    /* .SpriteGroups[Slopes8Banked22] = */ 0, SpritePrecision::None,
-    /* .SpriteGroups[Slopes25Banked22] = */ 0, SpritePrecision::None,
-    /* .SpriteGroups[Slopes8Banked22] = */ 0, SpritePrecision::None,
-    /* .SpriteGroups[Slopes16Banked22] = */ 0, SpritePrecision::None,
-    /* .SpriteGroups[Slopes16Banked45] = */ 0, SpritePrecision::None,
-    /* .SpriteGroups[Slopes25Banked45] = */ 0, SpritePrecision::None,
-    /* .SpriteGroups[Slopes12Banked45] = */ 0, SpritePrecision::None,
-    /* .SpriteGroups[Slopes25Banked67] = */ 0, SpritePrecision::None,
-    /* .SpriteGroups[Slopes25Banked90] = */ 0, SpritePrecision::None,
-    /* .SpriteGroups[Slopes25InlineTwists] = */ 0, SpritePrecision::None,
-    /* .SpriteGroups[Slopes42Banked22] = */ 0, SpritePrecision::None,
-    /* .SpriteGroups[Slopes42Banked45] = */ 0, SpritePrecision::None,
-    /* .SpriteGroups[Slopes42Banked67] = */ 0, SpritePrecision::None,
-    /* .SpriteGroups[Slopes42Banked90] = */ 0, SpritePrecision::None,
-    /* .SpriteGroups[Slopes60Banked22] = */ 0, SpritePrecision::None,
-    /* .SpriteGroups[Corkscrews] = */ 0, SpritePrecision::None,
-    /* .SpriteGroups[RestraintAnimation] = */ 0, SpritePrecision::None,
-    /* .SpriteGroups[CurvedLiftHillUp] = */ 0, SpritePrecision::None,
-    /* .SpriteGroups[CurvedLiftHillDown] = */ 0, SpritePrecision::None,
-    /* .no_vehicle_images = */ 0,
-    /* .no_seating_rows = */ 0,
-    /* .spinning_inertia = */ 0,
-    /* .spinning_friction = */ 255,
-    /* .friction_sound_id = */ OpenRCT2::Audio::SoundId::LiftClassic,
-    /* .log_flume_reverser_vehicle_type = */ 0,
-    /* .sound_range = */ 0,
-    /* .double_sound_frequency = */ 0,
-    /* .powered_acceleration = */ 0,
-    /* .powered_max_speed = */ 0,
-    /* .PaintStyle = */ 0,
-    /* .effect_visual = */ 1,
-    /* .draw_order = */ 14,
-    /* .num_vertical_frames_override = */ 0,
-    /* .peep_loading_positions = */ 0,
-    /* .AnimationExponent = */ 0,
-    /* .AnimationFrames = */ 0,
-    /* .SteamEffectType.longitudinal = */ 0,
-    /* .SteamEffectType.vertical = */ 0
+    .TabRotationMask = 31,
+    .spacing = 0,
+    .car_mass = 0,
+    .tab_height = 0,
+    .num_seats = 0,
+    .sprite_width = 0,
+    .sprite_height_negative = 0,
+    .sprite_height_positive = 0,
+    .animation = CarEntryAnimation::None,
+    .flags = 0,
+    .base_num_frames = 1,
+    .base_image_id = 29110,
+    .SpriteGroups = {
+        /* SpriteGroupType::SlopeFlat */            { 29110, SpritePrecision::Sprites32},
+        /* SpriteGroupType::Slopes12 */             { 29142, SpritePrecision::Sprites4},
+        /* SpriteGroupType::Slopes25 */             { 29150, SpritePrecision::Sprites32},
+        /* SpriteGroupType::Slopes42 */             { 29214, SpritePrecision::Sprites8},
+        /* SpriteGroupType::Slopes60 */             { 29230, SpritePrecision::Sprites32},
+        /* SpriteGroupType::Slopes75 */             { 0, SpritePrecision::None},
+        /* SpriteGroupType::Slopes90 */             { 0, SpritePrecision::None},
+        /* SpriteGroupType::SlopesLoop */           { 0, SpritePrecision::None},
+        /* SpriteGroupType::SlopeInverted */        { 0, SpritePrecision::None},
+        /* SpriteGroupType::Slopes8 */              { 0, SpritePrecision::None},
+        /* SpriteGroupType::Slopes16 */             { 0, SpritePrecision::None},
+        /* SpriteGroupType::Slopes50 */             { 0, SpritePrecision::None},
+        /* SpriteGroupType::FlatBanked22 */         { 0, SpritePrecision::None},
+        /* SpriteGroupType::FlatBanked45 */         { 0, SpritePrecision::None},
+        /* SpriteGroupType::FlatBanked67 */         { 0, SpritePrecision::None},
+        /* SpriteGroupType::FlatBanked90 */         { 0, SpritePrecision::None},
+        /* SpriteGroupType::InlineTwists */         { 0, SpritePrecision::None},
+        /* SpriteGroupType::Slopes12Banked22 */     { 0, SpritePrecision::None},
+        /* SpriteGroupType::Slopes8Banked22 */      { 0, SpritePrecision::None},
+        /* SpriteGroupType::Slopes25Banked22 */     { 0, SpritePrecision::None},
+        /* SpriteGroupType::Slopes8Banked22 */      { 0, SpritePrecision::None},
+        /* SpriteGroupType::Slopes16Banked22 */     { 0, SpritePrecision::None},
+        /* SpriteGroupType::Slopes16Banked45 */     { 0, SpritePrecision::None},
+        /* SpriteGroupType::Slopes25Banked45 */     { 0, SpritePrecision::None},
+        /* SpriteGroupType::Slopes12Banked45 */     { 0, SpritePrecision::None},
+        /* SpriteGroupType::Slopes25Banked67 */     { 0, SpritePrecision::None},
+        /* SpriteGroupType::Slopes25Banked90 */     { 0, SpritePrecision::None},
+        /* SpriteGroupType::Slopes25InlineTwists */ { 0, SpritePrecision::None},
+        /* SpriteGroupType::Slopes42Banked22 */     { 0, SpritePrecision::None},
+        /* SpriteGroupType::Slopes42Banked45 */     { 0, SpritePrecision::None},
+        /* SpriteGroupType::Slopes42Banked67 */     { 0, SpritePrecision::None},
+        /* SpriteGroupType::Slopes42Banked90 */     { 0, SpritePrecision::None},
+        /* SpriteGroupType::Slopes60Banked22 */     { 0, SpritePrecision::None},
+        /* SpriteGroupType::Corkscrews */           { 0, SpritePrecision::None},
+        /* SpriteGroupType::RestraintAnimation */   { 0, SpritePrecision::None},
+        /* SpriteGroupType::CurvedLiftHillUp */     { 0, SpritePrecision::None},
+        /* SpriteGroupType::CurvedLiftHillDown */   { 0, SpritePrecision::None},
+    },
+    .NumCarImages = 0,
+    .no_seating_rows = 0,
+    .spinning_inertia = 0,
+    .spinning_friction = 255,
+    .friction_sound_id = Audio::SoundId::LiftClassic,
+    .ReversedCarIndex = 0,
+    .sound_range = 0,
+    .double_sound_frequency = 0,
+    .powered_acceleration = 0,
+    .powered_max_speed = 0,
+    .PaintStyle = 0,
+    .effect_visual = 1,
+    .draw_order = 14,
+    .num_vertical_frames_override = 0,
+    .peep_loading_waypoint_segments = 0,
+    .AnimationSpeed = 0,
+    .AnimationFrames = 0,
+    .SteamEffect = {
+        .Longitudinal = 0,
+        .Vertical = 0,
+    },
 };
 
 /* rct2: 0x009A0AA0 */
@@ -344,6 +351,7 @@ constexpr RideTypeDescriptor RideTypeDescriptors[RIDE_TYPE_COUNT] = {
     /* RIDE_TYPE_SINGLE_RAIL_ROLLER_COASTER         */ SingleRailRollerCoasterRTD,
     /* RIDE_TYPE_ALPINE_COASTER                     */ AlpineCoasterRTD,
     /* RIDE_TYPE_CLASSIC_WOODEN_ROLLER_COASTER      */ ClassicWoodenRollerCoasterRTD,
+    /* RIDE_TYPE_CLASSIC_STAND_UP_ROLLER_COASTER    */ ClassicStandUpRollerCoasterRTD,
 };
 
 bool RideTypeDescriptor::HasFlag(uint64_t flag) const
@@ -354,13 +362,14 @@ bool RideTypeDescriptor::HasFlag(uint64_t flag) const
 void RideTypeDescriptor::GetAvailableTrackPieces(RideTrackGroup& res) const
 {
     res = EnabledTrackPieces;
-    if (gCheatsEnableAllDrawableTrackPieces)
+    if (GetGameState().Cheats.EnableAllDrawableTrackPieces)
         res |= ExtraTrackPieces;
 }
 
 bool RideTypeDescriptor::SupportsTrackPiece(const uint64_t trackPiece) const
 {
-    return EnabledTrackPieces.get(trackPiece) || (gCheatsEnableAllDrawableTrackPieces && ExtraTrackPieces.get(trackPiece));
+    return EnabledTrackPieces.get(trackPiece)
+        || (GetGameState().Cheats.EnableAllDrawableTrackPieces && ExtraTrackPieces.get(trackPiece));
 }
 
 ResearchCategory RideTypeDescriptor::GetResearchCategory() const
@@ -403,7 +412,7 @@ void UpdateEnabledRidePieces(ride_type_t rideType)
 {
     GetRideTypeDescriptor(rideType).GetAvailableTrackPieces(_enabledRidePieces);
 
-    if (!gCheatsEnableAllDrawableTrackPieces)
+    if (!GetGameState().Cheats.EnableAllDrawableTrackPieces)
     {
         _enabledRidePieces &= ~_disabledRidePieces;
     }
