@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2023 OpenRCT2 developers
+ * Copyright (c) 2014-2024 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -19,7 +19,7 @@ using track_type_t = uint16_t;
 // Convenience function for writing ride ratings. The result is a 16 bit signed
 // integer. To create the ride rating 3.65 type RIDE_RATING(3,65)
 #define RIDE_RATING(whole, fraction) FIXED_2DP(whole, fraction)
-#define RIDE_RATING_UNDEFINED static_cast<ride_rating>(static_cast<uint16_t>(0xFFFF))
+constexpr ride_rating kRideRatingUndefined = 0xFFFFu;
 
 #pragma pack(push, 1)
 
@@ -55,10 +55,8 @@ struct RideRatingUpdateState
 };
 
 static constexpr size_t RideRatingMaxUpdateStates = 4;
-
 using RideRatingUpdateStates = std::array<RideRatingUpdateState, RideRatingMaxUpdateStates>;
 
-RideRatingUpdateStates& RideRatingGetUpdateStates();
 void RideRatingResetUpdateStates();
 
 void RideRatingsUpdateRide(const Ride& ride);
