@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2023 OpenRCT2 developers
+ * Copyright (c) 2014-2024 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -23,25 +23,45 @@ constexpr int32_t kBlockBrakeBaseSpeed = 0x20364;
 constexpr int32_t kBlockBrakeSpeedOffset = kBlockBrakeBaseSpeed - (kRCT2DefaultBlockBrakeSpeed << 16);
 
 using track_type_t = uint16_t;
-using roll_type_t = uint8_t;
-using pitch_type_t = uint8_t;
 
 struct ResultWithMessage;
 
+enum class TrackRoll : uint8_t
+{
+    None = 0,
+    Left = 2,
+    Right = 4,
+    UpsideDown = 15,
+};
+
+enum class TrackPitch : uint8_t
+{
+    None = 0,
+    Up25 = 2,
+    Up60 = 4,
+    Down25 = 6,
+    Down60 = 8,
+    Up90 = 10,
+    Down90 = 18,
+
+    Tower = 10,
+    ReverseFreefall = 10
+};
+
 struct TrackDefinition
 {
-    track_type_t type;
-    pitch_type_t vangle_end;
-    pitch_type_t vangle_start;
-    roll_type_t bank_end;
-    roll_type_t bank_start;
-    int8_t preview_z_offset;
+    track_type_t Type;
+    TrackPitch PitchEnd;
+    TrackPitch PitchStart;
+    TrackRoll RollEnd;
+    TrackRoll RollStart;
+    int8_t PreviewZOffset;
 };
 
 struct PitchAndRoll
 {
-    pitch_type_t Pitch;
-    roll_type_t Roll;
+    TrackPitch Pitch;
+    TrackRoll Roll;
 };
 constexpr bool operator==(const PitchAndRoll& vb1, const PitchAndRoll& vb2)
 {
@@ -59,7 +79,7 @@ struct PreviewTrack
     int16_t x;     // 0x01
     int16_t y;     // 0x03
     int16_t z;     // 0x05
-    uint8_t var_07;
+    uint8_t ClearanceZ;
     QuarterTile var_08;
     uint8_t flags;
 };
@@ -103,7 +123,7 @@ enum
     TRACK_ELEMENT_COLOUR_SEAT_ROTATION_MASK = 0b11110000,
 };
 
-#define MAX_STATION_PLATFORM_LENGTH 32
+constexpr int8_t kMaxStationPlatformLength = 32;
 constexpr uint16_t const MAX_TRACK_HEIGHT = 254 * COORDS_Z_STEP;
 constexpr uint8_t const DEFAULT_SEAT_ROTATION = 4;
 
@@ -206,39 +226,17 @@ enum
     TRACK_GROUP_COUNT,
 };
 
-enum
+enum class TrackCurve : uint8_t
 {
-    TRACK_CURVE_LEFT_VERY_SMALL = 5,
-    TRACK_CURVE_LEFT_SMALL = 3,
-    TRACK_CURVE_LEFT = 1,
-    TRACK_CURVE_LEFT_LARGE = 7,
-    TRACK_CURVE_NONE = 0,
-    TRACK_CURVE_RIGHT_LARGE = 8,
-    TRACK_CURVE_RIGHT = 2,
-    TRACK_CURVE_RIGHT_SMALL = 4,
-    TRACK_CURVE_RIGHT_VERY_SMALL = 6
-};
-
-enum
-{
-    TRACK_SLOPE_NONE = 0,
-    TRACK_SLOPE_UP_25 = 2,
-    TRACK_SLOPE_UP_60 = 4,
-    TRACK_SLOPE_DOWN_25 = 6,
-    TRACK_SLOPE_DOWN_60 = 8,
-    TRACK_SLOPE_UP_90 = 10,
-    TRACK_SLOPE_DOWN_90 = 18,
-
-    TRACK_VANGLE_TOWER = 10,
-    TRACK_VANGLE_REVERSE_FREEFALL = 10
-};
-
-enum
-{
-    TRACK_BANK_NONE = 0,
-    TRACK_BANK_LEFT = 2,
-    TRACK_BANK_RIGHT = 4,
-    TRACK_BANK_UPSIDE_DOWN = 15,
+    LeftVerySmall = 5,
+    LeftSmall = 3,
+    Left = 1,
+    LeftLarge = 7,
+    None = 0,
+    RightLarge = 8,
+    Right = 2,
+    RightSmall = 4,
+    RightVerySmall = 6
 };
 
 enum
@@ -261,6 +259,7 @@ enum
     TRACK_ELEM_FLAG_CURVE_ALLOWS_LIFT = (1 << 13),
     TRACK_ELEM_FLAG_INVERSION_TO_NORMAL = (1 << 14),
     TRACK_ELEM_FLAG_BANKED = (1 << 15), // Also set on Spinning Tunnel and Log Flume reverser, probably to save a flag.
+    TRACK_ELEM_FLAG_CAN_BE_PARTLY_UNDERGROUND = (1 << 16),
 };
 
 namespace TrackElemType
@@ -688,9 +687,9 @@ bool TrackTypeIsBooster(track_type_t trackType);
 std::optional<CoordsXYZ> GetTrackElementOriginAndApplyChanges(
     const CoordsXYZD& location, track_type_t type, uint16_t extra_params, TileElement** output_element, uint16_t flags);
 
-roll_type_t TrackGetActualBank(TileElement* tileElement, roll_type_t bank);
-roll_type_t TrackGetActualBank2(int32_t rideType, bool isInverted, roll_type_t bank);
-roll_type_t TrackGetActualBank3(bool useInvertedSprites, TileElement* tileElement);
+TrackRoll TrackGetActualBank(TileElement* tileElement, TrackRoll bank);
+TrackRoll TrackGetActualBank2(int32_t rideType, bool isInverted, TrackRoll bank);
+TrackRoll TrackGetActualBank3(bool useInvertedSprites, TileElement* tileElement);
 
 ResultWithMessage TrackAddStationElement(CoordsXYZD loc, RideId rideIndex, int32_t flags, bool fromTrackDesign);
 ResultWithMessage TrackRemoveStationElement(const CoordsXYZD& loc, RideId rideIndex, int32_t flags);
