@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2023 OpenRCT2 developers
+ * Copyright (c) 2014-2024 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -12,6 +12,7 @@
 #include "../Cheats.h"
 #include "../Context.h"
 #include "../Game.h"
+#include "../GameState.h"
 #include "../OpenRCT2.h"
 #include "../TrackImporter.h"
 #include "../actions/FootpathLayoutPlaceAction.h"
@@ -47,8 +48,7 @@
 #include "../object/ObjectRepository.h"
 #include "../object/SmallSceneryEntry.h"
 #include "../object/StationObject.h"
-#include "../rct1/RCT1.h"
-#include "../rct1/Tables.h"
+#include "../rct2/RCT2.h"
 #include "../ride/RideConstruction.h"
 #include "../util/SawyerCoding.h"
 #include "../util/Util.h"
@@ -83,6 +83,15 @@ static bool _trackDesignPlaceStateEntranceExitPlaced{};
 
 static void TrackDesignPreviewClearMap();
 
+static u8string_view TrackDesignGetStationObjectIdentifier(const Ride& ride)
+{
+    const auto* stationObject = ride.GetStationObject();
+    if (stationObject == nullptr)
+        return "";
+
+    return stationObject->GetIdentifier();
+}
+
 ResultWithMessage TrackDesign::CreateTrackDesign(TrackDesignState& tds, const Ride& ride)
 {
     type = ride.type;
@@ -102,12 +111,12 @@ ResultWithMessage TrackDesign::CreateTrackDesign(TrackDesignState& tds, const Ri
     ride_mode = ride.mode;
     colour_scheme = ride.colour_scheme_type & 3;
 
-    for (int32_t i = 0; i < RCT2::Limits::MaxTrainsPerRide; i++)
+    for (size_t i = 0; i < std::size(vehicle_colours); i++)
     {
         vehicle_colours[i] = ride.vehicle_colours[i];
     }
 
-    for (int32_t i = 0; i < RCT12::Limits::NumColourSchemes; i++)
+    for (int32_t i = 0; i < OpenRCT2::Limits::NumColourSchemes; i++)
     {
         track_spine_colour[i] = ride.track_colour[i].main;
         track_rail_colour[i] = ride.track_colour[i].additional;
@@ -123,7 +132,7 @@ ResultWithMessage TrackDesign::CreateTrackDesign(TrackDesignState& tds, const Ri
     lift_hill_speed = ride.lift_hill_speed;
     num_circuits = ride.num_circuits;
 
-    entrance_style = ride.GetEntranceStyle();
+    StationObjectIdentifier = TrackDesignGetStationObjectIdentifier(ride);
     max_speed = static_cast<int8_t>(ride.max_speed / 65536);
     average_speed = static_cast<int8_t>(ride.average_speed / 65536);
     ride_length = ride.GetTotalLength() / 65536;
@@ -298,32 +307,27 @@ ResultWithMessage TrackDesign::CreateTrackDesignTrack(TrackDesignState& tds, con
 
             Direction entranceDirection = tileElement->GetDirection();
             entranceDirection -= _saveDirection;
-            entranceDirection &= TILE_ELEMENT_DIRECTION_MASK;
-
-            TrackDesignEntranceElement entrance{};
-            entrance.direction = entranceDirection;
+            entranceDirection &= kTileElementDirectionMask;
 
             mapLocation -= tds.Origin;
-
             // Rotate entrance coordinates backwards to the correct direction
-            auto rotatedMapLocation = mapLocation.Rotate(0 - _saveDirection);
-            entrance.x = rotatedMapLocation.x;
-            entrance.y = rotatedMapLocation.y;
+            auto rotatedMapLocation = TileCoordsXY(mapLocation.Rotate(0 - _saveDirection));
 
             z -= tds.Origin.z;
-            z /= 8;
+            z /= COORDS_Z_STEP;
 
             if (z > 127 || z < -126)
             {
                 return { false, STR_TRACK_TOO_LARGE_OR_TOO_MUCH_SCENERY };
             }
 
-            entrance.z = z;
+            TrackDesignEntranceElement entrance{};
+            entrance.Location = TileCoordsXYZD(rotatedMapLocation, z, entranceDirection);
 
             // If this is the exit version
             if (i == 1)
             {
-                entrance.isExit = true;
+                entrance.IsExit = true;
             }
             entrance_elements.push_back(entrance);
         }
@@ -409,13 +413,11 @@ ResultWithMessage TrackDesign::CreateTrackDesignMaze(TrackDesignState& tds, cons
     } while (!(tileElement++)->IsLastForTile());
     // Add something that stops this from walking off the end
 
-    uint8_t entranceDirection = tileElement->GetDirection();
-    TrackDesignMazeElement mazeEntrance{};
-    mazeEntrance.direction = entranceDirection;
-    mazeEntrance.type = 8;
-    mazeEntrance.x = static_cast<int8_t>((entranceLoc.x - startLoc.x) / 32);
-    mazeEntrance.y = static_cast<int8_t>((entranceLoc.y - startLoc.y) / 32);
-    maze_elements.push_back(mazeEntrance);
+    auto entranceOffset = entranceLoc - startLoc;
+    TrackDesignEntranceElement mazeEntrance{};
+    mazeEntrance.Location = TileCoordsXYZD(CoordsXYZD(entranceOffset, 0, tileElement->GetDirection()));
+    mazeEntrance.IsExit = false;
+    entrance_elements.push_back(mazeEntrance);
 
     location = ride.GetStation().Exit;
     if (location.IsNull())
@@ -438,13 +440,11 @@ ResultWithMessage TrackDesign::CreateTrackDesignMaze(TrackDesignState& tds, cons
     } while (!(tileElement++)->IsLastForTile());
     // Add something that stops this from walking off the end
 
-    uint8_t exit_direction = tileElement->GetDirection();
-    TrackDesignMazeElement mazeExit{};
-    mazeExit.direction = exit_direction;
-    mazeExit.type = 0x80;
-    mazeExit.x = static_cast<int8_t>((exitLoc.x - startLoc.x) / 32);
-    mazeExit.y = static_cast<int8_t>((exitLoc.y - startLoc.y) / 32);
-    maze_elements.push_back(mazeExit);
+    auto exitOffset = exitLoc - startLoc;
+    TrackDesignEntranceElement mazeExit{};
+    mazeExit.Location = TileCoordsXYZD(CoordsXYZD(exitOffset, 0, tileElement->GetDirection()));
+    mazeExit.IsExit = true;
+    entrance_elements.push_back(mazeExit);
 
     // Save global vars as they are still used by scenery????
     int32_t startZ = tds.Origin.z;
@@ -570,7 +570,7 @@ void TrackDesign::Serialise(DataSerialiser& stream)
     stream << DS_TAG(track_flags);
     stream << DS_TAG(colour_scheme);
     stream << DS_TAG(vehicle_colours);
-    stream << DS_TAG(entrance_style);
+    stream << DS_TAG(StationObjectIdentifier);
     stream << DS_TAG(total_air_time);
     stream << DS_TAG(depart_flags);
     stream << DS_TAG(number_of_trains);
@@ -743,7 +743,7 @@ static std::optional<TrackSceneryEntry> TrackDesignPlaceSceneryElementGetEntry(c
         {
             result.Type = obj->GetObjectType();
             result.Index = objectMgr.GetLoadedObjectEntryIndex(obj);
-            if (!gCheatsIgnoreResearchStatus)
+            if (!GetGameState().Cheats.IgnoreResearchStatus)
             {
                 objectUnavailable = !ResearchIsInvented(result.Type, result.Index);
             }
@@ -871,6 +871,18 @@ static void TrackDesignMirrorScenery(TrackDesign* td6)
     }
 }
 
+static void TrackDesignMirrorEntrances(TrackDesign& td)
+{
+    for (auto& entrance : td.entrance_elements)
+    {
+        entrance.Location.y = -entrance.Location.y;
+        if (entrance.Location.direction & 1)
+        {
+            entrance.Location.direction = DirectionReverse(entrance.Location.direction);
+        }
+    }
+}
+
 /**
  *
  *  rct2: 0x006D2443
@@ -882,15 +894,6 @@ static void TrackDesignMirrorRide(TrackDesign* td6)
         const auto& ted = GetTrackElementDescriptor(track.Type);
         track.Type = ted.MirrorElement;
     }
-
-    for (auto& entrance : td6->entrance_elements)
-    {
-        entrance.y = -entrance.y;
-        if (entrance.direction & 1)
-        {
-            entrance.direction = DirectionReverse(entrance.direction);
-        }
-    }
 }
 
 /** rct2: 0x00993EDC */
@@ -908,15 +911,6 @@ static void TrackDesignMirrorMaze(TrackDesign* td6)
     {
         maze.y = -maze.y;
 
-        if (maze.type == 0x8 || maze.type == 0x80)
-        {
-            if (maze.direction & 1)
-            {
-                maze.direction = DirectionReverse(maze.direction);
-            }
-            continue;
-        }
-
         uint16_t maze_entry = maze.maze_entry;
         uint16_t new_entry = 0;
         for (uint8_t position = UtilBitScanForward(maze_entry); position != 0xFF; position = UtilBitScanForward(maze_entry))
@@ -943,6 +937,7 @@ void TrackDesignMirror(TrackDesign* td6)
     {
         TrackDesignMirrorRide(td6);
     }
+    TrackDesignMirrorEntrances(*td6);
     TrackDesignMirrorScenery(td6);
 }
 
@@ -978,7 +973,7 @@ static GameActions::Result TrackDesignPlaceSceneryElementRemoveGhost(
     }
 
     int32_t z = scenery.loc.z + originZ;
-    uint8_t sceneryRotation = (rotation + scenery.flags) & TILE_ELEMENT_DIRECTION_MASK;
+    uint8_t sceneryRotation = (rotation + scenery.flags) & kTileElementDirectionMask;
     const uint32_t flags = GAME_COMMAND_FLAG_APPLY | GAME_COMMAND_FLAG_ALLOW_DURING_PAUSED | GAME_COMMAND_FLAG_NO_SPEND
         | GAME_COMMAND_FLAG_GHOST;
     std::unique_ptr<GameAction> ga;
@@ -1344,27 +1339,131 @@ static GameActions::Result TrackDesignPlaceAllScenery(
     return res;
 }
 
+static std::optional<GameActions::Result> TrackDesignPlaceEntrances(
+    TrackDesignState& tds, const TrackDesign& td, CoordsXYZ newCoords, RideId rideId, money64& totalCost)
+{
+    for (const auto& entrance : td.entrance_elements)
+    {
+        auto rotation = _currentTrackPieceDirection & 3;
+        CoordsXY entranceMapPos = entrance.Location.ToCoordsXY();
+        auto rotatedEntranceMapPos = entranceMapPos.Rotate(rotation);
+        newCoords = { rotatedEntranceMapPos + tds.Origin, newCoords.z };
+
+        TrackDesignUpdatePreviewBounds(tds, newCoords);
+
+        switch (tds.PlaceOperation)
+        {
+            case PTD_OPERATION_DRAW_OUTLINES:
+                TrackDesignAddSelectedTile(newCoords);
+                break;
+            case PTD_OPERATION_PLACE_QUERY:
+            case PTD_OPERATION_PLACE:
+            case PTD_OPERATION_PLACE_GHOST:
+            case PTD_OPERATION_PLACE_TRACK_PREVIEW:
+            {
+                rotation = (rotation + entrance.Location.direction) & 3;
+                newCoords.z = entrance.Location.z * COORDS_Z_STEP;
+                newCoords.z += tds.Origin.z;
+
+                if (tds.PlaceOperation != PTD_OPERATION_PLACE_QUERY)
+                {
+                    auto tile = CoordsXY{ newCoords } + CoordsDirectionDelta[rotation];
+                    TileElement* tile_element = MapGetFirstElementAt(tile);
+                    if (tile_element == nullptr)
+                    {
+                        return GameActions::Result(
+                            GameActions::Status::InvalidParameters, STR_ERR_INVALID_PARAMETER, STR_ERR_TILE_ELEMENT_NOT_FOUND);
+                    }
+
+                    do
+                    {
+                        if (tile_element->GetType() != TileElementType::Track)
+                        {
+                            continue;
+                        }
+                        if (tile_element->GetBaseZ() != newCoords.z)
+                        {
+                            continue;
+                        }
+
+                        auto stationIndex = tile_element->AsTrack()->GetStationIndex();
+                        uint8_t flags = GAME_COMMAND_FLAG_APPLY;
+                        if (tds.PlaceOperation == PTD_OPERATION_PLACE_TRACK_PREVIEW)
+                        {
+                            flags = GAME_COMMAND_FLAG_APPLY | GAME_COMMAND_FLAG_ALLOW_DURING_PAUSED
+                                | GAME_COMMAND_FLAG_NO_SPEND;
+                        }
+                        if (tds.PlaceOperation == PTD_OPERATION_PLACE_GHOST)
+                        {
+                            flags = GAME_COMMAND_FLAG_APPLY | GAME_COMMAND_FLAG_ALLOW_DURING_PAUSED | GAME_COMMAND_FLAG_NO_SPEND
+                                | GAME_COMMAND_FLAG_GHOST;
+                        }
+                        if (tds.PlaceOperation == PTD_OPERATION_PLACE_QUERY)
+                        {
+                            flags = 0;
+                        }
+                        if (tds.IsReplay)
+                        {
+                            flags |= GAME_COMMAND_FLAG_REPLAY;
+                        }
+
+                        auto rideEntranceExitPlaceAction = RideEntranceExitPlaceAction(
+                            newCoords, rotation, rideId, stationIndex, entrance.IsExit);
+                        rideEntranceExitPlaceAction.SetFlags(flags);
+                        auto res = flags & GAME_COMMAND_FLAG_APPLY ? GameActions::ExecuteNested(&rideEntranceExitPlaceAction)
+                                                                   : GameActions::QueryNested(&rideEntranceExitPlaceAction);
+
+                        if (res.Error != GameActions::Status::Ok)
+                        {
+                            return res;
+                        }
+                        totalCost += res.Cost;
+                        tds.EntranceExitPlaced = true;
+                        _trackDesignPlaceStateEntranceExitPlaced = true;
+                        break;
+                    } while (!(tile_element++)->IsLastForTile());
+                }
+                else
+                {
+                    auto res = RideEntranceExitPlaceAction::TrackPlaceQuery(newCoords, false);
+                    if (res.Error != GameActions::Status::Ok)
+                    {
+                        return res;
+                    }
+
+                    totalCost += res.Cost;
+                    tds.EntranceExitPlaced = true;
+                    _trackDesignPlaceStateEntranceExitPlaced = true;
+                }
+                break;
+            }
+        }
+    }
+
+    return std::nullopt;
+}
+
 static GameActions::Result TrackDesignPlaceMaze(
-    TrackDesignState& tds, TrackDesign* td6, const CoordsXYZ& coords, const Ride& ride)
+    TrackDesignState& tds, TrackDesign& td, const CoordsXYZ& origin, const Ride& ride)
 {
     if (tds.PlaceOperation == PTD_OPERATION_DRAW_OUTLINES)
     {
         gMapSelectionTiles.clear();
-        gMapSelectArrowPosition = CoordsXYZ{ coords, TileElementHeight(coords) };
+        gMapSelectArrowPosition = CoordsXYZ{ origin, TileElementHeight(origin) };
         gMapSelectArrowDirection = _currentTrackPieceDirection;
     }
 
     tds.PlaceZ = 0;
     money64 totalCost = 0;
 
-    for (const auto& maze_element : td6->maze_elements)
+    for (const auto& maze_element : td.maze_elements)
     {
         uint8_t rotation = _currentTrackPieceDirection & 3;
         CoordsXY mazeMapPos = TileCoordsXY(maze_element.x, maze_element.y).ToCoordsXY();
         auto mapCoord = mazeMapPos.Rotate(rotation);
-        mapCoord += coords;
+        mapCoord += origin;
 
-        TrackDesignUpdatePreviewBounds(tds, { mapCoord, coords.z });
+        TrackDesignUpdatePreviewBounds(tds, { mapCoord, origin.z });
 
         if (tds.PlaceOperation == PTD_OPERATION_DRAW_OUTLINES)
         {
@@ -1376,135 +1475,40 @@ static GameActions::Result TrackDesignPlaceMaze(
         {
             uint8_t flags;
             money64 cost = 0;
-            uint16_t maze_entry;
-            switch (maze_element.type)
+
+            uint16_t maze_entry = Numerics::rol16(maze_element.maze_entry, rotation * 4);
+
+            if (tds.PlaceOperation == PTD_OPERATION_PLACE_TRACK_PREVIEW)
             {
-                case MAZE_ELEMENT_TYPE_ENTRANCE:
-                    // entrance
-                    rotation += maze_element.direction;
-                    rotation &= 3;
-
-                    flags = GAME_COMMAND_FLAG_APPLY;
-
-                    if (tds.PlaceOperation == PTD_OPERATION_PLACE_QUERY)
-                    {
-                        auto res = RideEntranceExitPlaceAction::TrackPlaceQuery({ mapCoord, coords.z }, false);
-                        if (res.Error != GameActions::Status::Ok)
-                        {
-                            return res;
-                        }
-                        cost = res.Cost;
-                    }
-                    else
-                    {
-                        if (tds.PlaceOperation == PTD_OPERATION_PLACE_TRACK_PREVIEW)
-                        {
-                            flags = GAME_COMMAND_FLAG_APPLY | GAME_COMMAND_FLAG_ALLOW_DURING_PAUSED
-                                | GAME_COMMAND_FLAG_NO_SPEND;
-                        }
-                        else if (tds.PlaceOperation == PTD_OPERATION_PLACE_GHOST)
-                        {
-                            flags = GAME_COMMAND_FLAG_APPLY | GAME_COMMAND_FLAG_ALLOW_DURING_PAUSED | GAME_COMMAND_FLAG_NO_SPEND
-                                | GAME_COMMAND_FLAG_GHOST;
-                        }
-                        if (tds.IsReplay)
-                        {
-                            flags |= GAME_COMMAND_FLAG_REPLAY;
-                        }
-                        auto rideEntranceExitPlaceAction = RideEntranceExitPlaceAction(
-                            mapCoord, rotation, ride.id, StationIndex::FromUnderlying(0), false);
-                        rideEntranceExitPlaceAction.SetFlags(flags);
-                        auto res = GameActions::ExecuteNested(&rideEntranceExitPlaceAction);
-                        if (res.Error != GameActions::Status::Ok)
-                        {
-                            return res;
-                        }
-                        cost = res.Cost;
-                    }
-                    tds.EntranceExitPlaced = true;
-                    _trackDesignPlaceStateEntranceExitPlaced = true;
-                    break;
-                case MAZE_ELEMENT_TYPE_EXIT:
-                    // exit
-                    rotation += maze_element.direction;
-                    rotation &= 3;
-
-                    flags = GAME_COMMAND_FLAG_APPLY;
-
-                    if (tds.PlaceOperation == PTD_OPERATION_PLACE_QUERY)
-                    {
-                        auto res = RideEntranceExitPlaceAction::TrackPlaceQuery({ mapCoord, coords.z }, true);
-                        if (res.Error != GameActions::Status::Ok)
-                        {
-                            return res;
-                        }
-                        cost = res.Cost;
-                    }
-                    else
-                    {
-                        if (tds.PlaceOperation == PTD_OPERATION_PLACE_TRACK_PREVIEW)
-                        {
-                            flags = GAME_COMMAND_FLAG_APPLY | GAME_COMMAND_FLAG_ALLOW_DURING_PAUSED
-                                | GAME_COMMAND_FLAG_NO_SPEND;
-                        }
-                        else if (tds.PlaceOperation == PTD_OPERATION_PLACE_GHOST)
-                        {
-                            flags = GAME_COMMAND_FLAG_APPLY | GAME_COMMAND_FLAG_ALLOW_DURING_PAUSED | GAME_COMMAND_FLAG_NO_SPEND
-                                | GAME_COMMAND_FLAG_GHOST;
-                        }
-                        if (tds.IsReplay)
-                        {
-                            flags |= GAME_COMMAND_FLAG_REPLAY;
-                        }
-                        auto rideEntranceExitPlaceAction = RideEntranceExitPlaceAction(
-                            mapCoord, rotation, ride.id, StationIndex::FromUnderlying(0), true);
-                        rideEntranceExitPlaceAction.SetFlags(flags);
-                        auto res = GameActions::ExecuteNested(&rideEntranceExitPlaceAction);
-                        if (res.Error != GameActions::Status::Ok)
-                        {
-                            return res;
-                        }
-                        cost = res.Cost;
-                    }
-                    tds.EntranceExitPlaced = true;
-                    _trackDesignPlaceStateEntranceExitPlaced = true;
-                    break;
-                default:
-                    maze_entry = Numerics::rol16(maze_element.maze_entry, rotation * 4);
-
-                    if (tds.PlaceOperation == PTD_OPERATION_PLACE_TRACK_PREVIEW)
-                    {
-                        flags = GAME_COMMAND_FLAG_APPLY | GAME_COMMAND_FLAG_ALLOW_DURING_PAUSED | GAME_COMMAND_FLAG_NO_SPEND;
-                    }
-                    else if (tds.PlaceOperation == PTD_OPERATION_PLACE_GHOST)
-                    {
-                        flags = GAME_COMMAND_FLAG_APPLY | GAME_COMMAND_FLAG_ALLOW_DURING_PAUSED | GAME_COMMAND_FLAG_NO_SPEND
-                            | GAME_COMMAND_FLAG_GHOST;
-                    }
-                    else if (tds.PlaceOperation == PTD_OPERATION_PLACE_QUERY)
-                    {
-                        flags = 0;
-                    }
-                    else
-                    {
-                        flags = GAME_COMMAND_FLAG_APPLY;
-                    }
-                    if (tds.IsReplay)
-                    {
-                        flags |= GAME_COMMAND_FLAG_REPLAY;
-                    }
-
-                    auto mazePlace = MazePlaceTrackAction({ mapCoord, coords.z }, ride.id, maze_entry);
-                    mazePlace.SetFlags(flags);
-                    auto res = flags & GAME_COMMAND_FLAG_APPLY ? GameActions::ExecuteNested(&mazePlace)
-                                                               : GameActions::QueryNested(&mazePlace);
-                    if (res.Error != GameActions::Status::Ok)
-                    {
-                        return res;
-                    }
-                    cost = res.Cost;
-                    break;
+                flags = GAME_COMMAND_FLAG_APPLY | GAME_COMMAND_FLAG_ALLOW_DURING_PAUSED | GAME_COMMAND_FLAG_NO_SPEND;
             }
+            else if (tds.PlaceOperation == PTD_OPERATION_PLACE_GHOST)
+            {
+                flags = GAME_COMMAND_FLAG_APPLY | GAME_COMMAND_FLAG_ALLOW_DURING_PAUSED | GAME_COMMAND_FLAG_NO_SPEND
+                    | GAME_COMMAND_FLAG_GHOST;
+            }
+            else if (tds.PlaceOperation == PTD_OPERATION_PLACE_QUERY)
+            {
+                flags = 0;
+            }
+            else
+            {
+                flags = GAME_COMMAND_FLAG_APPLY;
+            }
+            if (tds.IsReplay)
+            {
+                flags |= GAME_COMMAND_FLAG_REPLAY;
+            }
+
+            auto mazePlace = MazePlaceTrackAction({ mapCoord, origin.z }, ride.id, maze_entry);
+            mazePlace.SetFlags(flags);
+            auto res = flags & GAME_COMMAND_FLAG_APPLY ? GameActions::ExecuteNested(&mazePlace)
+                                                       : GameActions::QueryNested(&mazePlace);
+            if (res.Error != GameActions::Status::Ok)
+            {
+                return res;
+            }
+            cost = res.Cost;
 
             totalCost += cost;
         }
@@ -1535,7 +1539,7 @@ static GameActions::Result TrackDesignPlaceMaze(
                 surfaceZ = waterZ;
             }
 
-            int16_t temp_z = coords.z + tds.PlaceZ - surfaceZ;
+            int16_t temp_z = origin.z + tds.PlaceZ - surfaceZ;
             if (temp_z < 0)
             {
                 tds.PlaceZ -= temp_z;
@@ -1543,6 +1547,14 @@ static GameActions::Result TrackDesignPlaceMaze(
         }
     }
 
+    tds.Origin = origin;
+
+    auto result = TrackDesignPlaceEntrances(tds, td, origin, ride.id, totalCost);
+    if (result.has_value())
+    {
+        return result.value();
+    }
+
     if (tds.PlaceOperation == PTD_OPERATION_REMOVE_GHOST)
     {
         auto gameAction = RideDemolishAction(ride.id, RIDE_MODIFY_DEMOLISH);
@@ -1550,8 +1562,6 @@ static GameActions::Result TrackDesignPlaceMaze(
         GameActions::Execute(&gameAction);
     }
 
-    tds.Origin = coords;
-
     auto res = GameActions::Result();
     res.Cost = totalCost;
 
@@ -1674,7 +1684,9 @@ static GameActions::Result TrackDesignPlaceRide(TrackDesignState& tds, TrackDesi
                     auto surfaceElement = MapGetSurfaceElementAt(tile);
                     if (surfaceElement == nullptr)
                     {
-                        return GameActions::Result(GameActions::Status::InvalidParameters, STR_NONE, STR_NONE);
+                        return GameActions::Result(
+                            GameActions::Status::InvalidParameters, STR_ERR_INVALID_PARAMETER,
+                            STR_ERR_SURFACE_ELEMENT_NOT_FOUND);
                     }
 
                     int32_t surfaceZ = surfaceElement->GetBaseZ();
@@ -1718,104 +1730,10 @@ static GameActions::Result TrackDesignPlaceRide(TrackDesignState& tds, TrackDesi
         }
     }
 
-    // Entrance elements
-    for (const auto& entrance : td6->entrance_elements)
+    auto result = TrackDesignPlaceEntrances(tds, *td6, newCoords, ride.id, totalCost);
+    if (result.has_value())
     {
-        rotation = _currentTrackPieceDirection & 3;
-        CoordsXY entranceMapPos{ entrance.x, entrance.y };
-        auto rotatedEntranceMapPos = entranceMapPos.Rotate(rotation);
-        newCoords = { rotatedEntranceMapPos + tds.Origin, newCoords.z };
-
-        TrackDesignUpdatePreviewBounds(tds, newCoords);
-
-        switch (tds.PlaceOperation)
-        {
-            case PTD_OPERATION_DRAW_OUTLINES:
-                TrackDesignAddSelectedTile(newCoords);
-                break;
-            case PTD_OPERATION_PLACE_QUERY:
-            case PTD_OPERATION_PLACE:
-            case PTD_OPERATION_PLACE_GHOST:
-            case PTD_OPERATION_PLACE_TRACK_PREVIEW:
-            {
-                rotation = (rotation + entrance.direction) & 3;
-                if (tds.PlaceOperation != PTD_OPERATION_PLACE_QUERY)
-                {
-                    auto tile = CoordsXY{ newCoords } + CoordsDirectionDelta[rotation];
-                    TileElement* tile_element = MapGetFirstElementAt(tile);
-                    newCoords.z = tds.Origin.z / COORDS_Z_STEP;
-                    newCoords.z += entrance.z;
-                    if (tile_element == nullptr)
-                    {
-                        return GameActions::Result(GameActions::Status::InvalidParameters, STR_NONE, STR_NONE);
-                    }
-
-                    do
-                    {
-                        if (tile_element->GetType() != TileElementType::Track)
-                        {
-                            continue;
-                        }
-                        if (tile_element->BaseHeight != newCoords.z)
-                        {
-                            continue;
-                        }
-
-                        auto stationIndex = tile_element->AsTrack()->GetStationIndex();
-                        uint8_t flags = GAME_COMMAND_FLAG_APPLY;
-                        if (tds.PlaceOperation == PTD_OPERATION_PLACE_TRACK_PREVIEW)
-                        {
-                            flags = GAME_COMMAND_FLAG_APPLY | GAME_COMMAND_FLAG_ALLOW_DURING_PAUSED
-                                | GAME_COMMAND_FLAG_NO_SPEND;
-                        }
-                        if (tds.PlaceOperation == PTD_OPERATION_PLACE_GHOST)
-                        {
-                            flags = GAME_COMMAND_FLAG_APPLY | GAME_COMMAND_FLAG_ALLOW_DURING_PAUSED | GAME_COMMAND_FLAG_NO_SPEND
-                                | GAME_COMMAND_FLAG_GHOST;
-                        }
-                        if (tds.PlaceOperation == PTD_OPERATION_PLACE_QUERY)
-                        {
-                            flags = 0;
-                        }
-                        if (tds.IsReplay)
-                        {
-                            flags |= GAME_COMMAND_FLAG_REPLAY;
-                        }
-
-                        auto rideEntranceExitPlaceAction = RideEntranceExitPlaceAction(
-                            newCoords, rotation, ride.id, stationIndex, entrance.isExit);
-                        rideEntranceExitPlaceAction.SetFlags(flags);
-                        auto res = flags & GAME_COMMAND_FLAG_APPLY ? GameActions::ExecuteNested(&rideEntranceExitPlaceAction)
-                                                                   : GameActions::QueryNested(&rideEntranceExitPlaceAction);
-
-                        if (res.Error != GameActions::Status::Ok)
-                        {
-                            return res;
-                        }
-                        totalCost += res.Cost;
-                        tds.EntranceExitPlaced = true;
-                        _trackDesignPlaceStateEntranceExitPlaced = true;
-                        break;
-                    } while (!(tile_element++)->IsLastForTile());
-                }
-                else
-                {
-                    newCoords.z = entrance.z * COORDS_Z_STEP;
-                    newCoords.z += tds.Origin.z;
-
-                    auto res = RideEntranceExitPlaceAction::TrackPlaceQuery(newCoords, false);
-                    if (res.Error != GameActions::Status::Ok)
-                    {
-                        return GameActions::Result(GameActions::Status::InvalidParameters, STR_NONE, STR_NONE);
-                    }
-
-                    totalCost += res.Cost;
-                    tds.EntranceExitPlaced = true;
-                    _trackDesignPlaceStateEntranceExitPlaced = true;
-                }
-                break;
-            }
-        }
+        return result.value();
     }
 
     if (tds.PlaceOperation == PTD_OPERATION_REMOVE_GHOST)
@@ -1824,7 +1742,7 @@ static GameActions::Result TrackDesignPlaceRide(TrackDesignState& tds, TrackDesi
         ride.Delete();
     }
 
-    auto res = GameActions::Result(GameActions::Status::Ok, STR_NONE, STR_NONE);
+    auto res = GameActions::Result();
     res.Cost = totalCost;
 
     return res;
@@ -1876,7 +1794,7 @@ static GameActions::Result TrackDesignPlaceVirtual(
     const auto& rtd = GetRideTypeDescriptor(td6->type);
     if (rtd.HasFlag(RIDE_TYPE_FLAG_IS_MAZE))
     {
-        trackPlaceRes = TrackDesignPlaceMaze(tds, td6, coords, ride);
+        trackPlaceRes = TrackDesignPlaceMaze(tds, *td6, coords, ride);
     }
     else
     {
@@ -1955,15 +1873,15 @@ int32_t TrackDesignGetZPlacement(TrackDesign* td6, Ride& ride, const CoordsXYZD&
 static money64 TrackDesignCreateRide(int32_t type, int32_t subType, int32_t flags, RideId* outRideIndex)
 {
     // Don't set colours as will be set correctly later.
-    auto gameAction = RideCreateAction(type, subType, 0, 0, gLastEntranceStyle);
+    auto gameAction = RideCreateAction(type, subType, 0, 0, GetGameState().LastEntranceStyle);
     gameAction.SetFlags(flags);
 
     auto res = GameActions::ExecuteNested(&gameAction);
 
-    // Callee's of this function expect MONEY64_UNDEFINED in case of failure.
+    // Callee's of this function expect kMoney64Undefined in case of failure.
     if (res.Error != GameActions::Status::Ok)
     {
-        return MONEY64_UNDEFINED;
+        return kMoney64Undefined;
     }
 
     *outRideIndex = res.GetData<RideId>();
@@ -1982,12 +1900,13 @@ static bool TrackDesignPlacePreview(TrackDesignState& tds, TrackDesign* td6, mon
     *outRide = nullptr;
     *flags = 0;
 
+    auto& gameState = GetGameState();
     auto& objManager = GetContext()->GetObjectManager();
     auto entry_index = objManager.GetLoadedObjectEntryIndex(td6->vehicle_object);
 
     RideId rideIndex;
     uint8_t rideCreateFlags = GAME_COMMAND_FLAG_APPLY | GAME_COMMAND_FLAG_ALLOW_DURING_PAUSED | GAME_COMMAND_FLAG_NO_SPEND;
-    if (TrackDesignCreateRide(td6->type, entry_index, rideCreateFlags, &rideIndex) == MONEY64_UNDEFINED)
+    if (TrackDesignCreateRide(td6->type, entry_index, rideCreateFlags, &rideIndex) == kMoney64Undefined)
     {
         return false;
     }
@@ -1998,14 +1917,13 @@ static bool TrackDesignPlacePreview(TrackDesignState& tds, TrackDesign* td6, mon
 
     ride->custom_name = {};
 
-    auto stationIdentifier = GetStationIdentifierFromStyle(td6->entrance_style);
-    ride->entrance_style = objManager.GetLoadedObjectEntryIndex(stationIdentifier);
+    ride->entrance_style = objManager.GetLoadedObjectEntryIndex(td6->StationObjectIdentifier);
     if (ride->entrance_style == OBJECT_ENTRY_INDEX_NULL)
     {
-        ride->entrance_style = gLastEntranceStyle;
+        ride->entrance_style = gameState.LastEntranceStyle;
     }
 
-    for (int32_t i = 0; i < RCT12::Limits::NumColourSchemes; i++)
+    for (int32_t i = 0; i < OpenRCT2::Limits::NumColourSchemes; i++)
     {
         ride->track_colour[i].main = td6->track_spine_colour[i];
         ride->track_colour[i].additional = td6->track_rail_colour[i];
@@ -2016,7 +1934,7 @@ static bool TrackDesignPlacePreview(TrackDesignState& tds, TrackDesign* td6, mon
     // in the preview window
     if (!GetRideTypeDescriptor(td6->type).HasFlag(RIDE_TYPE_FLAG_HAS_TRACK))
     {
-        for (int32_t i = 0; i < RCT12::Limits::MaxVehicleColours; i++)
+        for (size_t i = 0; i < std::size(ride->vehicle_colours); i++)
         {
             ride->vehicle_colours[i] = td6->vehicle_colours[i];
         }
@@ -2024,9 +1942,9 @@ static bool TrackDesignPlacePreview(TrackDesignState& tds, TrackDesign* td6, mon
 
     _trackDesignDrawingPreview = true;
     uint8_t backup_rotation = _currentTrackPieceDirection;
-    uint32_t backup_park_flags = gParkFlags;
-    gParkFlags &= ~PARK_FLAGS_FORBID_HIGH_CONSTRUCTION;
-    auto mapSize = TileCoordsXY{ gMapSize.x * 16, gMapSize.y * 16 };
+    uint32_t backup_park_flags = gameState.ParkFlags;
+    gameState.ParkFlags &= ~PARK_FLAGS_FORBID_HIGH_CONSTRUCTION;
+    auto mapSize = TileCoordsXY{ gameState.MapSize.x * 16, gameState.MapSize.y * 16 };
 
     _currentTrackPieceDirection = 0;
     int32_t z = TrackDesignGetZPlacement(
@@ -2049,7 +1967,7 @@ static bool TrackDesignPlacePreview(TrackDesignState& tds, TrackDesign* td6, mon
     auto res = TrackDesignPlaceVirtual(
         tds, td6, PTD_OPERATION_PLACE_TRACK_PREVIEW, placeScenery, *ride,
         { mapSize.x, mapSize.y, z, _currentTrackPieceDirection });
-    gParkFlags = backup_park_flags;
+    gameState.ParkFlags = backup_park_flags;
 
     if (res.Error == GameActions::Status::Ok)
     {
@@ -2057,7 +1975,7 @@ static bool TrackDesignPlacePreview(TrackDesignState& tds, TrackDesign* td6, mon
         {
             *flags |= TRACK_DESIGN_FLAG_VEHICLE_UNAVAILABLE;
         }
-        else if (!RideEntryIsInvented(entry_index) && !gCheatsIgnoreResearchStatus)
+        else if (!RideEntryIsInvented(entry_index) && !GetGameState().Cheats.IgnoreResearchStatus)
         {
             *flags |= TRACK_DESIGN_FLAG_VEHICLE_UNAVAILABLE;
         }
@@ -2098,7 +2016,7 @@ void TrackDesignDrawPreview(TrackDesign* td6, uint8_t* pixels)
     uint8_t flags;
     if (!TrackDesignPlacePreview(tds, td6, &cost, &ride, &flags))
     {
-        std::fill_n(pixels, TRACK_PREVIEW_IMAGE_SIZE * 4, 0x00);
+        std::fill_n(pixels, kTrackPreviewImageSize * 4, 0x00);
         UnstashMap();
         return;
     }
@@ -2163,12 +2081,11 @@ void TrackDesignDrawPreview(TrackDesign* td6, uint8_t* pixels)
     const ScreenCoordsXY offset = { size_x / 2, size_y / 2 };
     for (uint8_t i = 0; i < 4; i++)
     {
-        gCurrentRotation = i;
-
         view.viewPos = Translate3DTo2DWithZ(i, centre) - offset;
-        ViewportPaint(&view, dpi, { view.viewPos, view.viewPos + ScreenCoordsXY{ size_x, size_y } });
+        view.rotation = i;
+        ViewportRender(dpi, &view, { {}, ScreenCoordsXY{ size_x, size_y } });
 
-        dpi.bits += TRACK_PREVIEW_IMAGE_SIZE;
+        dpi.bits += kTrackPreviewImageSize;
     }
 
     ride->Delete();
@@ -2181,9 +2098,9 @@ void TrackDesignDrawPreview(TrackDesign* td6, uint8_t* pixels)
  */
 static void TrackDesignPreviewClearMap()
 {
-    auto numTiles = MAXIMUM_MAP_SIZE_TECHNICAL * MAXIMUM_MAP_SIZE_TECHNICAL;
+    auto numTiles = kMaximumMapSizeTechnical * kMaximumMapSizeTechnical;
 
-    gMapSize = TRACK_DESIGN_PREVIEW_MAP_SIZE;
+    GetGameState().MapSize = TRACK_DESIGN_PREVIEW_MAP_SIZE;
 
     // Reserve ~8 elements per tile
     std::vector<TileElement> tileElements;
