@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2023 OpenRCT2 developers
+ * Copyright (c) 2014-2024 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -12,6 +12,7 @@
 #include "../../drawing/ImageId.hpp"
 #include "../../paint/Boundbox.h"
 #include "../../paint/Paint.h"
+#include "../../paint/support/WoodenSupports.h"
 #include "../../world/Location.hpp"
 #include "../TrackPaint.h"
 
@@ -26,11 +27,15 @@ struct SpriteBoundBox2
 };
 
 // Magic number 4 refers to the number of track blocks in a diagonal track element
-static constexpr const int8_t WoodenRCDiagonalSupports[4][NumOrthogonalDirections] = {
-    { -1, -1, -1, -1 }, // sequence 0
-    { 2, 3, 4, 5 },     // sequence 1
-    { 4, 5, 2, 3 },     // sequence 2
-    { -1, -1, -1, -1 }  // sequence 3
+static constexpr const WoodenSupportSubType WoodenRCDiagonalSupports[4][NumOrthogonalDirections] = {
+    { WoodenSupportSubType::Null, WoodenSupportSubType::Null, WoodenSupportSubType::Null,
+      WoodenSupportSubType::Null }, // sequence 0
+    { WoodenSupportSubType::Corner0, WoodenSupportSubType::Corner1, WoodenSupportSubType::Corner2,
+      WoodenSupportSubType::Corner3 }, // sequence 1
+    { WoodenSupportSubType::Corner2, WoodenSupportSubType::Corner3, WoodenSupportSubType::Corner0,
+      WoodenSupportSubType::Corner1 }, // sequence 2
+    { WoodenSupportSubType::Null, WoodenSupportSubType::Null, WoodenSupportSubType::Null,
+      WoodenSupportSubType::Null } // sequence 3
 };
 
 template<bool isClassic> ImageId WoodenRCGetTrackColour(const PaintSession& session)
