@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2023 OpenRCT2 developers
+ * Copyright (c) 2014-2024 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -17,43 +17,43 @@
 // clang-format off
 constexpr RideTypeDescriptor ClassicWoodenRollerCoasterRTD =
 {
-   SET_FIELD(AlternateType, RIDE_TYPE_NULL),
-   SET_FIELD(Category, RIDE_CATEGORY_ROLLERCOASTER),
-   SET_FIELD(EnabledTrackPieces, {TRACK_FLAT, TRACK_STRAIGHT, TRACK_STATION_END, TRACK_LIFT_HILL, TRACK_FLAT_ROLL_BANKING, TRACK_VERTICAL_LOOP, TRACK_SLOPE, TRACK_SLOPE_STEEP_UP, TRACK_SLOPE_STEEP_DOWN, TRACK_SLOPE_CURVE, TRACK_S_BEND, TRACK_CURVE_SMALL, TRACK_CURVE, TRACK_CURVE_LARGE, TRACK_BRAKES, TRACK_ON_RIDE_PHOTO, TRACK_WATER_SPLASH, TRACK_BLOCK_BRAKES, TRACK_DIAG_BRAKES, TRACK_DIAG_BLOCK_BRAKES}),
-   SET_FIELD(ExtraTrackPieces, {}),
-   SET_FIELD(CoveredTrackPieces, 0),
-   SET_FIELD(StartTrackPiece, TrackElemType::EndStation),
-   SET_FIELD(TrackPaintFunctions, TrackDrawerDescriptor(GetTrackPaintFunctionClassicWoodenRC)),
-   SET_FIELD(Flags, RIDE_TYPE_FLAGS_TRACK_HAS_3_COLOURS | RIDE_TYPE_FLAG_HAS_LEAVE_WHEN_ANOTHER_VEHICLE_ARRIVES_AT_STATION |
+   .AlternateType = RIDE_TYPE_NULL,
+   .Category = RIDE_CATEGORY_ROLLERCOASTER,
+   .EnabledTrackPieces = {TRACK_FLAT, TRACK_STRAIGHT, TRACK_STATION_END, TRACK_LIFT_HILL, TRACK_FLAT_ROLL_BANKING, TRACK_VERTICAL_LOOP, TRACK_SLOPE, TRACK_SLOPE_STEEP_UP, TRACK_SLOPE_STEEP_DOWN, TRACK_SLOPE_CURVE, TRACK_S_BEND, TRACK_CURVE_SMALL, TRACK_CURVE, TRACK_CURVE_LARGE, TRACK_BRAKES, TRACK_ON_RIDE_PHOTO, TRACK_WATER_SPLASH, TRACK_BLOCK_BRAKES, TRACK_DIAG_BRAKES, TRACK_DIAG_BLOCK_BRAKES},
+   .ExtraTrackPieces = {},
+   .CoveredTrackPieces = 0,
+   .StartTrackPiece = TrackElemType::EndStation,
+   .TrackPaintFunctions = TrackDrawerDescriptor(GetTrackPaintFunctionClassicWoodenRC),
+   .Flags = RIDE_TYPE_FLAGS_TRACK_HAS_3_COLOURS | RIDE_TYPE_FLAG_HAS_LEAVE_WHEN_ANOTHER_VEHICLE_ARRIVES_AT_STATION |
                     RIDE_TYPE_FLAGS_COMMON_COASTER | RIDE_TYPE_FLAGS_COMMON_COASTER_NON_ALT |
                     RIDE_TYPE_FLAG_PEEP_CHECK_GFORCES | RIDE_TYPE_FLAG_ALLOW_MULTIPLE_CIRCUITS |
-                    RIDE_TYPE_FLAG_ALLOW_REVERSED_TRAINS),
-   SET_FIELD(RideModes, EnumsToFlags(RideMode::ContinuousCircuit, RideMode::ContinuousCircuitBlockSectioned)),
-   SET_FIELD(DefaultMode, RideMode::ContinuousCircuit),
-   SET_FIELD(OperatingSettings, { 0, 0, 0, 0, 68, 0 }),
-   SET_FIELD(Naming, { STR_RIDE_NAME_CLASSIC_WOODEN_ROLLER_COASTER, STR_RIDE_DESCRIPTION_CLASSIC_WOODEN_ROLLER_COASTER }),
-   SET_FIELD(NameConvention, { RideComponentType::Train, RideComponentType::Track, RideComponentType::Station }),
-   SET_FIELD(EnumName, nameof(RIDE_TYPE_CLASSIC_WOODEN_ROLLER_COASTER)),
-   SET_FIELD(AvailableBreakdowns, (1 << BREAKDOWN_SAFETY_CUT_OUT) | (1 << BREAKDOWN_RESTRAINTS_STUCK_CLOSED) | (1 << BREAKDOWN_RESTRAINTS_STUCK_OPEN) | (1 << BREAKDOWN_VEHICLE_MALFUNCTION) | (1 << BREAKDOWN_BRAKES_FAILURE)),
-   SET_FIELD(Heights, { 24, 24, 8, 11, }),
-   SET_FIELD(MaxMass, 19),
-   SET_FIELD(LiftData, { OpenRCT2::Audio::SoundId::LiftWood, 3, 5 }),
-   SET_FIELD(RatingsMultipliers, { 52, 33, 4 }),
-   SET_FIELD(UpkeepCosts, { 40, 20, 80, 10, 3, 10 }),
-   SET_FIELD(BuildCosts, {37.50_GBP, 3.50_GBP, 50,  }),
-   SET_FIELD(DefaultPrices, { 20, 20 }),
-   SET_FIELD(DefaultMusic, MUSIC_OBJECT_WILD_WEST),
-   SET_FIELD(PhotoItem, ShopItem::Photo3),
-   SET_FIELD(BonusValue, 105),
-   SET_FIELD(ColourPresets, TRACK_COLOUR_PRESETS(
+                    RIDE_TYPE_FLAG_ALLOW_REVERSED_TRAINS,
+   .RideModes = EnumsToFlags(RideMode::ContinuousCircuit, RideMode::ContinuousCircuitBlockSectioned),
+   .DefaultMode = RideMode::ContinuousCircuit,
+   .OperatingSettings = { 0, 0, 0, 0, 68, 0 },
+   .Naming = { STR_RIDE_NAME_CLASSIC_WOODEN_ROLLER_COASTER, STR_RIDE_DESCRIPTION_CLASSIC_WOODEN_ROLLER_COASTER },
+   .NameConvention = { RideComponentType::Train, RideComponentType::Track, RideComponentType::Station },
+   .EnumName = nameof(RIDE_TYPE_CLASSIC_WOODEN_ROLLER_COASTER),
+   .AvailableBreakdowns = (1 << BREAKDOWN_SAFETY_CUT_OUT) | (1 << BREAKDOWN_RESTRAINTS_STUCK_CLOSED) | (1 << BREAKDOWN_RESTRAINTS_STUCK_OPEN) | (1 << BREAKDOWN_VEHICLE_MALFUNCTION) | (1 << BREAKDOWN_BRAKES_FAILURE),
+   .Heights = { 24, 24, 8, 11, },
+   .MaxMass = 19,
+   .LiftData = { OpenRCT2::Audio::SoundId::LiftWood, 3, 5 },
+   .RatingsMultipliers = { 52, 33, 4 },
+   .UpkeepCosts = { 40, 20, 80, 10, 3, 10 },
+   .BuildCosts = {37.50_GBP, 3.50_GBP, 50,  },
+   .DefaultPrices = { 20, 20 },
+   .DefaultMusic = MUSIC_OBJECT_WILD_WEST,
+   .PhotoItem = ShopItem::Photo3,
+   .BonusValue = 105,
+   .ColourPresets = TRACK_COLOUR_PRESETS(
        { COLOUR_SATURATED_BROWN, COLOUR_SATURATED_BROWN, COLOUR_SATURATED_BROWN},
        { COLOUR_WHITE, COLOUR_LIGHT_BROWN, COLOUR_WHITE },
        { COLOUR_LIGHT_BROWN, COLOUR_BLACK, COLOUR_LIGHT_BROWN },
-   )),
-   SET_FIELD(ColourPreview, { SPR_RIDE_DESIGN_PREVIEW_CLASSIC_WOODEN_ROLLER_COASTER_TRACK, SPR_RIDE_DESIGN_PREVIEW_CLASSIC_WOODEN_ROLLER_COASTER_SUPPORTS }),
-   SET_FIELD(ColourKey, RideColourKey::Ride),
-   SET_FIELD(Name, "classic_wooden_rc"),
-    SET_FIELD(RatingsData,
+   ),
+   .ColourPreview = { SPR_RIDE_DESIGN_PREVIEW_CLASSIC_WOODEN_ROLLER_COASTER_TRACK, SPR_RIDE_DESIGN_PREVIEW_CLASSIC_WOODEN_ROLLER_COASTER_SUPPORTS },
+   .ColourKey = RideColourKey::Ride,
+   .Name = "classic_wooden_rc",
+    .RatingsData = 
     {
         RatingsCalculationType::Normal,
         { RIDE_RATING(2, 80), RIDE_RATING(2, 60), RIDE_RATING(2, 00) },
@@ -81,6 +81,6 @@ constexpr RideTypeDescriptor ClassicWoodenRollerCoasterRTD =
             { RatingsModifierType::RequirementNumDrops,   2,                2, 1, 2 },
             { RatingsModifierType::PenaltyLateralGs,      0,                40960, 34555, 49648 },
         },
-    }),
+    },
 };
 // clang-format on
