@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2023 OpenRCT2 developers
+ * Copyright (c) 2014-2024 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -17,42 +17,42 @@
 // clang-format off
 constexpr RideTypeDescriptor HeartlineTwisterCoasterRTD =
 {
-    SET_FIELD(AlternateType, RIDE_TYPE_NULL),
-    SET_FIELD(Category, RIDE_CATEGORY_ROLLERCOASTER),
-    SET_FIELD(EnabledTrackPieces, {TRACK_STRAIGHT, TRACK_STATION_END, TRACK_LIFT_HILL, TRACK_LIFT_HILL_STEEP, TRACK_SLOPE, TRACK_SLOPE_STEEP_UP, TRACK_SLOPE_STEEP_DOWN, TRACK_HEARTLINE_ROLL, TRACK_HEARTLINE_TRANSFER}),
-    SET_FIELD(ExtraTrackPieces, {}),
-    SET_FIELD(CoveredTrackPieces, {}),
-    SET_FIELD(StartTrackPiece, TrackElemType::EndStation),
-    SET_FIELD(TrackPaintFunctions, TrackDrawerDescriptor(GetTrackPaintFunctionHeartlineTwisterRC)),
-    SET_FIELD(Flags, RIDE_TYPE_FLAGS_TRACK_HAS_3_COLOURS | RIDE_TYPE_FLAG_HAS_LEAVE_WHEN_ANOTHER_VEHICLE_ARRIVES_AT_STATION |
+    .AlternateType = RIDE_TYPE_NULL,
+    .Category = RIDE_CATEGORY_ROLLERCOASTER,
+    .EnabledTrackPieces = {TRACK_STRAIGHT, TRACK_STATION_END, TRACK_LIFT_HILL, TRACK_LIFT_HILL_STEEP, TRACK_SLOPE, TRACK_SLOPE_STEEP_UP, TRACK_SLOPE_STEEP_DOWN, TRACK_HEARTLINE_ROLL, TRACK_HEARTLINE_TRANSFER},
+    .ExtraTrackPieces = {},
+    .CoveredTrackPieces = {},
+    .StartTrackPiece = TrackElemType::EndStation,
+    .TrackPaintFunctions = TrackDrawerDescriptor(GetTrackPaintFunctionHeartlineTwisterRC),
+    .Flags = RIDE_TYPE_FLAGS_TRACK_HAS_3_COLOURS | RIDE_TYPE_FLAG_HAS_LEAVE_WHEN_ANOTHER_VEHICLE_ARRIVES_AT_STATION |
                      RIDE_TYPE_FLAGS_COMMON_COASTER | RIDE_TYPE_FLAGS_COMMON_COASTER_NON_ALT | RIDE_TYPE_FLAG_PEEP_CHECK_GFORCES |
-                     RIDE_TYPE_FLAG_ALLOW_REVERSED_TRAINS),
-    SET_FIELD(RideModes, EnumsToFlags(RideMode::ContinuousCircuit)),
-    SET_FIELD(DefaultMode, RideMode::ContinuousCircuit),
-    SET_FIELD(OperatingSettings, { 10, 27, 30, 25, 25, 0 }),
-    SET_FIELD(Naming, { STR_RIDE_NAME_HEARTLINE_TWISTER_COASTER, STR_RIDE_DESCRIPTION_HEARTLINE_TWISTER_COASTER }),
-    SET_FIELD(NameConvention, { RideComponentType::Car, RideComponentType::Track, RideComponentType::Station }),
-    SET_FIELD(EnumName, nameof(RIDE_TYPE_HEARTLINE_TWISTER_COASTER)),
-    SET_FIELD(AvailableBreakdowns, (1 << BREAKDOWN_SAFETY_CUT_OUT) | (1 << BREAKDOWN_RESTRAINTS_STUCK_CLOSED) | (1 << BREAKDOWN_RESTRAINTS_STUCK_OPEN) | (1 << BREAKDOWN_VEHICLE_MALFUNCTION)),
-    SET_FIELD(Heights, { 22, 24, 15, 9, }),
-    SET_FIELD(MaxMass, 18),
-    SET_FIELD(LiftData, { OpenRCT2::Audio::SoundId::LiftClassic, 4, 6 }),
-    SET_FIELD(RatingsMultipliers, { 50, 30, 10 }),
-    SET_FIELD(UpkeepCosts, { 47, 20, 80, 11, 3, 10 }),
-    SET_FIELD(BuildCosts, { 72.50_GBP, 3.50_GBP, 30, }),
-    SET_FIELD(DefaultPrices, { 15, 20 }),
-    SET_FIELD(DefaultMusic, MUSIC_OBJECT_TECHNO),
-    SET_FIELD(PhotoItem, ShopItem::Photo),
-    SET_FIELD(BonusValue, 70),
-    SET_FIELD(ColourPresets, TRACK_COLOUR_PRESETS(
+                     RIDE_TYPE_FLAG_ALLOW_REVERSED_TRAINS,
+    .RideModes = EnumsToFlags(RideMode::ContinuousCircuit),
+    .DefaultMode = RideMode::ContinuousCircuit,
+    .OperatingSettings = { 10, 27, 30, 25, 25, 0 },
+    .Naming = { STR_RIDE_NAME_HEARTLINE_TWISTER_COASTER, STR_RIDE_DESCRIPTION_HEARTLINE_TWISTER_COASTER },
+    .NameConvention = { RideComponentType::Car, RideComponentType::Track, RideComponentType::Station },
+    .EnumName = nameof(RIDE_TYPE_HEARTLINE_TWISTER_COASTER),
+    .AvailableBreakdowns = (1 << BREAKDOWN_SAFETY_CUT_OUT) | (1 << BREAKDOWN_RESTRAINTS_STUCK_CLOSED) | (1 << BREAKDOWN_RESTRAINTS_STUCK_OPEN) | (1 << BREAKDOWN_VEHICLE_MALFUNCTION),
+    .Heights = { 22, 24, 15, 9, },
+    .MaxMass = 18,
+    .LiftData = { OpenRCT2::Audio::SoundId::LiftClassic, 4, 6 },
+    .RatingsMultipliers = { 50, 30, 10 },
+    .UpkeepCosts = { 47, 20, 80, 11, 3, 10 },
+    .BuildCosts = { 72.50_GBP, 3.50_GBP, 30, },
+    .DefaultPrices = { 15, 20 },
+    .DefaultMusic = MUSIC_OBJECT_TECHNO,
+    .PhotoItem = ShopItem::Photo,
+    .BonusValue = 70,
+    .ColourPresets = TRACK_COLOUR_PRESETS(
         { COLOUR_WHITE, COLOUR_LIGHT_BLUE, COLOUR_WHITE },
         { COLOUR_BORDEAUX_RED, COLOUR_YELLOW, COLOUR_BLACK },
         { COLOUR_DARK_PURPLE, COLOUR_WHITE, COLOUR_DARK_GREEN },
-    )),
-    SET_FIELD(ColourPreview, { SPR_RIDE_DESIGN_PREVIEW_HEARTLINE_TWISTER_COASTER_TRACK, SPR_RIDE_DESIGN_PREVIEW_HEARTLINE_TWISTER_COASTER_SUPPORTS }),
-    SET_FIELD(ColourKey, RideColourKey::Ride),
-    SET_FIELD(Name, "heartline_twister_rc"),
-    SET_FIELD(RatingsData,
+    ),
+    .ColourPreview = { SPR_RIDE_DESIGN_PREVIEW_HEARTLINE_TWISTER_COASTER_TRACK, SPR_RIDE_DESIGN_PREVIEW_HEARTLINE_TWISTER_COASTER_SUPPORTS },
+    .ColourKey = RideColourKey::Ride,
+    .Name = "heartline_twister_rc",
+    .RatingsData = 
     {
         RatingsCalculationType::Normal,
         { RIDE_RATING(3, 00), RIDE_RATING(1, 70), RIDE_RATING(1, 65) },
@@ -76,6 +76,6 @@ constexpr RideTypeDescriptor HeartlineTwisterCoasterRTD =
             { RatingsModifierType::RequirementNumDrops,   1,    4, 1, 1 },
             { RatingsModifierType::PenaltyLateralGs,      0,    24576, 44683, 89367 },
         },
-    }),
+    },
 };
 // clang-format on
