@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2023 OpenRCT2 developers
+ * Copyright (c) 2014-2024 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -60,73 +60,63 @@
 
 #include <algorithm>
 
+using namespace OpenRCT2;
+
 const StringId ScenarioCategoryStringIds[SCENARIO_CATEGORY_COUNT] = {
     STR_BEGINNER_PARKS, STR_CHALLENGING_PARKS,    STR_EXPERT_PARKS, STR_REAL_PARKS, STR_OTHER_PARKS,
     STR_DLC_PARKS,      STR_BUILD_YOUR_OWN_PARKS, STR_COMPETITIONS, STR_UCES_TM,    STR_UCES_KD,
 };
 
-SCENARIO_CATEGORY gScenarioCategory;
-std::string gScenarioName;
-std::string gScenarioDetails;
-std::string gScenarioCompletedBy;
 std::string gScenarioSavePath;
 bool gFirstTimeSaving = true;
-uint16_t gSavedAge;
 uint32_t gLastAutoSaveUpdate = 0;
 
-random_engine_t gScenarioRand;
-
-Objective gScenarioObjective;
-
 bool gAllowEarlyCompletionInNetworkPlay;
-uint16_t gScenarioParkRatingWarningDays;
-money64 gScenarioCompletedCompanyValue;
-money64 gScenarioCompanyValueRecord;
 
 std::string gScenarioFileName;
 
-static void ScenarioCheckObjective();
+static void ScenarioCheckObjective(GameState_t& gameState);
 
 using namespace OpenRCT2;
 
-void ScenarioBegin()
+void ScenarioBegin(GameState_t& gameState)
 {
     GameLoadInit();
-    ScenarioReset();
+    ScenarioReset(gameState);
 
-    if (gScenarioObjective.Type != OBJECTIVE_NONE && !gLoadKeepWindowsOpen)
+    if (gameState.ScenarioObjective.Type != OBJECTIVE_NONE && !gLoadKeepWindowsOpen)
         ContextOpenWindowView(WV_PARK_OBJECTIVE);
 
     gScreenAge = 0;
 }
 
-void ScenarioReset()
+void ScenarioReset(GameState_t& gameState)
 {
     // Set the scenario pseudo-random seeds
     Random::RCT2::Seed s{ 0x1234567F ^ Platform::GetTicks(), 0x789FABCD ^ Platform::GetTicks() };
-    gScenarioRand.seed(s);
+    gameState.ScenarioRand.seed(s);
 
     ResearchResetCurrentItem();
     ScenerySetDefaultPlacementConfiguration();
     News::InitQueue();
 
     auto& park = GetContext()->GetGameState()->GetPark();
-    gParkRating = park.CalculateParkRating();
-    gParkValue = park.CalculateParkValue();
-    gCompanyValue = park.CalculateCompanyValue();
-    gHistoricalProfit = gInitialCash - gBankLoan;
-    gCash = gInitialCash;
+    gameState.ParkRating = park.CalculateParkRating();
+    gameState.ParkValue = park.CalculateParkValue();
+    gameState.CompanyValue = park.CalculateCompanyValue();
+    gameState.HistoricalProfit = gameState.InitialCash - gameState.BankLoan;
+    gameState.Cash = gameState.InitialCash;
 
     {
         utf8 normalisedName[64];
-        ScenarioSources::NormaliseName(normalisedName, sizeof(normalisedName), gScenarioName.c_str());
+        ScenarioSources::NormaliseName(normalisedName, sizeof(normalisedName), gameState.ScenarioName.c_str());
 
         StringId localisedStringIds[3];
         if (LanguageGetLocalisedScenarioStrings(normalisedName, localisedStringIds))
         {
             if (localisedStringIds[0] != STR_NONE)
             {
-                gScenarioName = LanguageGetString(localisedStringIds[0]);
+                gameState.ScenarioName = LanguageGetString(localisedStringIds[0]);
             }
             if (localisedStringIds[1] != STR_NONE)
             {
@@ -134,7 +124,7 @@ void ScenarioReset()
             }
             if (localisedStringIds[2] != STR_NONE)
             {
-                gScenarioDetails = LanguageGetString(localisedStringIds[2]);
+                gameState.ScenarioDetails = LanguageGetString(localisedStringIds[2]);
             }
         }
     }
@@ -144,16 +134,16 @@ void ScenarioReset()
     auto savePath = env->GetDirectoryPath(DIRBASE::USER, DIRID::SAVE);
     gScenarioSavePath = Path::Combine(savePath, park.Name + u8".park");
 
-    gCurrentExpenditure = 0;
-    gCurrentProfit = 0;
-    gWeeklyProfitAverageDividend = 0;
-    gWeeklyProfitAverageDivisor = 0;
-    gTotalAdmissions = 0;
-    gTotalIncomeFromAdmissions = 0;
+    gameState.CurrentExpenditure = 0;
+    gameState.CurrentProfit = 0;
+    gameState.WeeklyProfitAverageDividend = 0;
+    gameState.WeeklyProfitAverageDivisor = 0;
+    gameState.TotalAdmissions = 0;
+    gameState.TotalIncomeFromAdmissions = 0;
 
-    gParkFlags &= ~PARK_FLAGS_SCENARIO_COMPLETE_NAME_INPUT;
-    gScenarioCompletedCompanyValue = MONEY64_UNDEFINED;
-    gScenarioCompletedBy = "?";
+    gameState.ParkFlags &= ~PARK_FLAGS_SCENARIO_COMPLETE_NAME_INPUT;
+    gameState.ScenarioCompletedCompanyValue = kMoney64Undefined;
+    gameState.ScenarioCompletedBy = "?";
 
     park.ResetHistories();
     FinanceResetHistory();
@@ -166,24 +156,24 @@ void ScenarioReset()
     Staff::ResetStats();
 
     auto& objManager = GetContext()->GetObjectManager();
-    gLastEntranceStyle = objManager.GetLoadedObjectEntryIndex("rct2.station.plain");
-    if (gLastEntranceStyle == OBJECT_ENTRY_INDEX_NULL)
+    gameState.LastEntranceStyle = objManager.GetLoadedObjectEntryIndex("rct2.station.plain");
+    if (gameState.LastEntranceStyle == OBJECT_ENTRY_INDEX_NULL)
     {
         // Fall back to first entrance object
-        gLastEntranceStyle = 0;
+        gameState.LastEntranceStyle = 0;
     }
 
     gMarketingCampaigns.clear();
-    gParkRatingCasualtyPenalty = 0;
+    gameState.ParkRatingCasualtyPenalty = 0;
 
     // Open park with free entry when there is no money
-    if (gParkFlags & PARK_FLAGS_NO_MONEY)
+    if (gameState.ParkFlags & PARK_FLAGS_NO_MONEY)
     {
-        gParkFlags |= PARK_FLAGS_PARK_OPEN;
-        gParkEntranceFee = 0;
+        gameState.ParkFlags |= PARK_FLAGS_PARK_OPEN;
+        gameState.ParkEntranceFee = 0;
     }
 
-    gParkFlags |= PARK_FLAGS_SPRITES_INITIALISED;
+    gameState.ParkFlags |= PARK_FLAGS_SPRITES_INITIALISED;
     gGamePaused = false;
 }
 
@@ -199,9 +189,9 @@ static void ScenarioEnd()
  *
  *  rct2: 0x0066A752
  */
-void ScenarioFailure()
+void ScenarioFailure(GameState_t& gameState)
 {
-    gScenarioCompletedCompanyValue = COMPANY_VALUE_ON_FAILED_OBJECTIVE;
+    gameState.ScenarioCompletedCompanyValue = COMPANY_VALUE_ON_FAILED_OBJECTIVE;
     ScenarioEnd();
 }
 
@@ -209,18 +199,18 @@ void ScenarioFailure()
  *
  *  rct2: 0x0066A75E
  */
-void ScenarioSuccess()
+void ScenarioSuccess(GameState_t& gameState)
 {
-    auto companyValue = gCompanyValue;
+    auto companyValue = gameState.CompanyValue;
 
-    gScenarioCompletedCompanyValue = companyValue;
+    gameState.ScenarioCompletedCompanyValue = companyValue;
     PeepApplause();
 
     if (ScenarioRepositoryTryRecordHighscore(gScenarioFileName.c_str(), companyValue, nullptr))
     {
         // Allow name entry
-        gParkFlags |= PARK_FLAGS_SCENARIO_COMPLETE_NAME_INPUT;
-        gScenarioCompanyValueRecord = companyValue;
+        GetGameState().ParkFlags |= PARK_FLAGS_SCENARIO_COMPLETE_NAME_INPUT;
+        gameState.ScenarioCompanyValueRecord = companyValue;
     }
     ScenarioEnd();
 }
@@ -229,13 +219,13 @@ void ScenarioSuccess()
  *
  *  rct2: 0x006695E8
  */
-void ScenarioSuccessSubmitName(const char* name)
+void ScenarioSuccessSubmitName(GameState_t& gameState, const char* name)
 {
-    if (ScenarioRepositoryTryRecordHighscore(gScenarioFileName.c_str(), gScenarioCompanyValueRecord, name))
+    if (ScenarioRepositoryTryRecordHighscore(gScenarioFileName.c_str(), gameState.ScenarioCompanyValueRecord, name))
     {
-        gScenarioCompletedBy = name;
+        gameState.ScenarioCompletedBy = name;
     }
-    gParkFlags &= ~PARK_FLAGS_SCENARIO_COMPLETE_NAME_INPUT;
+    gameState.ParkFlags &= ~PARK_FLAGS_SCENARIO_COMPLETE_NAME_INPUT;
 }
 
 /**
@@ -244,13 +234,14 @@ void ScenarioSuccessSubmitName(const char* name)
  */
 static void ScenarioCheckEntranceFeeTooHigh()
 {
-    const auto max_fee = AddClamp_money64(gTotalRideValueForMoney, gTotalRideValueForMoney / 2);
+    const auto& gameState = GetGameState();
+    const auto max_fee = AddClamp_money64(gameState.TotalRideValueForMoney, gameState.TotalRideValueForMoney / 2);
 
-    if ((gParkFlags & PARK_FLAGS_PARK_OPEN) && ParkGetEntranceFee() > max_fee)
+    if ((gameState.ParkFlags & PARK_FLAGS_PARK_OPEN) && ParkGetEntranceFee() > max_fee)
     {
-        if (!gParkEntrances.empty())
+        if (!gameState.ParkEntrances.empty())
         {
-            const auto& entrance = gParkEntrances[0];
+            const auto& entrance = gameState.ParkEntrances[0];
             auto x = entrance.x + 16;
             auto y = entrance.y + 16;
 
@@ -265,7 +256,7 @@ static void ScenarioCheckEntranceFeeTooHigh()
 
 void ScenarioAutosaveCheck()
 {
-    if (gLastAutoSaveUpdate == AUTOSAVE_PAUSE)
+    if (gLastAutoSaveUpdate == kAutosavePause)
         return;
 
     // Milliseconds since last save
@@ -293,33 +284,33 @@ void ScenarioAutosaveCheck()
 
     if (shouldSave)
     {
-        gLastAutoSaveUpdate = AUTOSAVE_PAUSE;
+        gLastAutoSaveUpdate = kAutosavePause;
         GameAutosave();
     }
 }
 
-static void ScenarioDayUpdate()
+static void ScenarioDayUpdate(GameState_t& gameState)
 {
     FinanceUpdateDailyProfit();
     PeepUpdateDaysInQueue();
-    switch (gScenarioObjective.Type)
+    switch (gameState.ScenarioObjective.Type)
     {
         case OBJECTIVE_10_ROLLERCOASTERS:
         case OBJECTIVE_GUESTS_AND_RATING:
         case OBJECTIVE_10_ROLLERCOASTERS_LENGTH:
         case OBJECTIVE_FINISH_5_ROLLERCOASTERS:
         case OBJECTIVE_REPAY_LOAN_AND_PARK_VALUE:
-            ScenarioCheckObjective();
+            ScenarioCheckObjective(gameState);
             break;
         default:
             if (AllowEarlyCompletion())
-                ScenarioCheckObjective();
+                ScenarioCheckObjective(gameState);
             break;
     }
 
     // Lower the casualty penalty
-    uint16_t casualtyPenaltyModifier = (gParkFlags & PARK_FLAGS_NO_MONEY) ? 40 : 7;
-    gParkRatingCasualtyPenalty = std::max(0, gParkRatingCasualtyPenalty - casualtyPenaltyModifier);
+    uint16_t casualtyPenaltyModifier = (gameState.ParkFlags & PARK_FLAGS_NO_MONEY) ? 40 : 7;
+    gameState.ParkRatingCasualtyPenalty = std::max(0, gameState.ParkRatingCasualtyPenalty - casualtyPenaltyModifier);
 
     auto intent = Intent(INTENT_ACTION_UPDATE_DATE);
     ContextBroadcastIntent(&intent);
@@ -358,7 +349,7 @@ static void ScenarioFortnightUpdate()
 static void ScenarioMonthUpdate()
 {
     FinanceShiftExpenditureTable();
-    ScenarioCheckObjective();
+    ScenarioCheckObjective(GetGameState());
     ScenarioCheckEntranceFeeTooHigh();
     AwardUpdateAll();
 }
@@ -370,7 +361,7 @@ static void ScenarioUpdateDayNightCycle()
 
     if (gScreenFlags == SCREEN_FLAGS_PLAYING && gConfigGeneral.DayNightCycle)
     {
-        float monthFraction = GetDate().GetMonthTicks() / static_cast<float>(TICKS_PER_MONTH);
+        float monthFraction = GetDate().GetMonthTicks() / static_cast<float>(kTicksPerMonth);
         if (monthFraction < (1 / 8.0f))
         {
             gDayNightCycle = 0.0f;
@@ -404,7 +395,7 @@ static void ScenarioUpdateDayNightCycle()
  * Scenario and finance related update iteration.
  *  rct2: 0x006C44B1
  */
-void ScenarioUpdate()
+void ScenarioUpdate(GameState_t& gameState)
 {
     PROFILED_FUNCTION();
 
@@ -413,7 +404,7 @@ void ScenarioUpdate()
         auto& date = GetDate();
         if (date.IsDayStart())
         {
-            ScenarioDayUpdate();
+            ScenarioDayUpdate(gameState);
         }
         if (date.IsWeekStart())
         {
@@ -442,8 +433,9 @@ bool ScenarioCreateDucks()
     constexpr int32_t SquareRadiusSize = SquareCentre * 32;
 
     CoordsXY centrePos;
-    centrePos.x = SquareRadiusSize + (ScenarioRandMax(gMapSize.x - SquareCentre) * 32);
-    centrePos.y = SquareRadiusSize + (ScenarioRandMax(gMapSize.y - SquareCentre) * 32);
+    auto& gameState = GetGameState();
+    centrePos.x = SquareRadiusSize + (ScenarioRandMax(gameState.MapSize.x - SquareCentre) * 32);
+    centrePos.y = SquareRadiusSize + (ScenarioRandMax(gameState.MapSize.y - SquareCentre) * 32);
 
     Guard::Assert(MapIsLocationValid(centrePos));
 
@@ -502,13 +494,13 @@ bool ScenarioCreateDucks()
 
 const random_engine_t::state_type& ScenarioRandState()
 {
-    return gScenarioRand.state();
+    return GetGameState().ScenarioRand.state();
 };
 
 void ScenarioRandSeed(random_engine_t::result_type s0, random_engine_t::result_type s1)
 {
     Random::RCT2::Seed s{ s0, s1 };
-    gScenarioRand.seed(s);
+    GetGameState().ScenarioRand.seed(s);
 }
 
 /**
@@ -519,7 +511,7 @@ void ScenarioRandSeed(random_engine_t::result_type s0, random_engine_t::result_t
  */
 random_engine_t::result_type ScenarioRand()
 {
-    return gScenarioRand();
+    return GetGameState().ScenarioRand();
 }
 
 uint32_t ScenarioRandMax(uint32_t max)
@@ -540,9 +532,9 @@ uint32_t ScenarioRandMax(uint32_t max)
  * Prepare rides, for the finish five rollercoasters objective.
  *  rct2: 0x006788F7
  */
-static ResultWithMessage ScenarioPrepareRidesForSave()
+static ResultWithMessage ScenarioPrepareRidesForSave(GameState_t& gameState)
 {
-    int32_t isFiveCoasterObjective = gScenarioObjective.Type == OBJECTIVE_FINISH_5_ROLLERCOASTERS;
+    int32_t isFiveCoasterObjective = gameState.ScenarioObjective.Type == OBJECTIVE_FINISH_5_ROLLERCOASTERS;
     uint8_t rcs = 0;
 
     for (auto& ride : GetRideManager())
@@ -599,31 +591,31 @@ static ResultWithMessage ScenarioPrepareRidesForSave()
  *
  *  rct2: 0x006726C7
  */
-ResultWithMessage ScenarioPrepareForSave()
+ResultWithMessage ScenarioPrepareForSave(GameState_t& gameState)
 {
     // This can return false if the goal is 'Finish 5 roller coaster' and there are too few.
-    const auto prepareRidesResult = ScenarioPrepareRidesForSave();
+    const auto prepareRidesResult = ScenarioPrepareRidesForSave(gameState);
     if (!prepareRidesResult.Successful)
     {
         return { false, prepareRidesResult.Message };
     }
 
-    if (gScenarioObjective.Type == OBJECTIVE_GUESTS_AND_RATING)
-        gParkFlags |= PARK_FLAGS_PARK_OPEN;
+    if (gameState.ScenarioObjective.Type == OBJECTIVE_GUESTS_AND_RATING)
+        GetGameState().ParkFlags |= PARK_FLAGS_PARK_OPEN;
 
-    ScenarioReset();
+    ScenarioReset(gameState);
 
     return { true };
 }
 
 ObjectiveStatus Objective::CheckGuestsBy() const
 {
-    auto parkRating = gParkRating;
+    auto parkRating = GetGameState().ParkRating;
     int32_t currentMonthYear = GetDate().GetMonthsElapsed();
 
     if (currentMonthYear == MONTH_COUNT * Year || AllowEarlyCompletion())
     {
-        if (parkRating >= 600 && gNumGuestsInPark >= NumGuests)
+        if (parkRating >= 600 && GetGameState().NumGuestsInPark >= NumGuests)
         {
             return ObjectiveStatus::Success;
         }
@@ -641,7 +633,7 @@ ObjectiveStatus Objective::CheckParkValueBy() const
 {
     int32_t currentMonthYear = GetDate().GetMonthsElapsed();
     money64 objectiveParkValue = Currency;
-    money64 parkValue = gParkValue;
+    money64 parkValue = GetGameState().ParkValue;
 
     if (currentMonthYear == MONTH_COUNT * Year || AllowEarlyCompletion())
     {
@@ -697,52 +689,53 @@ ObjectiveStatus Objective::Check10RollerCoasters() const
  */
 ObjectiveStatus Objective::CheckGuestsAndRating() const
 {
-    if (gParkRating < 700 && GetDate().GetMonthsElapsed() >= 1)
+    auto& gameState = GetGameState();
+    if (gameState.ParkRating < 700 && GetDate().GetMonthsElapsed() >= 1)
     {
-        gScenarioParkRatingWarningDays++;
-        if (gScenarioParkRatingWarningDays == 1)
+        gameState.ScenarioParkRatingWarningDays++;
+        if (gameState.ScenarioParkRatingWarningDays == 1)
         {
             if (gConfigNotifications.ParkRatingWarnings)
             {
                 News::AddItemToQueue(News::ItemType::Graph, STR_PARK_RATING_WARNING_4_WEEKS_REMAINING, 0, {});
             }
         }
-        else if (gScenarioParkRatingWarningDays == 8)
+        else if (gameState.ScenarioParkRatingWarningDays == 8)
         {
             if (gConfigNotifications.ParkRatingWarnings)
             {
                 News::AddItemToQueue(News::ItemType::Graph, STR_PARK_RATING_WARNING_3_WEEKS_REMAINING, 0, {});
             }
         }
-        else if (gScenarioParkRatingWarningDays == 15)
+        else if (gameState.ScenarioParkRatingWarningDays == 15)
         {
             if (gConfigNotifications.ParkRatingWarnings)
             {
                 News::AddItemToQueue(News::ItemType::Graph, STR_PARK_RATING_WARNING_2_WEEKS_REMAINING, 0, {});
             }
         }
-        else if (gScenarioParkRatingWarningDays == 22)
+        else if (gameState.ScenarioParkRatingWarningDays == 22)
         {
             if (gConfigNotifications.ParkRatingWarnings)
             {
                 News::AddItemToQueue(News::ItemType::Graph, STR_PARK_RATING_WARNING_1_WEEK_REMAINING, 0, {});
             }
         }
-        else if (gScenarioParkRatingWarningDays == 29)
+        else if (gameState.ScenarioParkRatingWarningDays == 29)
         {
             News::AddItemToQueue(News::ItemType::Graph, STR_PARK_HAS_BEEN_CLOSED_DOWN, 0, {});
-            gParkFlags &= ~PARK_FLAGS_PARK_OPEN;
-            gGuestInitialHappiness = 50;
+            gameState.ParkFlags &= ~PARK_FLAGS_PARK_OPEN;
+            gameState.GuestInitialHappiness = 50;
             return ObjectiveStatus::Failure;
         }
     }
-    else if (gScenarioCompletedCompanyValue != COMPANY_VALUE_ON_FAILED_OBJECTIVE)
+    else if (gameState.ScenarioCompletedCompanyValue != COMPANY_VALUE_ON_FAILED_OBJECTIVE)
     {
-        gScenarioParkRatingWarningDays = 0;
+        gameState.ScenarioParkRatingWarningDays = 0;
     }
 
-    if (gParkRating >= 700)
-        if (gNumGuestsInPark >= NumGuests)
+    if (gameState.ParkRating >= 700)
+        if (gameState.NumGuestsInPark >= NumGuests)
             return ObjectiveStatus::Success;
 
     return ObjectiveStatus::Undecided;
@@ -750,7 +743,7 @@ ObjectiveStatus Objective::CheckGuestsAndRating() const
 
 ObjectiveStatus Objective::CheckMonthlyRideIncome() const
 {
-    money64 lastMonthRideIncome = gExpenditureTable[1][static_cast<int32_t>(ExpenditureType::ParkRideTickets)];
+    money64 lastMonthRideIncome = GetGameState().ExpenditureTable[1][EnumValue(ExpenditureType::ParkRideTickets)];
     if (lastMonthRideIncome >= Currency)
     {
         return ObjectiveStatus::Success;
@@ -824,8 +817,9 @@ ObjectiveStatus Objective::CheckFinish5RollerCoasters() const
 
 ObjectiveStatus Objective::CheckRepayLoanAndParkValue() const
 {
-    money64 parkValue = gParkValue;
-    money64 currentLoan = gBankLoan;
+    const auto& gameState = GetGameState();
+    money64 parkValue = gameState.ParkValue;
+    money64 currentLoan = gameState.BankLoan;
 
     if (currentLoan <= 0 && parkValue >= Currency)
     {
@@ -837,11 +831,11 @@ ObjectiveStatus Objective::CheckRepayLoanAndParkValue() const
 
 ObjectiveStatus Objective::CheckMonthlyFoodIncome() const
 {
-    const auto* lastMonthExpenditure = gExpenditureTable[1];
-    auto lastMonthProfit = lastMonthExpenditure[static_cast<int32_t>(ExpenditureType::ShopSales)]
-        + lastMonthExpenditure[static_cast<int32_t>(ExpenditureType::ShopStock)]
-        + lastMonthExpenditure[static_cast<int32_t>(ExpenditureType::FoodDrinkSales)]
-        + lastMonthExpenditure[static_cast<int32_t>(ExpenditureType::FoodDrinkStock)];
+    const auto* lastMonthExpenditure = GetGameState().ExpenditureTable[1];
+    auto lastMonthProfit = lastMonthExpenditure[EnumValue(ExpenditureType::ShopSales)]
+        + lastMonthExpenditure[EnumValue(ExpenditureType::ShopStock)]
+        + lastMonthExpenditure[EnumValue(ExpenditureType::FoodDrinkSales)]
+        + lastMonthExpenditure[EnumValue(ExpenditureType::FoodDrinkStock)];
 
     if (lastMonthProfit >= Currency)
     {
@@ -868,16 +862,16 @@ bool AllowEarlyCompletion()
     }
 }
 
-static void ScenarioCheckObjective()
+static void ScenarioCheckObjective(GameState_t& gameState)
 {
-    auto status = gScenarioObjective.Check();
+    auto status = gameState.ScenarioObjective.Check(gameState);
     if (status == ObjectiveStatus::Success)
     {
-        ScenarioSuccess();
+        ScenarioSuccess(gameState);
     }
     else if (status == ObjectiveStatus::Failure)
     {
-        ScenarioFailure();
+        ScenarioFailure(gameState);
     }
 }
 
@@ -885,9 +879,9 @@ static void ScenarioCheckObjective()
  * Checks the win/lose conditions of the current objective.
  *  rct2: 0x0066A4B2
  */
-ObjectiveStatus Objective::Check() const
+ObjectiveStatus Objective::Check(GameState_t& gameState) const
 {
-    if (gScenarioCompletedCompanyValue != MONEY64_UNDEFINED)
+    if (gameState.ScenarioCompletedCompanyValue != kMoney64Undefined)
     {
         return ObjectiveStatus::Undecided;
     }
