@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2023 OpenRCT2 developers
+ * Copyright (c) 2014-2024 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -25,6 +25,11 @@ struct ResultWithMessage;
 
 using random_engine_t = Random::RCT2::Engine;
 
+namespace OpenRCT2
+{
+    struct GameState_t;
+}
+
 enum
 {
     SCENARIO_FLAGS_VISIBLE = (1 << 0),
@@ -38,9 +43,6 @@ enum
     S6_TYPE_SCENARIO
 };
 
-#define S6_RCT2_VERSION 120001
-#define S6_MAGIC_NUMBER 0x00031144
-
 enum SCENARIO_CATEGORY
 {
     // RCT2 categories (keep order)
@@ -116,7 +118,7 @@ struct Objective
         return objectiveAllowedByMoneyUsage && objectiveAllowedByPaymentSettings;
     }
 
-    ObjectiveStatus Check() const;
+    ObjectiveStatus Check(OpenRCT2::GameState_t& gameState) const;
 
 private:
     ObjectiveStatus CheckGuestsBy() const;
@@ -146,35 +148,24 @@ enum
     AUTOSAVE_NEVER
 };
 
-#define AUTOSAVE_PAUSE 0
-#define DEFAULT_NUM_AUTOSAVES_TO_KEEP 10
+constexpr uint8_t kAutosavePause = 0;
+constexpr uint8_t kDefaultNumAutosavesToKeep = 10;
 
 static constexpr money64 COMPANY_VALUE_ON_FAILED_OBJECTIVE = 0x8000000000000001;
 
 extern const StringId ScenarioCategoryStringIds[SCENARIO_CATEGORY_COUNT];
 
-extern random_engine_t gScenarioRand;
-
-extern Objective gScenarioObjective;
 extern bool gAllowEarlyCompletionInNetworkPlay;
-extern uint16_t gScenarioParkRatingWarningDays;
-extern money64 gScenarioCompletedCompanyValue;
-extern money64 gScenarioCompanyValueRecord;
 
-extern SCENARIO_CATEGORY gScenarioCategory;
-extern std::string gScenarioName;
-extern std::string gScenarioDetails;
-extern std::string gScenarioCompletedBy;
 extern std::string gScenarioSavePath;
 extern bool gFirstTimeSaving;
-extern uint16_t gSavedAge;
 extern uint32_t gLastAutoSaveUpdate;
 
 extern std::string gScenarioFileName;
 
-void ScenarioBegin();
-void ScenarioReset();
-void ScenarioUpdate();
+void ScenarioBegin(OpenRCT2::GameState_t& gameState);
+void ScenarioReset(OpenRCT2::GameState_t& gameState);
+void ScenarioUpdate(OpenRCT2::GameState_t& gameState);
 bool ScenarioCreateDucks();
 bool AllowEarlyCompletion();
 
@@ -183,9 +174,9 @@ void ScenarioRandSeed(random_engine_t::result_type s0, random_engine_t::result_t
 random_engine_t::result_type ScenarioRand();
 uint32_t ScenarioRandMax(uint32_t max);
 
-ResultWithMessage ScenarioPrepareForSave();
-int32_t ScenarioSave(u8string_view path, int32_t flags);
-void ScenarioFailure();
-void ScenarioSuccess();
-void ScenarioSuccessSubmitName(const char* name);
+ResultWithMessage ScenarioPrepareForSave(OpenRCT2::GameState_t& gameState);
+int32_t ScenarioSave(OpenRCT2::GameState_t& gameState, u8string_view path, int32_t flags);
+void ScenarioFailure(OpenRCT2::GameState_t& gameState);
+void ScenarioSuccess(OpenRCT2::GameState_t& gameState);
+void ScenarioSuccessSubmitName(OpenRCT2::GameState_t& gameState, const char* name);
 void ScenarioAutosaveCheck();
